@@ -33,13 +33,16 @@ define('SECTION_PLUGINNAME', 'admin');
 define('SECTION_PAGE', 'institutions');
 require_once('pieforms/pieform.php');
 define('MENUITEM', 'manageinstitutions/institutions');
-$smarty = smarty(array('lib/pieforms/static/core/pieforms.js'));
 
 $institution = param_variable('i', '');
 $add         = param_boolean('add');
 $edit        = param_boolean('edit');
 $delete      = param_boolean('delete');
 
+$query = param_variable('query', '');
+$offset = param_integer('offset', 0);
+$limit  = 20;
+
 if (!$USER->get('admin')) {
     // Institutional admins with only 1 institution go straight to the edit page for that institution
     // They cannot add or delete institutions, or edit an institution they don't administer
@@ -65,8 +68,7 @@ if ($institution || $add) {
     if ($delete) {
         function delete_validate(Pieform $form, $values) {
             if (get_field('usr_institution', 'COUNT(*)', 'institution', $values['i'])) {
-                // TODO: exception is of the wrong type
-                throw new Exception('Attempt to delete an institution that has members');
+                throw new ConfigException('Attempt to delete an institution that has members');
             }
         }
 
@@ -130,7 +132,10 @@ if ($institution || $add) {
                 )
             )
         );
-        $smarty->assign('delete_form', pieform($form));
+        $deleteform = pieform($form);
+        $smarty = smarty();
+        $smarty->assign('delete_form', $deleteform);
+        $smarty->assign('institutionname', get_field('institution', 'displayname', 'name', $institution));
         $smarty->display('admin/users/institutions.tpl');
         exit;
     }
@@ -140,6 +145,8 @@ if ($institution || $add) {
     $c = count($authinstances);
     $inuse = '';
 
+    $sitelockedfields = (array) get_column('institution_locked_profile_field', 'profilefield', 'name', 'mahara');
+
     if (!$add) {
         $data = get_record('institution', 'name', $institution);
         $lockedprofilefields = (array) get_column('institution_locked_profile_field', 'profilefield', 'name', $institution);
@@ -149,7 +156,7 @@ if ($institution || $add) {
             foreach($authinstances as $key => $val) {
                 $authinstances[$key]->index = $key;
                 $authinstances[$key]->total = $c;
-                $instancearray[] = $val->id;
+                $instancearray[] = (int)$val->id;
             }
 
             $instancestring = implode(',',$instancearray);
@@ -173,11 +180,10 @@ if ($institution || $add) {
         $data->theme = 'sitedefault';
         $data->defaultmembershipperiod = null;
         $lockedprofilefields = array();
-        $smarty->assign('add', true);
 
         $authtypes = auth_get_available_auth_types();
     }
-    $themeoptions = get_themes();
+    $themeoptions = get_institution_themes($institution);
     $themeoptions['sitedefault'] = '- ' . get_string('sitedefault', 'admin') . ' (' . $themeoptions[get_config('theme')] . ') -';
     uksort($themeoptions, 'theme_sort');
 
@@ -223,7 +229,7 @@ if ($institution || $add) {
             'help'   => true,
         ),
     );
-    if ($institution != 'mahara') {
+    if ($USER->get('admin') && $institution != 'mahara') {
        $elements['expiry'] = array(
             'type'         => 'date',
             'title'        => get_string('institutionexpiry', 'admin'),
@@ -277,7 +283,7 @@ if ($institution || $add) {
         );
         $elements['theme'] = array(
             'type'         => 'select',
-            'title'        => get_string('theme','admin'),
+            'title'        => get_string('theme'),
             'description'  => get_string('sitethemedescription','admin'),
             'defaultvalue' => $data->theme ? $data->theme : 'sitedefault',
             'collapseifoneoption' => true,
@@ -306,11 +312,18 @@ if ($institution || $add) {
         'collapsed' => true,
         'elements' => array(),
     );
+    if ($institution != 'mahara') {
+        $elements['lockedfields']['elements']['description'] = array(
+            'type' => 'html',
+            'value' => get_string('disabledlockedfieldhelp', 'admin', get_field('institution', 'displayname', 'name', 'mahara')),
+        );
+    }
     foreach (ArtefactTypeProfile::get_all_fields() as $field => $type) {
         $elements['lockedfields']['elements'][$field] = array(
             'type' => 'checkbox',
             'title' => get_string($field, 'artefact.internal'),
-            'defaultvalue' => in_array($field, $lockedprofilefields)
+            'defaultvalue' => in_array($field, $lockedprofilefields) || ($institution != 'mahara' && in_array($field, $sitelockedfields)),
+            'disabled' => $institution != 'mahara' && in_array($field, $sitelockedfields)
         );
     }
     $elements['lockedfieldshelp'] = array(
@@ -324,63 +337,66 @@ if ($institution || $add) {
         'value' => array(get_string('submit'), get_string('cancel'))
     );
 
-    $smarty->assign('instancestring', $instancestring);
-
-    $smarty->assign('institution_form', pieform(array(
+    $institutionform = pieform(array(
         'name'     => 'institution',
         'renderer' => 'table',
         'plugintype' => 'core',
         'pluginname' => 'admin',
         'elements' => $elements
-    )));
+    ));
 
 }
 else {
     // Get a list of institutions
+    require_once(get_config('libroot') . 'institution.php');
     if (!$USER->get('admin')) { // Filter the list for institutional admins
-        $where = '
-        WHERE ii.name IN (' . join(',', array_map('db_quote', $USER->get('admininstitutions'))) . ')';
+        $filter      = $USER->get('admininstitutions');
+        $showdefault = false;
     }
     else {
-        $where = '';
-        $smarty->assign('siteadmin', true);
-        $defaultinstmembers = count_records_sql('
-            SELECT COUNT(u.id) FROM {usr} u LEFT OUTER JOIN {usr_institution} i ON u.id = i.usr
-            WHERE u.deleted = 0 AND i.usr IS NULL AND u.id != 0
-        ');
+        $filter      = false;
+        $showdefault = true;
     }
-    $institutions = get_records_sql_assoc('
-        SELECT
-            ii.name,
-            ii.displayname,
-            ii.maxuseraccounts,
-            ii.suspended,
-            COALESCE(a.members, 0) AS members,
-            COALESCE(a.staff, 0) AS staff,
-            COALESCE(a.admins, 0) AS admins
-        FROM
-            {institution} ii
-            LEFT JOIN
-                (SELECT
-                    i.name, i.displayname, i.maxuseraccounts,
-                    COUNT(ui.usr) AS members, SUM(ui.staff) AS staff, SUM(ui.admin) AS admins
-                FROM
-                    {institution} i
-                    LEFT OUTER JOIN {usr_institution} ui ON (ui.institution = i.name)
-                    LEFT OUTER JOIN {usr} u ON (u.id = ui.usr)
-                WHERE
-                    (u.deleted = 0 OR u.id IS NULL)
-                GROUP BY
-                    i.name, i.displayname, i.maxuseraccounts
-                ) a ON (a.name = ii.name)' . $where . '
-                ORDER BY
-                    ii.name = \'mahara\', ii.displayname', array());
-    if (isset($defaultinstmembers)) {
-        $institutions['mahara']->members = $defaultinstmembers;
-        $institutions['mahara']->staff   = '';
-        $institutions['mahara']->admins  = '';
-    }
-    $smarty->assign('institutions', $institutions);
+    $data = build_institutions_html($filter, $showdefault, $query, $limit, $offset, $count);
+
+    $smarty = smarty(array('lib/pieforms/static/core/pieforms.js', 'paginator'));
+    $smarty->assign('results', $data);
+    $smarty->assign('countinstitutions', $count);
+
+    /*search institution form*/
+    $searchform = pieform(array(
+        'name' => 'search',
+        'renderer' => 'oneline',
+        'elements' => array(
+            'query' => array(
+                'type' => 'text',
+                'defaultvalue' => $query
+            ),
+            'submit' => array(
+                'type' => 'submit',
+                'value' => get_string('search')
+            )
+        )
+    ));
+    $smarty->assign('searchform', $searchform);
+
+    $js = <<< EOF
+    addLoadEvent(function () {
+    p = {$data['pagination_js']}
+    connect('search_submit', 'onclick', function (event) {
+        replaceChildNodes('messages');
+        var params = {'query': $('search_query').value};
+        p.sendQuery(params);
+        event.stop();
+        });
+    });
+EOF;
+
+    $smarty->assign('INLINEJAVASCRIPT', $js);
+    $smarty->assign('siteadmin', $USER->get('admin'));
+    $smarty->assign('PAGEHEADING', get_string('admininstitutions', 'admin'));
+    $smarty->display('admin/users/institutions.tpl');
+    exit;
 }
 
 function institution_validate(Pieform $form, $values) {
@@ -412,10 +428,10 @@ function institution_submit(Pieform $form, $values) {
     }
     $newinstitution->theme                        = (empty($values['theme']) || $values['theme'] == 'sitedefault') ? null : $values['theme'];
     if ($institution != 'mahara') {
-        $newinstitution->expiry                   = db_format_timestamp($values['expiry']);
         $newinstitution->defaultmembershipperiod  = ($values['defaultmembershipperiod']) ? intval($values['defaultmembershipperiod']) : null;
         if ($USER->get('admin')) {
             $newinstitution->maxuseraccounts      = ($values['maxuseraccounts']) ? intval($values['maxuseraccounts']) : null;
+            $newinstitution->expiry               = db_format_timestamp($values['expiry']);
         }
     }
 
@@ -423,20 +439,17 @@ function institution_submit(Pieform $form, $values) {
         $allinstances = array_merge($values['authplugin']['instancearray'], $values['authplugin']['deletearray']);
 
         if (array_diff($allinstances, $instancearray)) {
-            // TODO wrong exception type
-            throw new Exception('Attempt to delete or update another institution\'s auth instance');
+            throw new ConfigException('Attempt to delete or update another institution\'s auth instance');
         }
 
         if (array_diff($instancearray, $allinstances)) {
-            // TODO wrong exception type
-            throw new Exception('One of your instances is unaccounted for in this transaction');
+            throw new ConfigException('One of your instances is unaccounted for in this transaction');
         }
 
         foreach($values['authplugin']['instancearray'] as $priority => $instanceid) {
             if (in_array($instanceid, $values['authplugin']['deletearray'])) {
                 // Should never happen:
-                // TODO wrong exception type
-                throw new Exception('Attempt to update AND delete an auth instance');
+                throw new SystemException('Attempt to update AND delete an auth instance');
             }
             $record = new StdClass;
             $record->priority = $priority;
@@ -449,8 +462,8 @@ function institution_submit(Pieform $form, $values) {
             $hostwwwroot = null;
             foreach ($authinstances as $ai) {
                 if ($ai->id == $instanceid && $ai->authname == 'xmlrpc') {
-                    $hostwwwroot = get_field_sql("SELECT value FROM {auth_instance_config} WHERE instance = ? AND field = 'wwwroot'", array($instanceid));
-                    if ($hostwwwroot && count_records_select('auth_instance_config', "field = 'wwwroot' AND value = ?", array($hostwwwroot)) == 1) {
+                    $hostwwwroot = get_field_sql("SELECT \"value\" FROM {auth_instance_config} WHERE \"instance\" = ? AND field = 'wwwroot'", array($instanceid));
+                    if ($hostwwwroot && count_records_select('auth_instance_config', "field = 'wwwroot' AND \"value\" = ?", array($hostwwwroot)) == 1) {
                         // Unfortunately, it's possible that this host record could belong to a different institution,
                         // so specify the institution here.
                         delete_records('host', 'wwwroot', $hostwwwroot, 'institution', $institution);
@@ -526,89 +539,105 @@ function institution_cancel_submit() {
 }
 
 if ($institution && $institution != 'mahara') {
-    function institution_suspend_submit(Pieform $form, $values) {
-        global $SESSION, $USER;
-        if (!$USER->get('admin')) {
-            $SESSION->add_error_msg(get_string('errorwhilesuspending', 'admin'));
-        }
-        else {
-            set_field('institution', 'suspended', 1, 'name', $values['i']);
-            $SESSION->add_ok_msg(get_string('institutionsuspended', 'admin'));
-        }
-        redirect('/admin/users/institutions.php?i=' . $values['i']);
-    }
-
-    function institution_unsuspend_submit(Pieform $form, $values) {
-        global $SESSION, $USER;
-        if (!$USER->get('admin')) {
-            $SESSION->add_error_msg(get_string('errorwhileunsuspending', 'admin'));
-        }
-        else {
-            set_field('institution', 'suspended', 0, 'name', $values['i']);
-            $SESSION->add_ok_msg(get_string('institutionunsuspended', 'admin'));
-        }
-        redirect('/admin/users/institutions.php?i=' . $values['i']);
-    }
-
     $_institution = get_record('institution', 'name', $institution);
-    // Suspension controls
     $suspended = $_institution->suspended;
-    if (empty($suspended)) {
-        $suspendformdef = array(
-            'name'       => 'institution_suspend',
-            'plugintype' => 'core',
-            'pluginname' => 'admin',
-            'elements'   => array(
-                'i' => array(
-                     'type'    => 'hidden',
-                     'value'   => $institution,
-                ),
-                'submit' => array(
-                    'type'        => 'submit',
-                    'value'       => get_string('suspendinstitution','admin'),
-                    'description' => get_string('suspendinstitutiondescription','admin'),
-                ),
-            )
-        );
+    if ($USER->get('admin')) {
+        function institution_suspend_submit(Pieform $form, $values) {
+            global $SESSION, $USER;
+            if (!$USER->get('admin')) {
+                $SESSION->add_error_msg(get_string('errorwhilesuspending', 'admin'));
+            }
+            else {
+                set_field('institution', 'suspended', 1, 'name', $values['i']);
+                $SESSION->add_ok_msg(get_string('institutionsuspended', 'admin'));
+            }
+            redirect('/admin/users/institutions.php?i=' . $values['i']);
+        }
 
-        $suspendform  = pieform($suspendformdef);
-    }
-    else {
-        $suspendformdef = array(
-            'name'       => 'institution_unsuspend',
-            'plugintype' => 'core',
-            'pluginname' => 'admin',
-            'elements'   => array(
-                'i' => array(
-                     'type'    => 'hidden',
-                     'value'   => $institution,
-                ),
-                'submit' => array(
-                    'type'        => 'submit',
-                    'value'       => get_string('unsuspendinstitution','admin'),
-                    'description' => get_string('unsuspendinstitutiondescription','admin'),
-                ),
-            )
-        );
-        $suspendform  = pieform($suspendformdef);
+        function institution_unsuspend_submit(Pieform $form, $values) {
+            global $SESSION, $USER;
+            if (!$USER->get('admin')) {
+                $SESSION->add_error_msg(get_string('errorwhileunsuspending', 'admin'));
+            }
+            else {
+                set_field('institution', 'suspended', 0, 'name', $values['i']);
+                $SESSION->add_ok_msg(get_string('institutionunsuspended', 'admin'));
+            }
+            redirect('/admin/users/institutions.php?i=' . $values['i']);
+        }
 
-        // Create a second forms for unsuspension to go in the suspend message.
-        // This keeps the HTML IDs unique
-        $suspendformdef['name'] = 'institution_unsuspend_top';
-        $suspendformdef['renderer'] = 'oneline';
-        $suspendformdef['successcallback'] = 'institution_unsuspend_submit';
-        $suspendform_top = pieform($suspendformdef);
-    }
-    $smarty->assign('suspendform', $suspendform);
-    if (isset($suspendform_top)) {
-        $smarty->assign('suspendform_top', $suspendform_top);
-    }
-    if ($suspended) {
-        $smarty->assign('suspended', get_string('suspendedinstitutionmessage', 'admin'));
+        // Suspension controls
+        if (empty($suspended)) {
+            $suspendformdef = array(
+                'name'       => 'institution_suspend',
+                'plugintype' => 'core',
+                'pluginname' => 'admin',
+                'elements'   => array(
+                    'i' => array(
+                        'type'    => 'hidden',
+                        'value'   => $institution,
+                    ),
+                    'submit' => array(
+                        'type'        => 'submit',
+                        'value'       => get_string('suspendinstitution','admin'),
+                        'description' => get_string('suspendinstitutiondescription','admin'),
+                    ),
+                )
+            );
+
+            $suspendform  = pieform($suspendformdef);
+        }
+        else {
+            $suspendformdef = array(
+                'name'       => 'institution_unsuspend',
+                'plugintype' => 'core',
+                'pluginname' => 'admin',
+                'elements'   => array(
+                    'i' => array(
+                        'type'    => 'hidden',
+                        'value'   => $institution,
+                    ),
+                    'submit' => array(
+                        'type'        => 'submit',
+                        'value'       => get_string('unsuspendinstitution','admin'),
+                        'description' => get_string('unsuspendinstitutiondescription','admin'),
+                    ),
+                )
+            );
+            $suspendform  = pieform($suspendformdef);
+
+            // Create a second forms for unsuspension to go in the suspend message.
+            // This keeps the HTML IDs unique
+            $suspendformdef['name'] = 'institution_unsuspend_top';
+            $suspendformdef['renderer'] = 'oneline';
+            $suspendformdef['successcallback'] = 'institution_unsuspend_submit';
+            $suspendform_top = pieform($suspendformdef);
+        }
     }
 }
 
-$smarty->assign('PAGEHEADING', hsc(get_string('admininstitutions', 'admin')));
+function search_submit(Pieform $form, $values) {
+    redirect('/admin/users/institutions.php' . (!empty($values['query']) ? '?query=' . urlencode($values['query']) : ''));
+}
+
+$smarty = smarty();
+$smarty->assign('institution_form', $institutionform);
+$smarty->assign('instancestring', $instancestring);
+$smarty->assign('add', $add);
+
+if (isset($suspended)) {
+    if ($suspended) {
+        $smarty->assign('suspended', get_string('suspendedinstitutionmessage', 'admin'));
+    }
+    if (isset($suspendform)) {
+        $smarty->assign('suspendform', $suspendform);
+        if (isset($suspendform_top)) {
+            $smarty->assign('suspendform_top', $suspendform_top);
+        }
+    }
+}
+
+$smarty->assign('PAGEHEADING', get_string('admininstitutions', 'admin'));
 $smarty->display('admin/users/institutions.tpl');
 
 function theme_sort($a, $b) {
@@ -620,5 +649,3 @@ function theme_sort($a, $b) {
     }
     return $a > $b;
 }
-
-?>
