@@ -27,9 +27,8 @@
 
 defined('INTERNAL') || die();
 
-$string['title'] = 'Blog';
-$string['description'] = 'Display an entire blog';
+$string['title'] = 'Journal';
+$string['description'] = 'Display an entire journal';
 
-$string['defaulttitledescription'] = 'If you leave this blank, the title of the blog will be used';
-
-?>
+$string['defaulttitledescription'] = 'If you leave this blank, the title of the journal will be used';
+$string['postsperpage'] = 'Entries per page';
