@@ -26,7 +26,7 @@
  */
 
 define('INTERNAL', 1);
-define('MENUITEM', 'myportfolio/blogs');
+define('MENUITEM', 'content/blogs');
 define('SECTION_PLUGINTYPE', 'artefact');
 define('SECTION_PLUGINNAME', 'blog');
 define('SECTION_PAGE', 'new');
@@ -58,6 +58,7 @@ $form = pieform(array(
             'title'       => get_string('blogdesc', 'artefact.blog'),
             'description' => get_string('blogdescdesc', 'artefact.blog'),
             'rules' => array(
+                'maxlength'   => 65536,
                 'required'    => false
             ),
         ),
@@ -78,9 +79,9 @@ $form = pieform(array(
 ));
 
 $smarty =& smarty();
-$smarty->assign_by_ref('newblogform', $form);
-$smarty->assign_by_ref('PAGEHEADING', hsc(TITLE));
-$smarty->display('artefact:blog:new.tpl');
+$smarty->assign_by_ref('form', $form);
+$smarty->assign('PAGEHEADING', TITLE);
+$smarty->display('form.tpl');
 exit;
 
 /**
@@ -101,5 +102,3 @@ function newblog_submit(Pieform $form, $values) {
 function newblog_cancel_submit() {
     redirect('/artefact/blog/');
 }
-
-?>
