@@ -26,7 +26,7 @@
  */
 
 define('INTERNAL', 1);
-define('MENUITEM', 'myportfolio/blogs');
+define('MENUITEM', 'content/blogs');
 define('SECTION_PLUGINTYPE', 'artefact');
 define('SECTION_PLUGINNAME', 'blog');
 define('SECTION_PAGE', 'post');
@@ -63,6 +63,9 @@ if (!$blogpost) {
 else {
     $blogpostobj = new ArtefactTypeBlogPost($blogpost);
     $blogpostobj->check_permission();
+    if ($blogpostobj->get('locked')) {
+        throw new AccessDeniedException(get_string('submittedforassessment', 'view'));
+    }
     $blog = $blogpostobj->get('parent');
     $title = $blogpostobj->get('title');
     $description = $blogpostobj->get('description');
@@ -74,7 +77,6 @@ else {
     define('TITLE', get_string('editblogpost','artefact.blog'));
 }
 
-
 $folder = param_integer('folder', 0);
 $browse = (int) param_variable('browse', 0);
 $highlight = null;
@@ -89,8 +91,8 @@ $form = pieform(array(
     'autofocus'          => $focuselement,
     'jsform'             => true,
     'newiframeonsubmit'  => true,
-    'jssuccesscallback'  => 'editpost_success',
-    'jserrorcallback'    => 'editpost_error',
+    'jssuccesscallback'  => 'editpost_callback',
+    'jserrorcallback'    => 'editpost_callback',
     'plugintype'         => 'artefact',
     'pluginname'         => 'blog',
     'configdirs'         => array(get_config('libroot') . 'form/', get_config('docroot') . 'artefact/file/form/'),
@@ -118,6 +120,7 @@ $form = pieform(array(
             'title' => get_string('postbody', 'artefact.blog'),
             'description' => get_string('postbodydesc', 'artefact.blog'),
             'rules' => array(
+                'maxlength' => 65536,
                 'required' => true
             ),
             'defaultvalue' => $description,
@@ -156,6 +159,12 @@ $form = pieform(array(
             'defaultvalue' => $checked,
             'help' => true,
         ),
+        'allowcomments' => array(
+            'type'         => 'checkbox',
+            'title'        => get_string('allowcomments','artefact.comment'),
+            'description'  => get_string('allowcommentsonpost','artefact.blog'),
+            'defaultvalue' => $blogpost ? $blogpostobj->get('allowcomments') : 1,
+        ),
         'submitpost' => array(
             'type' => 'submitcancel',
             'value' => array(get_string('savepost', 'artefact.blog'), get_string('cancel')),
@@ -180,78 +189,6 @@ $javascript = <<<EOF
 // to select an image from the list of image files attached to the
 // post.
 
-// The contents of this function is stolen straight out of the tinyMCE
-// code in tinymce/themes/advanced/editor_template_src.js
-function getSelectedImgAttributes (editorid) {
-    var src = "", alt = "", border = "", hspace = "", vspace = "", width = "", height = "", align = "";
-    var title = "", onmouseover = "", onmouseout = "", action = "insert";
-    var img = tinyMCE.imgElement;
-    var inst = tinyMCE.getInstanceById(editorid);
-
-    if (tinyMCE.selectedElement != null && tinyMCE.selectedElement.nodeName.toLowerCase() == "img") {
-        img = tinyMCE.selectedElement;
-        tinyMCE.imgElement = img;
-    }
-
-    if (img) {
-        // Is it a internal MCE visual aid image, then skip this one.
-        if (tinyMCE.getAttrib(img, 'name').indexOf('mce_') == 0)
-            return true;
-
-        src = tinyMCE.getAttrib(img, 'src');
-        alt = tinyMCE.getAttrib(img, 'alt');
-
-        // Try polling out the title
-        if (alt == "")
-            alt = tinyMCE.getAttrib(img, 'title');
-
-        // Fix width/height attributes if the styles is specified
-        if (tinyMCE.isGecko) {
-            var w = img.style.width;
-            if (w != null && w != "")
-                img.setAttribute("width", w);
-
-            var h = img.style.height;
-            if (h != null && h != "")
-                img.setAttribute("height", h);
-        }
-
-        border = tinyMCE.getAttrib(img, 'border');
-        hspace = tinyMCE.getAttrib(img, 'hspace');
-        vspace = tinyMCE.getAttrib(img, 'vspace');
-        width = tinyMCE.getAttrib(img, 'width');
-        height = tinyMCE.getAttrib(img, 'height');
-        align = tinyMCE.getAttrib(img, 'align');
-        onmouseover = tinyMCE.getAttrib(img, 'onmouseover');
-        onmouseout = tinyMCE.getAttrib(img, 'onmouseout');
-        title = tinyMCE.getAttrib(img, 'title');
-
-        // Is realy specified?
-        if (tinyMCE.isMSIE) {
-            width = img.attributes['width'].specified ? width : "";
-            height = img.attributes['height'].specified ? height : "";
-        }
-
-        src = eval(tinyMCE.settings['urlconverter_callback'] + "(src, img, true);");
-
-        // Use mce_src if defined
-        mceRealSrc = tinyMCE.getAttrib(img, 'mce_src');
-        if (mceRealSrc != "") {
-            src = mceRealSrc;
-
-            if (tinyMCE.getParam('convert_urls'))
-                src = eval(tinyMCE.settings['urlconverter_callback'] + "(src, img, true);");
-        }
-
-        action = "update";
-    }
-    return {'src' : src, 'alt' : alt, 'border' : border, 'hspace' : hspace, 'vspace' : vspace, 
-            'width' : width, 'height' : height, 'align' : align, 'title' : title, 
-            'onmouseover' : onmouseover, 'onmouseout' : onmouseout, 'action' : action};
-}
-
-
-
 // Get all the files in the attached files list that have been
 // recognised as images.  This function is called by the the popup
 // window, but needs access to the attachment list on this page
@@ -260,7 +197,11 @@ function attachedImageList() {
     var attachments = editpost_filebrowser.selecteddata;
     for (var a in attachments) {
         if (attachments[a].artefacttype == 'image') {
-            images.push({'id': attachments[a].id, 'name': attachments[a].title});
+            images.push({
+                'id': attachments[a].id,
+                'name': attachments[a].title,
+                'description': attachments[a].description ? attachments[a].description : ''
+            });
         }
     }
     return images;
@@ -286,14 +227,10 @@ function blogpostImageWindow(ui, v) {
     var t = tinyMCE.activeEditor;
 
     imageList = attachedImageList();
-    if (imageList.length == 0) {
-        alert({$noimagesmessage});
-        return true;
-    }
 
     var template = new Array();
 
-    template['file'] = '{$wwwroot}artefact/blog/image_popup.php?src=\{\$src\}';
+    template['file'] = '{$wwwroot}artefact/blog/image_popup.php';
     template['width'] = 355;
     template['height'] = 275 + (tinyMCE.isMSIE ? 25 : 0);
 
@@ -305,12 +242,8 @@ function blogpostImageWindow(ui, v) {
     t.windowManager.open(template);
 }
 
-function editpost_success(form, data) {
-    editpost_filebrowser.success(form, data);
-};
-
-function editpost_error(form, data) {
-    editpost_filebrowser.init();
+function editpost_callback(form, data) {
+    editpost_filebrowser.callback(form, data);
 };
 
 EOF;
@@ -327,7 +260,7 @@ $smarty = smarty(array(), array(), array(), array(
 ));
 $smarty->assign('INLINEJAVASCRIPT', $javascript);
 $smarty->assign_by_ref('form', $form);
-$smarty->assign('PAGEHEADING', hsc($pagetitle));
+$smarty->assign('PAGEHEADING', $pagetitle);
 $smarty->display('artefact:blog:editpost.tpl');
 
 
@@ -350,6 +283,7 @@ function editpost_submit(Pieform $form, $values) {
     $postobj->set('description', $values['description']);
     $postobj->set('tags', $values['tags']);
     $postobj->set('published', !$values['draft']);
+    $postobj->set('allowcomments', (int) $values['allowcomments']);
     if (!$blogpost) {
         $postobj->set('parent', $blog);
         $postobj->set('owner', $USER->id);
@@ -364,12 +298,18 @@ function editpost_submit(Pieform $form, $values) {
     if (!empty($new) || !empty($old)) {
         foreach ($old as $o) {
             if (!in_array($o, $new)) {
-                $postobj->detach($o);
+                try {
+                    $postobj->detach($o);
+                }
+                catch (ArtefactNotFoundException $e) {}
             }
         }
         foreach ($new as $n) {
             if (!in_array($n, $old)) {
-                $postobj->attach($n);
+                try {
+                    $postobj->attach($n);
+                }
+                catch (ArtefactNotFoundException $e) {}
             }
         }
     }
@@ -401,5 +341,3 @@ function delete_attachment($attachmentid) {
         $blogpostobj->detach($attachmentid);
     }
 }
- 
-?>
