@@ -41,9 +41,7 @@ class PluginBlocktypeFolder extends PluginBlocktype {
         $configdata = $bi->get('configdata');
 
         if (!empty($configdata['artefactid'])) {
-            require_once(get_config('docroot') . 'artefact/lib.php');
-            $folder = artefact_instance_from_id($configdata['artefactid']);
-            return $folder->get('title');
+            return $bi->get_artefact_instance($configdata['artefactid'])->get('title');
         }
         return '';
     }
@@ -117,7 +115,7 @@ class PluginBlocktypeFolder extends PluginBlocktype {
     }
 
     public static function artefactchooser_get_sort_order() {
-        return 'parent, title';
+        return array(array('fieldname' => 'parent'), array('fieldname' => 'title'));
     }
 
     public static function filebrowser_element(&$instance, $default=array()) {
@@ -138,5 +136,3 @@ class PluginBlocktypeFolder extends PluginBlocktype {
     }
 
 }
-
-?>
