@@ -266,7 +266,7 @@ class PluginBlocktypeInternalmedia extends PluginBlocktype {
 
         $baseurl = get_config('wwwroot') . 'artefact/file/blocktype/internalmedia/';
 
-        $playerurl = $baseurl . 'flowplayer/flowplayer-3.2.4.swf';
+        $playerurl = $baseurl . 'flowplayer/flowplayer-3.2.7.swf';
         $autohide = 'true';
         $type = '';
         $audio = '';
@@ -277,7 +277,7 @@ class PluginBlocktypeInternalmedia extends PluginBlocktype {
             $type = 'type: "audio",'; // force the player to use the audio plugin
             $buffering = 'false'; // without this autoPlay will also be set to true
             $audio = ', audio: {
-		                  url: "' . $baseurl . 'flowplayer.audio/flowplayer.audio-3.2.1.swf"
+		                  url: "' . $baseurl . 'flowplayer.audio/flowplayer.audio-3.2.2.swf"
 		             }';
         }
 
@@ -294,7 +294,7 @@ class PluginBlocktypeInternalmedia extends PluginBlocktype {
                    },
                    plugins: {
 	                  controls: {
-                          url: "flowplayer.controls-3.2.2.swf",
+                          url: "flowplayer.controls-3.2.5.swf",
                           play:true,
                           volume:true,
                           mute:true,
@@ -431,9 +431,8 @@ class PluginBlocktypeInternalmedia extends PluginBlocktype {
             return '';
         }
         define('BLOCKTYPE_INTERNALMEDIA_JS_INCLUDED', true);
-        return '<script src="'.get_config('wwwroot').'artefact/file/blocktype/internalmedia/flowplayer/flowplayer-3.2.4.js"></script>
-             <script src="' . get_config('wwwroot') . 'artefact/file/blocktype/internalmedia/swfobject.js" type="text/javascript"></script>
-             <script defer="defer" src="' . get_config('wwwroot') . 'artefact/file/blocktype/internalmedia/eolas_fix.js" type="text/javascript"></script>';
+        return '<script src="'.get_config('wwwroot').'artefact/file/blocktype/internalmedia/flowplayer/flowplayer-3.2.6.js"></script>
+             <script src="' . get_config('wwwroot') . 'artefact/file/blocktype/internalmedia/swfobject.js" type="text/javascript"></script>';
     }
 
     public static function default_copy_type() {
