@@ -1,3 +1,26 @@
+/**
+ * File browser
+ * @source: http://gitorious.org/mahara/mahara
+ *
+ * @licstart
+ * Copyright (C) 2006-2010  Catalyst IT Ltd
+ *
+ * The JavaScript code in this page is free software: you can
+ * redistribute it and/or modify it under the terms of the GNU
+ * General Public License (GNU GPL) as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option)
+ * any later version.  The code is distributed WITHOUT ANY WARRANTY;
+ * without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU GPL for more details.
+ *
+ * As additional permission under GNU GPL version 3 section 7, you
+ * may distribute non-source (e.g., minimized or compacted) forms of
+ * that code without the copy of the GNU GPL normally required by
+ * section 4, provided you include this license notice and a URL
+ * through which recipients can access the Corresponding Source.
+ * @licend
+ */
+
 function FileBrowser(idprefix, folderid, config, globalconfig) {
 
     var self = this;
@@ -47,6 +70,17 @@ function FileBrowser(idprefix, folderid, config, globalconfig) {
                 'value':0
             }));
         }
+        if (is_FF() && self.config.select && !$(self.id + '_uploadsubmit') && $(self.id + '_uploadsubmit_container')) {
+            var submitbutton = INPUT({
+                'class': 'submit',
+                'type': 'submit',
+                'name': self.id + '_uploadsubmit',
+                'id': self.id + '_uploadsubmit',
+                'value': get_string('upload')
+            });
+            appendChildNodes(self.id + '_uploadsubmit_container', submitbutton);
+            self.config.submitbutton = true;
+        }
         self.upload_connectbuttons();
     }
 
@@ -62,7 +96,15 @@ function FileBrowser(idprefix, folderid, config, globalconfig) {
                 }
             });
         }
-        connect(self.id + '_userfile', 'onchange', self.upload_submit);
+        if (self.config.submitbutton && $(self.id + '_uploadsubmit')) {
+            connect(self.id + '_uploadsubmit', 'onclick', self.upload_submit);
+        }
+        else {
+            connect(self.id + '_userfile', 'onchange', self.upload_submit);
+            if ($(self.id + '_uploadsubmit')) {
+                removeElement(self.id + '_uploadsubmit');
+            }
+        }
     }
 
     this.upload_validate = function () {
@@ -105,7 +147,9 @@ function FileBrowser(idprefix, folderid, config, globalconfig) {
             'name':'userfile',
             'size':40
         }));
-        connect(self.id + '_userfile', 'onchange', self.upload_submit);
+        if (!$(self.id + '_uploadsubmit')) {
+            connect(self.id + '_userfile', 'onchange', self.upload_submit);
+        }
         $(self.id + '_upload').value = 0;
         return false;
     }
@@ -169,20 +213,24 @@ function FileBrowser(idprefix, folderid, config, globalconfig) {
         }
     }
 
-    this.upload_success = function (data) {
+    this.callback_feedback = function (data) {
         if (data.problem) {
             var image = 'images/icon_problem.gif';
         }
-        else if (!data.error) {
-            var image = 'images/success.gif';
+        else if (data.error) {
+            var image = 'images/failure.gif';
         }
         else {
-            var image = 'images/failure.gif';
+            var image = 'images/success.gif';
         }
 
         quotaUpdate(data.quotaused, data.quota);
-        var newmessage = makeMessage(DIV(null,IMG({'src':get_themeurl(image)}), ' ', data.message));
-        replaceChildNodes($('uploadstatusline'+data.uploadnumber), newmessage);
+        var newmessage = makeMessage(DIV(null,IMG({'src':get_themeurl(image)}), ' ', data.message), 'info');
+        setNodeAttribute(newmessage, 'id', 'uploadstatusline' + data.uploadnumber);
+        if (data.uploadnumber) {
+            removeElement($('uploadstatusline'+data.uploadnumber));
+        }
+        appendChildNodes(self.id + '_upload_messages', newmessage);
     }
 
     this.hide_edit_form = function () {
@@ -210,6 +258,7 @@ function FileBrowser(idprefix, folderid, config, globalconfig) {
         $(self.id + '_edit_heading').innerHTML = self.filedata[id].artefacttype == 'folder' ? get_string('editfolder') : get_string('editfile');
         $(self.id + '_edit_title').value = self.filedata[id].title;
         $(self.id + '_edit_description').value = self.filedata[id].description == null ? '' : self.filedata[id].description;
+        $(self.id + '_edit_allowcomments').checked = self.filedata[id].allowcomments;
         $(self.id + '_edit_tags').value = self.filedata[id].tags.join(', ');
         replaceChildNodes($(self.id + '_edit_messages'));
         forEach(getElementsByTagAndClassName('input', 'permission', self.id + '_edit_row'), function (elem) {
@@ -223,6 +272,8 @@ function FileBrowser(idprefix, folderid, config, globalconfig) {
         });
         // $(self.id + '_edit_artefact').value = id; // Changes button text in IE
         setNodeAttribute(self.id + '_edit_artefact', 'name', self.id + '_update[' + id + ']');
+        var tags_control_elem = augment_tags_control(self.id + '_edit_tags', true);
+        swapDOM($(self.id + '_edit_tags').parentNode.firstChild, tags_control_elem);
         var edit_row = removeElement(self.id + '_edit_row');
         var this_row = getFirstParentByTagAndClassName(this, 'tr');
         insertSiblingNodesAfter(this_row, edit_row);
@@ -245,7 +296,7 @@ function FileBrowser(idprefix, folderid, config, globalconfig) {
 
     this.browse_init = function () {
         if (self.config.edit || self.config.editmeta) {
-            forEach(getElementsByTagAndClassName('input', null, 'filelist'), function (elem) {
+            forEach(getElementsByTagAndClassName('input', null, self.id + '_filelist'), function (elem) {
                 var name = getNodeAttribute(elem, 'name').match(new RegExp('^' + self.id + "_([a-z]+)\\[(\\d+)\\]$"));
                 if (name && name[1]) {
                     if (name[1] == 'edit') {
@@ -301,10 +352,10 @@ function FileBrowser(idprefix, folderid, config, globalconfig) {
                 forEach(Draggables.drags, function (drag) { drag.destroy(); });
                 forEach(Droppables.drops, function (drop) { drop.destroy(); });
 
-                forEach(getElementsByTagAndClassName('div', 'icon-drag', 'filelist'), function (elem) {
+                forEach(getElementsByTagAndClassName('div', 'icon-drag', self.id + '_filelist'), function (elem) {
                     self.make_icon_draggable(elem);
                 });
-                forEach(getElementsByTagAndClassName('tr', 'folder', 'filelist'), self.make_row_droppable);
+                forEach(getElementsByTagAndClassName('tr', 'folder', self.id + '_filelist'), self.make_row_droppable);
             }
         }
         forEach(getElementsByTagAndClassName('a', 'changeowner', self.id + '_upload_browse'), function (elem) {
@@ -452,7 +503,7 @@ function FileBrowser(idprefix, folderid, config, globalconfig) {
     }
 
     this.connect_select_buttons = function () {
-        forEach(getElementsByTagAndClassName('input', 'select', 'filelist'), function (elem) {
+        forEach(getElementsByTagAndClassName('input', 'select', self.id + '_filelist'), function (elem) {
             var id = elem.name.replace(/.*_select\[(\d+)\]$/, '$1');
             if (self.selecteddata[id]) {
                 addElementClass(elem, 'hidden');
@@ -536,10 +587,14 @@ function FileBrowser(idprefix, folderid, config, globalconfig) {
         return false;
     }
 
-    this.success = function (form, data) {
+    this.callback = function (form, data) {
         self.form = form; // ????
-        if (data.uploaded) {
-            self.upload_success(data);  // Remove uploading message
+        if (data.uploaded || data.error || data.deleted) {
+            self.callback_feedback(data);  // add/update message
+            if (data.maxuploadsize) {
+                // keep max upload size up to date
+                replaceChildNodes(self.id + '_userfile_maxuploadsize', '(' + get_string('maxuploadsize') + ' ' + data.maxuploadsize + ')');
+            }
         }
         // Only update the file listing if the user hasn't changed folders yet
         if (data.newlist && (data.folder == self.folderid || data.changedfolder)) {
@@ -561,14 +616,27 @@ function FileBrowser(idprefix, folderid, config, globalconfig) {
                         addElementClass(self.id + '_upload_container', 'hidden');
                     }
                 }
+                if (self.config.upload) {
+                    if (data.disableedit && !hasElementClass(self.id + '_upload_container', 'hidden')) {
+                        addElementClass(self.id + '_upload_container', 'hidden');
+                        if ($('createfolder')) {
+                            addElementClass('createfolder', 'hidden');
+                        }
+                        removeElementClass(self.id + '_upload_disabled', 'hidden');
+                    }
+                    else if (hasElementClass(self.id + '_upload_container', 'hidden') && !data.disableedit) {
+                        removeElementClass(self.id + '_upload_container', 'hidden');
+                        if ($('createfolder')) {
+                            removeElementClass('createfolder', 'hidden');
+                        }
+                        addElementClass(self.id + '_upload_disabled', 'hidden');
+                    }
+                }
             }
             else if (data.uploaded && self.config.select && data.highlight) {
                 // Newly uploaded files should be automatically selected
                 self.add_to_selected_list(data.highlight, true);
             }
-            else if (data.deleted) {
-                quotaUpdate(data.quotaused, data.quota);
-            }
             if (data.tagblockhtml && $('sb-tags')) {
                 $('sb-tags').innerHTML = data.tagblockhtml;
             }
