@@ -34,6 +34,8 @@ $string['addafile'] = 'Add a file';
 $string['archive'] = 'Archive';
 $string['bytes'] = 'bytes';
 $string['cannoteditfolder'] = 'You do not have permission to add content to this folder';
+$string['cannoteditfoldersubmitted'] = 'You cannot add content to a folder in a submitted page.';
+$string['cannotremovefromsubmittedfolder'] = 'You cannot remove content from a folder in a submitted page.';
 $string['changessaved'] = 'Changes saved';
 $string['clickanddragtomovefile'] = 'Click and drag to move %s';
 $string['contents'] = 'Contents';
@@ -49,6 +51,13 @@ $string['Date'] = 'Date';
 $string['defaultagreement'] = 'Default Agreement';
 $string['defaultquota'] = 'Default Quota';
 $string['defaultquotadescription'] = 'You can set the amount of disk space that new users will have as their quota here. Existing user quotas will not be changed.';
+$string['maxquotaenabled'] = 'Enforce a site-wide maximum quota';
+$string['maxquota'] = 'Maximum Quota';
+$string['maxquotatoolow'] = 'The maximum quota cannot be lower than the default quota.';
+$string['maxquotaexceeded'] = 'You specified a quota above the maximum available setting for this site (%s). Try specifying a lower value or contact the site administrator to have them increase the maximum quota.';
+$string['maxquotaexceededform'] = 'Please specify a file quota of less than %s.';
+$string['maxquotadescription'] = 'You can set the maximum quota that an administrator can give to a user. Existing user quotas will not be affected.';
+$string['deletingfailed'] =  'Deleting failed: file or folder does not exist any more';
 $string['deletefile?'] = 'Are you sure you want to delete this file?';
 $string['deletefolder?'] = 'Are you sure you want to delete this folder?';
 $string['Description'] = 'Description';
@@ -59,12 +68,15 @@ $string['downloadfile'] = 'Download %s';
 $string['downloadoriginalversion'] = 'Download the original version';
 $string['editfile'] = 'Edit file';
 $string['editfolder'] = 'Edit folder';
+$string['editingfailed'] = 'Editing failed: file or folder does not exist any more';
 $string['emptyfolder'] = 'Empty folder';
 $string['file'] = 'File'; // Capitalised to be consistent with names of all the other artefact types
 $string['File'] = 'File';
+$string['fileadded'] = 'File selected';
 $string['filealreadyindestination'] = 'The file you moved is already in that folder';
-$string['fileappearsinviews'] = 'This file appears in one or more of your views.';
+$string['fileappearsinviews'] = 'This file appears in one or more of your pages.';
 $string['fileattached'] = 'This file is attached to %s other item(s) in your portfolio.';
+$string['fileremoved'] = 'File removed';
 $string['files'] = 'files';
 $string['Files'] = 'Files';
 $string['fileexists'] = 'File exists';
@@ -72,12 +84,12 @@ $string['fileexistsoverwritecancel'] =  'A file with that name already exists.
 $string['filelistloaded'] = 'File list loaded';
 $string['filemoved'] = 'File moved successfully';
 $string['filenamefieldisrequired'] = 'The file field is required';
-$string['fileinstructions'] = 'Upload your images, documents, or other files for inclusion in views. To move a file or folder, drag and drop it onto a folder.';
+$string['fileinstructions'] = 'Upload your images, documents, or other files for inclusion in pages. Drag and drop the icons to move files between folders.';
 $string['filethingdeleted'] = '%s deleted';
 $string['filewithnameexists'] = 'A file or folder with the name "%s" already exists.';
 $string['folder'] = 'Folder';
 $string['Folder'] = 'Folder';
-$string['folderappearsinviews'] = 'This folder appears in one or more of your views.';
+$string['folderappearsinviews'] = 'This folder appears in one or more of your pages.';
 $string['Folders'] = 'Folders';
 $string['foldernotempty'] = 'This folder is not empty.';
 $string['foldercreated'] = 'Folder created';
@@ -88,6 +100,7 @@ $string['home'] = 'Home';
 $string['htmlremovedmessage'] = 'You are viewing <strong>%s</strong> by <a href="%s">%s</a>. The file displayed below has been filtered to remove malicious content, and is only a rough representation of the original.';
 $string['htmlremovedmessagenoowner'] = 'You are viewing <strong>%s</strong>. The file displayed below has been filtered to remove malicious content, and is only a rough representation of the original.';
 $string['image'] = 'Image';
+$string['Images'] = 'Images';
 $string['lastmodified'] = 'Last Modified';
 $string['myfiles'] = 'My Files';
 $string['Name'] = 'Name';
@@ -98,6 +111,7 @@ $string['movefaileddestinationnotfolder'] = 'You can only move files into folder
 $string['movefailednotfileartefact'] = 'Only file, folder and image artefacts can be moved.';
 $string['movefailednotowner'] = 'You do not have permission to move the file into this folder';
 $string['movefailed'] = 'Move failed.';
+$string['movingfailed'] = 'Moving failed: file or folder does not exist any more';
 $string['nametoolong'] = 'That name is too long.  Please choose a shorter one.';
 $string['nofilesfound'] = 'No files found';
 $string['notpublishable'] = 'You do not have permission to publish this file';
@@ -106,8 +120,10 @@ $string['Owner'] = 'Owner';
 $string['parentfolder'] = 'Parent folder';
 $string['Preview'] = 'Preview';
 $string['requireagreement'] = 'Require Agreement';
+$string['removingfailed'] = 'Removing failed: file or folder does not exist any more';
 $string['savechanges'] = 'Save changes';
 $string['selectafile'] = 'Select a file';
+$string['selectingfailed'] = 'Selecting failed: file or folder does not exist any more';
 $string['Size'] = 'Size';
 $string['spaceused'] = 'Space used';
 $string['timeouterror'] = 'File upload failed: try uploading the file again';
@@ -188,30 +204,30 @@ $string['rm'] = 'RM Real Player Movie';
 
 
 // Profile icons
-$string['cantcreatetempprofileiconfile'] = 'Could not write temporary profile icon image in %s';
-$string['profileiconsize'] = 'Profile Icon Size';
-$string['profileicons'] = 'Profile Icons';
+$string['cantcreatetempprofileiconfile'] = 'Could not write temporary profile picture image in %s';
+$string['profileiconsize'] = 'Profile Picture Size';
+$string['profileicons'] = 'Profile Pictures';
 $string['Default'] = 'Default';
-$string['deleteselectedicons'] = 'Delete selected icons';
-$string['profileicon'] = 'Profile Icon';
+$string['deleteselectedicons'] = 'Delete selected Profile Pictures';
+$string['profileicon'] = 'Profile Pictures';
 $string['noimagesfound'] = 'No images found';
-$string['uploadedprofileiconsuccessfully'] = 'Uploaded new profile icon successfully';
-$string['profileiconsetdefaultnotvalid'] = 'Could not set the default profile icon, the choice was not valid';
-$string['profileiconsdefaultsetsuccessfully'] = 'Default profile icon set successfully';
-$string['profileiconsdeletedsuccessfully'] = 'Profile icon(s) deleted successfully';
-$string['profileiconsnoneselected'] = 'No profile icons were selected to be deleted';
-$string['onlyfiveprofileicons'] = 'You may upload only five profile icons';
+$string['uploadedprofileiconsuccessfully'] = 'Uploaded new profile picture successfully';
+$string['profileiconsetdefaultnotvalid'] = 'Could not set the default profile picture, the choice was not valid';
+$string['profileiconsdefaultsetsuccessfully'] = 'Default profile picture set successfully';
+$string['profileiconsdeletedsuccessfully'] = 'Profile picture(s) deleted successfully';
+$string['profileiconsnoneselected'] = 'No profile pictures were selected to be deleted';
+$string['onlyfiveprofileicons'] = 'You may upload only five profile pictures';
 $string['or'] = 'or';
-$string['profileiconuploadexceedsquota'] = 'Uploading this profile icon would exceed your disk quota. Try deleting some files you have uploaded';
-$string['profileiconimagetoobig'] = 'The image you uploaded was too big (%sx%s pixels). It must not be larger than %sx%s pixels';
+$string['profileiconuploadexceedsquota'] = 'Uploading this profile picture would exceed your disk quota. Try deleting some files you have uploaded';
+$string['profileiconimagetoobig'] = 'The picture you uploaded was too big (%sx%s pixels). It must not be larger than %sx%s pixels';
 $string['uploadingfile'] = 'uploading file...';
-$string['uploadprofileicon'] = 'Upload Profile Icon';
-$string['profileiconsiconsizenotice'] = 'You may upload up to <strong>five</strong> profile icons here, and choose one to be displayed as your default icon at any one time. Your icons must be between 16x16 and %sx%s pixels in size.';
+$string['uploadprofileicon'] = 'Upload Profile Picture';
+$string['profileiconsiconsizenotice'] = 'You may upload up to <strong>five</strong> profile pictures here, and choose one to be displayed as your default icon at any one time. Your icons must be between 16x16 and %sx%s pixels in size.';
 $string['setdefault'] = 'Set Default';
 $string['Title'] = 'Title';
 $string['imagetitle'] = 'Image Title';
 $string['usenodefault'] = 'Use no default';
-$string['usingnodefaultprofileicon'] = 'Now using no default profile icon';
+$string['usingnodefaultprofileicon'] = 'Now using no default profile picture';
 $string['wrongfiletypeforblock'] = 'The file you uploaded was not the correct type for this block.';
 
 // Unzip
@@ -227,4 +243,8 @@ $string['pleasewaitwhileyourfilesarebeingunzipped'] = 'Please wait while your fi
 $string['spacerequired'] = 'Space Required';
 $string['Unzip'] = 'Unzip';
 $string['unzipprogress'] = '%s files/folders created.';
-?>
+
+// Group file permissions
+$string['filepermission.view'] = 'View';
+$string['filepermission.edit'] = 'Edit';
+$string['filepermission.republish'] = 'Publish';
