@@ -49,17 +49,17 @@ class PluginArtefactFile extends PluginArtefact {
 
     public static function menu_items() {
         return array(
-            array(
-                'path' => 'myportfolio/files',
+            'content/files' => array(
+                'path' => 'content/files',
                 'url' => 'artefact/file/',
-                'title' => get_string('myfiles', 'artefact.file'),
-                'weight' => 20,
+                'title' => get_string('Files', 'artefact.file'),
+                'weight' => 30,
             ),
-            array(
-                'path' => 'profile/icons',
+            'content/profileicons' => array(
+                'path' => 'content/profileicons',
                 'url' => 'artefact/file/profileicons.php',
                 'title' => get_string('profileicons', 'artefact.file'),
-                'weight' => 11,
+                'weight' => 20,
             ),
         );
     }
@@ -70,7 +70,7 @@ class PluginArtefactFile extends PluginArtefact {
                 'path' => 'groups/files',
                 'url' => 'artefact/file/groupfiles.php?group='.$groupid,
                 'title' => get_string('Files', 'artefact.file'),
-                'weight' => 60,
+                'weight' => 70,
             ),
         );
     }
@@ -90,13 +90,13 @@ class PluginArtefactFile extends PluginArtefact {
     public static function postinst($prevversion) {
         if ($prevversion == 0) {
             set_config_plugin('artefact', 'file', 'defaultquota', 52428800);
-            set_config_plugin('artefact', 'file', 'uploadagreement', 1);
         }
+        set_config_plugin('artefact', 'file', 'commentsallowedimage', 1);
         self::resync_filetype_list();
     }
 
     public static function newuser($event, $user) {
-        if (empty($user->quota)) {
+        if (empty($user['quota'])) {
             update_record('usr', array('quota' => get_config_plugin('artefact', 'file', 'defaultquota')), array('id' => $user['id']));
         }
     }
@@ -130,8 +130,10 @@ class PluginArtefactFile extends PluginArtefact {
                     'folderappearsinviews',
                     'foldernamerequired',
                     'foldernotempty',
+                    'maxuploadsize',
                     'nametoolong',
                     'namefieldisrequired',
+                    'upload',
                     'uploadingfiletofolder',
                     'youmustagreetothecopyrightnotice',
                 ),
@@ -164,13 +166,14 @@ class PluginArtefactFile extends PluginArtefact {
     function resync_filetype_list() {
         require_once('xmlize.php');
         db_begin();
-        log_info('Beginning resync of filetype list');
 
         $currentlist = get_records_assoc('artefact_file_mime_types');
         $newlist     = xmlize(file_get_contents(get_config('docroot') . 'artefact/file/filetypes.xml'));
         $filetypes   = $newlist['filetypes']['#']['filetype'];
         $newtypes    = array();
 
+        $count = array('added' => 0, 'updated' => 0, 'removed' => 0);
+
         // Step one: if a mimetype is in the new list that is not in the current
         // list, add it to the current list.
         foreach ($filetypes as $filetype) {
@@ -178,12 +181,12 @@ class PluginArtefactFile extends PluginArtefact {
             foreach ($filetype['#']['mimetypes'][0]['#']['mimetype'] as $type) {
                 $mimetype = $type['#'];
                 if (!isset($currentlist[$mimetype])) {
-                    log_debug('Adding mimetype: ' . $mimetype . ' (' . $description . ')');
                     execute_sql("INSERT INTO {artefact_file_mime_types} (mimetype, description) VALUES (?,?)", array($mimetype, $description));
+                    $count['added']++;
                 }
                 else if ($currentlist[$mimetype]->description != $description) {
-                    log_debug('Updating mimetype: ' . $mimetype . ' (' . $description . ')');
                     execute_sql("UPDATE {artefact_file_mime_types} SET description = ? WHERE mimetype = ?", array($description, $mimetype));
+                    $count['updated']++;
                 }
                 $newtypes[$mimetype] = true;
                 $currentlist[$mimetype] = (object) array(
@@ -197,12 +200,19 @@ class PluginArtefactFile extends PluginArtefact {
         // new list, remove it from the current list.
         foreach ($currentlist as $mimetype => $type) {
             if (!isset($newtypes[$mimetype])) {
-                log_debug('Removing mimetype: ' . $mimetype);
                 delete_records('artefact_file_mime_types', 'mimetype', $mimetype);
+                $count['removed']++;
             }
         }
        
         db_commit();
+        $changes = array();
+        foreach (array_filter($count) as $k => $v) {
+            $changes[] = "$v $k";
+        }
+        if ($changes) {
+            log_info('Updated filetype list: ' . join(', ', $changes) . '.');
+        }
     }
 
     public static function get_mimetypes_from_description($description=null) {
@@ -248,9 +258,9 @@ abstract class ArtefactTypeFileBase extends ArtefactType {
 
     public function __construct($id = 0, $data = null) {
         parent::__construct($id, $data);
-        
+
         if (empty($this->id)) {
-            $this->locked = 0;
+            $this->allowcomments = get_config_plugin('artefact', 'file', 'commentsallowed' . $this->artefacttype);
         }
     }
 
@@ -281,7 +291,7 @@ abstract class ArtefactTypeFileBase extends ArtefactType {
             LEFT OUTER JOIN {artefact_file_files} f ON f.artefact = a.id
             WHERE a.title = ?
             AND a.' . $ownersql . '
-            AND a.parent ' . (empty($folder) ? ' IS NULL' : ' = ' . $folder) . '
+            AND a.parent ' . (empty($folder) ? ' IS NULL' : ' = ' . (int)$folder) . '
             AND a.artefacttype IN ' . $filetypesql, array($title));
     }
 
@@ -308,7 +318,7 @@ abstract class ArtefactTypeFileBase extends ArtefactType {
         global $USER;
         $select = '
             SELECT
-                a.id, a.artefacttype, a.mtime, f.size, a.title, a.description,
+                a.id, a.artefacttype, a.mtime, f.size, a.title, a.description, a.locked, a.allowcomments,
                 COUNT(DISTINCT c.id) AS childcount, COUNT (DISTINCT aa.artefact) AS attachcount, COUNT(DISTINCT va.view) AS viewcount';
         $from = '
             FROM {artefact} a
@@ -333,7 +343,7 @@ abstract class ArtefactTypeFileBase extends ArtefactType {
 
         $groupby = '
             GROUP BY
-                a.id, a.artefacttype, a.mtime, f.size, a.title, a.description';
+                a.id, a.artefacttype, a.mtime, f.size, a.title, a.description, a.locked, a.allowcomments';
 
         $phvals = array();
 
@@ -392,6 +402,7 @@ abstract class ArtefactTypeFileBase extends ArtefactType {
             foreach ($filedata as $item) {
                 $item->mtime = format_date(strtotime($item->mtime), 'strfdaymonthyearshort');
                 $item->tags = array();
+                $item->allowcomments = (bool) $item->allowcomments;
                 $item->icon = call_static_method(generate_artefact_class_name($item->artefacttype), 'get_icon', array('id' => $item->id));
                 if ($item->size) { // Doing this here now for non-js users
                     $item->size = ArtefactTypeFile::short_size($item->size, true);
@@ -456,7 +467,8 @@ abstract class ArtefactTypeFileBase extends ArtefactType {
             'name'               => 'files',
             'jsform'             => true,
             'newiframeonsubmit'  => true,
-            'jssuccesscallback'  => 'files_success',
+            'jssuccesscallback'  => 'files_callback',
+            'jserrorcallback'    => 'files_callback',
             'renderer'           => 'oneline',
             'plugintype'         => 'artefact',
             'pluginname'         => 'file',
@@ -484,7 +496,7 @@ abstract class ArtefactTypeFileBase extends ArtefactType {
     }
 
     public static function files_js() {
-        return "function files_success(form, data) { files_filebrowser.success(form, data); }";
+        return "function files_callback(form, data) { files_filebrowser.callback(form, data); }";
     }
 
     public static function count_user_files($owner=null, $group=null, $institution=null) {
@@ -635,7 +647,7 @@ abstract class ArtefactTypeFileBase extends ArtefactType {
             $end = '';
         }
 
-        $where = $parent ? "parent = $parent" : 'parent IS NULL';
+        $where = ($parent && is_int($parent)) ? "parent = $parent" : 'parent IS NULL';
         $where .=  ' AND ' . artefact_owner_sql($owner, $group, $institution);
 
         $taken = get_column_sql("
@@ -709,10 +721,6 @@ class ArtefactTypeFile extends ArtefactTypeFileBase {
                 }
             }
         }
-
-        if (empty($this->id)) {
-            $this->container = 0;
-        }
     }
 
     /**
@@ -804,7 +812,17 @@ class ArtefactTypeFile extends ArtefactTypeFileBase {
         $size = filesize($pathname);
         $f = self::new_file($pathname, $data);
         $f->set('size', $size);
-        // @todo: Set mime type! (and old extension)
+
+        // sometimes the filetype is actually set, assume it is correct
+        if (empty($data->filetype)) {
+            $f->set('filetype', file_mime_type($pathname));
+        }
+
+        // if an extension has been provided (only from self::extract() at this stage), use it
+        if (!empty($data->extension)) {
+            $f->set('oldextension', $data->extension);
+        }
+
         $f->commit();
         $id = $f->get('id');
 
@@ -848,6 +866,7 @@ class ArtefactTypeFile extends ArtefactTypeFileBase {
             global $USER;
             if ($data->owner == $USER->get('id')) {
                 $owner = $USER;
+                $owner->quota_refresh();
             }
             else {
                 $owner = new User;
@@ -963,8 +982,6 @@ class ArtefactTypeFile extends ArtefactTypeFileBase {
             return; 
         }
         $file = $this->get_path();
-        // Detach this file from any view feedback
-        set_field('view_feedback', 'attachment', null, 'attachment', $this->id);
         if (is_file($file)) {
             $size = filesize($file);
             // Only delete the file on disk if no other artefacts point to it
@@ -981,6 +998,7 @@ class ArtefactTypeFile extends ArtefactTypeFileBase {
 
         delete_records('artefact_attachment', 'attachment', $this->id);
         delete_records('artefact_file_files', 'artefact', $this->id);
+        delete_records('site_menu', 'file', $this->id);
         parent::delete();
     }
 
@@ -991,7 +1009,7 @@ class ArtefactTypeFile extends ArtefactTypeFileBase {
             return;
         }
 
-        $idstr = join(',', $artefactids);
+        $idstr = join(',', array_map('intval', $artefactids));
 
         db_begin();
         // Get the size of all the files we're about to delete that belong to
@@ -1019,7 +1037,6 @@ class ArtefactTypeFile extends ArtefactTypeFileBase {
         // log deletion for all these files if at least one is group-owned.
         $log = (bool) count_records_select('artefact', 'id IN (' . $idstr . ') AND "group" IS NOT NULL');
 
-        set_field_select('view_feedback', 'attachment', null, 'attachment IN (' . $idstr . ')', array());
         delete_records_select('artefact_attachment', 'attachment IN (' . $idstr . ')');
         delete_records_select('artefact_file_files', 'artefact IN (' . $idstr . ')');
         parent::bulk_delete($artefactids, $log);
@@ -1073,6 +1090,32 @@ class ArtefactTypeFile extends ArtefactTypeFileBase {
             'collapsible' => true
         );
 
+        $maxquota = get_config_plugin('artefact', 'file', 'maxquota');
+        $maxquotaenabled = get_config_plugin('artefact', 'file', 'maxquotaenabled');
+        if (empty($maxquota)) {
+            $maxquota = 1024 * 1024 * 1024;
+        }
+        $elements['maxquota'] = array(
+            'type' => 'fieldset',
+            'legend' => get_string('maxquota', 'artefact.file'),
+            'elements' => array(
+                'maxquotadescription' => array(
+                    'value' => '<tr><td colspan="2">' . get_string('maxquotadescription', 'artefact.file') . '</td></tr>'
+                ),
+                'maxquotaenabled' => array(
+                    'title'        => get_string('maxquotaenabled', 'artefact.file'),
+                    'type'         => 'checkbox',
+                    'defaultvalue' => $maxquotaenabled,
+                ),
+                'maxquota' => array(
+                    'title'        => get_string('maxquota', 'artefact.file'),
+                    'type'         => 'bytes',
+                    'defaultvalue' => $maxquota,
+                ),
+            ),
+            'collapsible' => true
+        );
+
         // Require user agreement before uploading files
         // Rework this when/if we provide translatable agreements
         $uploadagreement = get_config_plugin('artefact', 'file', 'uploadagreement');
@@ -1106,6 +1149,7 @@ class ArtefactTypeFile extends ArtefactTypeFileBase {
                     'rows'         => 10,
                     'cols'         => 80,
                     'defaultvalue' => get_field('site_content', 'content', 'name', 'uploadcopyright'),
+                    'rules'        => array('maxlength' => 65536),
                 ),
             ),
             'collapsible' => true
@@ -1145,15 +1189,47 @@ class ArtefactTypeFile extends ArtefactTypeFileBase {
             'collapsible' => true
         );
 
+        $commentdefaults = array();
+        foreach(PluginArtefactFile::get_artefact_types() as $at) {
+            $commentdefaults[] = array(
+                'title'        => get_string($at, 'artefact.file'),
+                'value'        => $at,
+                'defaultvalue' => get_config_plugin('artefact', 'file', 'commentsallowed' . $at),
+            );
+        }
+
+        $elements['comments'] = array(
+            'type'     => 'fieldset',
+            'legend'   => get_string('Comments', 'artefact.comment'),
+            'elements' => array(
+                'commentdefault' => array(
+                    'type'         => 'checkboxes',
+                    'title'        => get_string('artefactdefaultpermissions', 'artefact.comment'),
+                    'description'  => get_string('artefactdefaultpermissionsdescription', 'artefact.comment'),
+                    'elements'     => $commentdefaults,
+                ),
+            ),
+            'collapsible' => true,
+        );
+
         return array(
             'elements' => $elements,
             'renderer' => 'table'
         );
     }
 
+    public static function validate_config_options($form, $values) {
+        global $USER;
+        if ($values['maxquotaenabled'] && $values['maxquota'] < $values['defaultquota']) {
+            $form->set_error('maxquota', get_string('maxquotatoolow', 'artefact.file'));
+        }
+    }
+
     public static function save_config_options($values) {
         global $USER;
         set_config_plugin('artefact', 'file', 'defaultquota', $values['defaultquota']);
+        set_config_plugin('artefact', 'file', 'maxquota', $values['maxquota']);
+        set_config_plugin('artefact', 'file', 'maxquotaenabled', $values['maxquotaenabled']);
         set_config_plugin('artefact', 'file', 'profileiconwidth', $values['profileiconwidth']);
         set_config_plugin('artefact', 'file', 'profileiconheight', $values['profileiconheight']);
         set_config_plugin('artefact', 'file', 'uploadagreement', $values['uploadagreement']);
@@ -1163,7 +1239,15 @@ class ArtefactTypeFile extends ArtefactTypeFileBase {
         $data->content = $values['customagreement'];
         $data->mtime   = db_format_timestamp(time());
         $data->mauthor = $USER->get('id');
-        update_record('site_content', $data, 'name');
+        if (record_exists('site_content', 'name', $data->name)) {
+            update_record('site_content', $data, 'name');
+        }
+        else {
+            insert_record('site_content', $data);
+        }
+        foreach(PluginArtefactFile::get_artefact_types() as $at) {
+            set_config_plugin('artefact', 'file', 'commentsallowed' . $at, (int) in_array($at, $values['commentdefault']));
+        }
     }
 
     public static function short_size($bytes, $abbr=false) {
@@ -1353,7 +1437,7 @@ class ArtefactTypeFolder extends ArtefactTypeFileBase {
      * @param array $artefactstoignore A list of IDs to not consider as the given folder. See {@link default_parent_for_copy()}
      */
     public static function get_folder_by_name($name, $parentfolderid=null, $userid=null, $groupid=null, $institution=null, $artefactstoignore=array()) {
-        $parentclause = $parentfolderid ? 'parent = ' . $parentfolderid : 'parent IS NULL';
+        $parentclause = ($parentfolderid && is_int($parentfolderid)) ? 'parent = ' . $parentfolderid : 'parent IS NULL';
         $ownerclause = artefact_owner_sql($userid, $groupid, $institution);
         $ignoreclause = $artefactstoignore ? ' AND id NOT IN(' . implode(', ', array_map('db_quote', $artefactstoignore)) . ')' : '';
         return get_record_sql('SELECT * FROM {artefact}
@@ -1464,6 +1548,7 @@ class ArtefactTypeImage extends ArtefactTypeFile {
                 }
             }
         }
+
     }
 
     /**
@@ -1542,16 +1627,32 @@ class ArtefactTypeImage extends ArtefactTypeFile {
             return;
         }
         db_begin();
-        delete_records_select('artefact_file_image', 'artefact IN (' . join(',', $artefactids) . ')');
+        delete_records_select('artefact_file_image', 'artefact IN (' . join(',', array_map('intval', $artefactids)) . ')');
         parent::bulk_delete($artefactids);
         db_commit();
     }
 
     public function render_self($options) {
+        $downloadpath = get_config('wwwroot') . 'artefact/file/download.php?file=' . $this->id;
+        $url = get_config('wwwroot') . 'view/artefact.php?artefact=' . $this->id;
+        if (isset($options['viewid'])) {
+            $downloadpath .= '&view=' . $options['viewid'];
+            $url .= '&view=' . $options['viewid'];
+        }
+        $metadataurl = $url . '&details=1';
+        if (empty($options['metadata'])) {
+            $smarty = smarty_core();
+            $smarty->assign('id', $this->id);
+            $smarty->assign('title', $this->get('title'));
+            $smarty->assign('description', $this->get('description'));
+            $smarty->assign('downloadpath', $downloadpath);
+            $smarty->assign('metadataurl', $metadataurl);
+            return array('html' => $smarty->fetch('artefact:file:image_render_self.tpl'), 'javascript' => '');
+        }
         $result = parent::render_self($options);
-        $result['html'] = '<div class="fr filedata-icon" style="text-align: center;"><h4>' . get_string('Preview', 'artefact.file') . '</h4><a href="'
-            . hsc(get_config('wwwroot') . 'artefact/file/download.php?file=' . $this->id . '&view=' . (isset($options['viewid']) ? $options['viewid'] : 0)) . '"><img src="'
-            . hsc(get_config('wwwroot') . 'artefact/file/download.php?file=' . $this->id . '&view=' . (isset($options['viewid']) ? $options['viewid']  : 0). '&maxwidth=400&maxheight=180')
+        $result['html'] = '<div class="fl filedata-icon"><h4>'
+            . get_string('Preview', 'artefact.file') . '</h4><a href="'
+            . hsc($url) . '"><img src="' . hsc($downloadpath) . '&maxwidth=400&maxheight=180'
             . '" alt=""></a></div>' . $result['html'];
         return $result;
     }
@@ -1859,6 +1960,10 @@ class ArtefactTypeArchive extends ArtefactTypeFile {
                 $folder = dirname($name);
                 $this->data['template']->parent = $this->data['folderids'][$folder];
                 $this->data['template']->title = basename($name);
+
+                // set the file extension for later use (eg by flowplayer)
+                $this->data['template']->extension = pathinfo($this->data['template']->title, PATHINFO_EXTENSION);
+
                 if (substr($name, -1) == '/') {
                     $this->create_folder($folder);
                 }
@@ -1892,6 +1997,7 @@ class ArtefactTypeArchive extends ArtefactTypeFile {
                         if (!isset($this->data['folderids'][$child])) {
                             $this->data['template']->parent = $this->data['folderids'][$parent];
                             $this->data['template']->title = $path[$i];
+
                             $this->create_folder($parent);
                         }
                         $parent = $child;
@@ -1900,6 +2006,10 @@ class ArtefactTypeArchive extends ArtefactTypeFile {
 
                 $this->data['template']->parent = $this->data['folderids'][$folder];
                 $this->data['template']->title = basename($name);
+
+                // set the file extension for later use (eg by flowplayer)
+                $this->data['template']->extension = pathinfo($this->data['template']->title, PATHINFO_EXTENSION);
+
                 if (substr($name, -1) == '/') {
                     $this->create_folder($folder);
                 }
@@ -1922,5 +2032,3 @@ class ArtefactTypeArchive extends ArtefactTypeFile {
     }
 
 }
-
-?>
