@@ -59,7 +59,7 @@ class PluginBlocktypeProfileinfo extends PluginBlocktype {
             foreach ($configdata['artefactids'] as $id) {
                 try {
                     $artefact = artefact_instance_from_id($id);
-                    if ($artefact->get('owner') == $viewowner) {
+                    if (is_a($artefact, 'ArtefactTypeProfile') && $artefact->get('owner') == $viewowner) {
                         $rendered = $artefact->render_self(array('link' => true));
                         $data[$artefact->get('artefacttype')] = $rendered['html'];
                     }
@@ -129,7 +129,7 @@ class PluginBlocktypeProfileinfo extends PluginBlocktype {
             FROM {artefact} a
             WHERE (artefacttype = \'profileicon\' OR artefacttype = \'email\')
             AND a.owner = (
-                SELECT owner
+                SELECT "owner"
                 FROM {view}
                 WHERE id = ?
             )
@@ -191,6 +191,7 @@ class PluginBlocktypeProfileinfo extends PluginBlocktype {
             'defaultvalue' => (isset($configdata['introtext'])) ? $configdata['introtext'] : '',
             'width' => '100%',
             'height' => '150px',
+            'rules' => array('maxlength' => 65536),
         );
 
         return $form;
@@ -225,8 +226,8 @@ class PluginBlocktypeProfileinfo extends PluginBlocktype {
         if ($view->get('owner') !== null) {
             $artefacttypes = array_diff(PluginArtefactInternal::get_artefact_types(), array('email'));
             $artefactids = get_column_sql('
-                SELECT id FROM {artefact}
-                WHERE owner = ? AND artefacttype IN (' . join(',', array_map('db_quote', $artefacttypes)) . ')', array($view->get('owner')));
+                SELECT a.id FROM {artefact} a
+                WHERE a.owner = ? AND a.artefacttype IN (' . join(',', array_map('db_quote', $artefacttypes)) . ')', array($view->get('owner')));
             $configdata['artefactids'] = $artefactids;
             if (isset($configdata['email'])) {
                 if ($newemail = get_field('artefact_internal_profile_email', 'artefact', 'principal', 1, 'owner', $view->get('owner'))) {
@@ -259,7 +260,7 @@ class PluginBlocktypeProfileinfo extends PluginBlocktype {
      * Overrides the default implementation so we can export enough information
      * to reconstitute profile information again.
      *
-     * LEAP2A export doesn't export profile related artefacts as entries, so we
+     * Leap2A export doesn't export profile related artefacts as entries, so we
      * need to take that into account when exporting config for it.
      */
     public static function export_blockinstance_config_leap(BlockInstance $bi) {
@@ -275,5 +276,3 @@ class PluginBlocktypeProfileinfo extends PluginBlocktype {
     }
 
 }
-
-?>
