@@ -1,3 +1,26 @@
+/**
+ * Javascript for the profile form
+ * @source: http://gitorious.org/mahara/mahara
+ *
+ * @licstart
+ * Copyright (C) 2006-2010  Catalyst IT Ltd
+ *
+ * The JavaScript code in this page is free software: you can
+ * redistribute it and/or modify it under the terms of the GNU
+ * General Public License (GNU GPL) as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option)
+ * any later version.  The code is distributed WITHOUT ANY WARRANTY;
+ * without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU GPL for more details.
+ *
+ * As additional permission under GNU GPL version 3 section 7, you
+ * may distribute non-source (e.g., minimized or compacted) forms of
+ * that code without the copy of the GNU GPL normally required by
+ * section 4, provided you include this license notice and a URL
+ * through which recipients can access the Corresponding Source.
+ * @licend
+ */
+
 // Stuff
 addLoadEvent(function() {
     var fieldsets = getElementsByTagAndClassName('fieldset', null, 'profileform');
@@ -7,7 +30,7 @@ addLoadEvent(function() {
 
     var tabs = [];
     forEach(legends, function(legend) {
-        var a = A({'href': ''}, legend.firstChild);
+        var a = A({'href': ''}, scrapeText(legend));
         legend.parentNode.tabLink = a;
         // Pieforms is unhelpful with legend/fieldset ids; get it from children
         var fsid = 'general';
@@ -75,14 +98,6 @@ addLoadEvent(function() {
         });
     });
 
-    connect('cancel_profileform_submit', 'onclick', function(e) {
-        if (formDirty) {
-            if (!confirm(get_string('loseyourchanges'))) {
-                e.stop();
-            }
-        }
-    });
-
     // Now unhide the profile form
     hideElement('profile-loading');
     $('profileform').style.position = 'static';
