@@ -30,14 +30,12 @@ defined('INTERNAL') || die();
 $string['pluginname'] = 'Profile';
 
 $string['profile'] = 'Profile';
-$string['myfiles'] = 'My Files';
 
 $string['mandatory'] = 'Mandatory';
 $string['public'] = 'Public';
 
 $string['aboutdescription'] = 'Enter your real first and last name here. If you want to show a different name to people in the system, put that name in as your display name.';
-$string['contactdescription'] = 'All of this information is private, unless you choose to put it in a view.';
-$string['messagingdescription'] = 'Like your contact information, this information is private.';
+$string['infoisprivate'] = 'This information is private until you include it in a page that is shared with others.';
 $string['viewmyprofile'] = 'View my profile';
 
 // profile categories
@@ -55,6 +53,7 @@ $string['studentid'] = 'Student ID';
 $string['preferredname'] = 'Display Name';
 $string['introduction'] = 'Introduction';
 $string['email'] = 'Email Address';
+$string['maildisabled'] = 'Email Disabled';
 $string['officialwebsite'] = 'Official Website Address';
 $string['personalwebsite'] = 'Personal Website Address';
 $string['blogaddress'] = 'Blog Address';
@@ -89,7 +88,11 @@ $string['emailvalidation_subject'] = 'Email validation';
 $string['emailvalidation_body'] = <<<EOF
 Hello %s,
 
-The email address %s has been added to your user account in Mahara. Please visit the link below to activate this address.
+You have added email address %s to your user account in Mahara. Please visit the link below to activate this address.
+
+%s
+
+If this email belongs to you but you have not requested adding it to your Mahara account, follow the link below to decline email activation.
 
 %s
 EOF;
@@ -100,15 +103,16 @@ $string['emailactivation'] = 'Email Activation';
 $string['emailactivationsucceeded'] = 'Email Activation Successful';
 $string['emailalreadyactivated'] = 'Email already activiated';
 $string['emailactivationfailed'] = 'Email Activation Failed';
+$string['emailactivationdeclined'] = 'Email Activation Declined Successfully';
 $string['verificationlinkexpired'] = 'Verification link expired';
 $string['invalidemailaddress'] = 'Invalid email address';
 $string['unvalidatedemailalreadytaken'] = 'The e-mail address you are trying to validate is already taken';
+$string['addbutton'] = 'Add';
 
 $string['emailingfailed'] = 'Profile saved, but emails were not sent to: %s';
 
 $string['loseyourchanges'] = 'Lose your changes?';
 
-$string['editprofile']  = 'Edit Profile';
 $string['Title'] = 'Title';
 
 $string['Created'] = 'Created';
@@ -124,5 +128,3 @@ $string['profileinformation'] = 'Profile Information';
 $string['profilepage'] = 'Profile Page';
 $string['viewprofilepage'] = 'View profile page';
 $string['viewallprofileinformation'] = 'View all profile information';
-
-?>
