@@ -92,16 +92,10 @@ class PluginArtefactInternal extends PluginArtefact {
 
     public static function menu_items() {
         return array(
-            array(
-                'path' => 'profile',
-                'url'  => 'artefact/internal/', // @todo possibly do path aliasing and dispatch?
-                'title' => get_string('profile', 'artefact.internal'),
-                'weight' => 20,
-            ),
-            array(
-                'path' => 'profile/edit',
+            'content/profile' => array(
+                'path' => 'content/profile',
                 'url' => 'artefact/internal/',
-                'title' => get_string('editprofile', 'artefact.internal'),
+                'title' => get_string('profile', 'artefact.internal'),
                 'weight' => 10,
             ),
         );
@@ -140,7 +134,7 @@ class PluginArtefactInternal extends PluginArtefact {
      * profileinfo and contactinfo blocktypes. See the blocktypes'
      * export_blockinstance_config_leap method for more information.
      *
-     * LEAP2A export doesn't export profile related artefacts as entries, so we
+     * Leap2A export doesn't export profile related artefacts as entries, so we
      * need to take that into account when exporting config for it.
      *
      * @param BlockInstance $bi The blockinstance to export the config for.
@@ -158,7 +152,7 @@ class PluginArtefactInternal extends PluginArtefact {
         if (!isset($cache[$owner])) {
             $cache[$owner] = get_records_sql_assoc("SELECT id, artefacttype, title
                 FROM {artefact}
-                WHERE owner = ?
+                WHERE \"owner\" = ?
                 AND artefacttype IN (
                     SELECT name
                     FROM {artefact_installed_type}
@@ -179,7 +173,7 @@ class PluginArtefactInternal extends PluginArtefact {
                 $result['fields'] = json_encode(array($result['fields']));
             }
 
-            // Email addresses are not entries in leap2a (they're elements on
+            // Email addresses are not entries in Leap2A (they're elements on
             // the persondata element), so we export the actual address here
             // instead of an artefact ID.
             if (!empty($configdata['email']) && isset($cache[$owner][$configdata['email']])) {
@@ -226,7 +220,7 @@ class PluginArtefactInternal extends PluginArtefact {
                     if (!isset($cache[$owner])) {
                         $cache[$owner] = get_records_sql_assoc("SELECT artefacttype, id
                             FROM {artefact}
-                            WHERE owner = ?
+                            WHERE \"owner\" = ?
                             AND artefacttype IN (
                                 SELECT name
                                 FROM {artefact_installed_type}
@@ -234,7 +228,9 @@ class PluginArtefactInternal extends PluginArtefact {
                         )", array($owner));
                     }
 
-                    $configdata['artefactids'][] = $cache[$owner][$field]->id;
+                    if (isset($cache[$owner][$field])) {
+                        $configdata['artefactids'][] = $cache[$owner][$field]->id;
+                    }
                 }
             }
 
@@ -342,6 +338,16 @@ class ArtefactTypeProfile extends ArtefactType {
             'jabberusername'  => 'text',
             'occupation'      => 'text',
             'industry'        => 'text',
+            'maildisabled'    => 'html',
+        );
+    }
+
+    public static function get_field_element_data() {
+        return array(
+            'firstname'       => array('rules' => array('maxlength' => 50)),
+            'lastname'        => array('rules' => array('maxlength' => 50)),
+            'studentid'       => array('rules' => array('maxlength' => 50)),
+            'preferredname'   => array('rules' => array('maxlength' => 50)),
         );
     }
 
@@ -561,6 +567,19 @@ class ArtefactTypeEmail extends ArtefactTypeProfileField {
         parent::delete();
     }
 
+    public static function bulk_delete($artefactids) {
+        if (empty($artefactids)) {
+            return;
+        }
+
+        $idstr = join(',', array_map('intval', $artefactids));
+
+        db_begin();
+        delete_records_select('artefact_internal_profile_email', 'artefact IN (' . $idstr . ')');
+        parent::bulk_delete($artefactids);
+        db_commit();
+    }
+
     public function render_self($options) {
         if (array_key_exists('link', $options) && $options['link'] == true) {
             $html = '<a href="mailto:' . hsc($this->title) . '">' . hsc($this->title) . '</a>';
@@ -601,7 +620,11 @@ class ArtefactTypeWebAddress extends ArtefactTypeProfileField {
 class ArtefactTypeOfficialwebsite extends ArtefactTypeWebAddress {}
 class ArtefactTypePersonalwebsite extends ArtefactTypeWebAddress {}
 class ArtefactTypeBlogAddress extends ArtefactTypeWebAddress {}
-class ArtefactTypeAddress extends ArtefactTypeProfileField {}
+class ArtefactTypeAddress extends ArtefactTypeProfileField {
+    public function render_self($options) {
+        return array('html' => format_whitespace($this->title), 'javascript' => null);
+    }
+}
 class ArtefactTypeTown extends ArtefactTypeProfileField {}
 class ArtefactTypeCity extends ArtefactTypeProfileField {}
 class ArtefactTypeCountry extends ArtefactTypeProfileField {
@@ -623,7 +646,3 @@ class ArtefactTypeSkypeusername extends ArtefactTypeProfileField {}
 class ArtefactTypeJabberusername extends ArtefactTypeProfileField {}
 class ArtefactTypeOccupation extends ArtefactTypeProfileField {}
 class ArtefactTypeIndustry extends ArtefactTypeProfileField {}
-
-
-
-?>
