@@ -133,6 +133,10 @@ abstract class ArtefactType {
     protected $tags = array();
     protected $institution;
     protected $group;
+    protected $author;
+    protected $authorname;
+    protected $allowcomments;
+    protected $approvecomments;
     protected $rolepermissions;
     protected $mtimemanuallyset;
 
@@ -370,10 +374,6 @@ abstract class ArtefactType {
         }
     }
     
-    public function is_container() {
-        return false;
-    }
-
     /** 
      * This method updates the contents of the artefact table only.  If your
      * artefact has extra information in other tables, you need to override
@@ -384,6 +384,10 @@ abstract class ArtefactType {
             return;
         }
 
+        if (empty($this->author) && empty($this->authorname)) {
+            $this->set_author();
+        }
+
         db_begin();
 
         $fordb = new StdClass;
@@ -475,6 +479,10 @@ abstract class ArtefactType {
       
         db_begin();
 
+        // Call delete() on comments (if there are any)
+        safe_require('artefact', 'comment');
+        ArtefactTypeComment::delete_comments_onartefacts(array($this->id));
+
         // Call delete() on children (if there are any)
         if ($children = $this->get_children_instances()) {
             foreach ($children as $child) {
@@ -515,9 +523,13 @@ abstract class ArtefactType {
 
         artefact_watchlist_notification($artefactids);
 
+        // Delete comments first
+        safe_require('artefact', 'comment');
+        ArtefactTypeComment::delete_comments_onartefacts($artefactids);
+
         $records = get_records_select_assoc(
             'artefact',
-            'id IN (' . join(',', $artefactids) . ')',
+            'id IN (' . join(',', array_map('intval', $artefactids)) . ')',
             null, 'artefacttype', 'id,parent,artefacttype,container'
         );
 
@@ -525,7 +537,7 @@ abstract class ArtefactType {
         $leaves = array();
         foreach ($records as $r) {
             if ($r->container) {
-                $containers[$r->artefacttype][] = $r->id;
+                $containers[$r->artefacttype][] = (int)$r->id;
             }
             else {
                 $leaves[$r->artefacttype][] = $r->id;
@@ -588,10 +600,13 @@ abstract class ArtefactType {
             return;
         }
 
-        $idstr = '(' . join(',', $artefactids) . ')';
+        $idstr = '(' . join(',', array_map('intval', $artefactids)) . ')';
 
         db_begin();
 
+        // Detach any files from this artefact
+        delete_records_select('artefact_attachment', "artefact IN $idstr");
+
         // Delete any references to these artefacts from non-artefact places.
         delete_records_select('artefact_parent_cache', "artefact IN $idstr");
 
@@ -609,7 +624,6 @@ abstract class ArtefactType {
             BlockInstance::bulk_delete_artefacts($records);
         }
         delete_records_select('view_artefact', "artefact IN $idstr");
-        delete_records_select('artefact_feedback', "artefact IN $idstr");
         delete_records_select('artefact_tag', "artefact IN $idstr");
         delete_records_select('artefact_access_role', "artefact IN $idstr");
         delete_records_select('artefact_access_usr', "artefact IN $idstr");
@@ -619,6 +633,21 @@ abstract class ArtefactType {
         db_commit();
     }
 
+
+    /**
+     * Initialise artefact author to either the artefact owner, the
+     * logged-in user, or the system user.
+     */
+    private function set_author() {
+        global $USER;
+        if (isset($this->owner)) {
+            $this->author = $this->owner;
+        }
+        else {
+            $this->author = $USER->get('id');
+        }
+    }
+
     /**
     * this function provides the way to link to viewing very deeply nested artefacts
     * within a view
@@ -635,16 +664,6 @@ abstract class ArtefactType {
     }
 
 
-    /**
-     * By default public feedback can be placed on all artefacts.
-     * Artefact types which don't want to allow public feedback should
-     * redefine this function.
-     */
-    public function public_feedback_allowed() {
-        return true;
-    }
-
-
     /**
      * By default users are notified of all feedback on artefacts
      * which they own.  Artefact types which want to allow this
@@ -655,6 +674,21 @@ abstract class ArtefactType {
     }
 
 
+    /**
+     * A dummy method, giving graceful output, if this method is not implemented in the relevant child class
+     */
+    public function render_self($options) {
+        $smarty = smarty();
+        $smarty->assign('viewtitle', $this->get('title'));
+        $smarty->assign('viewdescription', $this->get('description'));
+
+        return array(
+            'html' => $smarty->fetch('view/viewcontent.tpl'),
+            'javascript'=>''
+        );
+    }
+
+
     /**
      * Returns a URL for an icon for the appropriate artefact
      *
@@ -687,13 +721,6 @@ abstract class ArtefactType {
      */
     public static abstract function is_singular();
 
-    /**
-     * Whether the 'note' field is for the artefact's private use
-     */
-    public static function is_note_private() {
-        return false;
-    }
-
     /**
      * Returns a list of key => value pairs where the key is either '_default'
      * or a langauge string, and value is a URL linking to that behaviour for
@@ -970,18 +997,36 @@ abstract class ArtefactType {
         if (empty($artefactids)) {
             return array();
         }
+        // @todo: Join on artefact_file_files shouldn't happen below.
+        // We could either assume all attachments are files and then
+        // move all these attachment functions to the artefact file
+        // plugin, or we could allow artefact plugins to add stuff
+        // to this query.
         $attachments = get_records_sql_array('
             SELECT
-                aa.artefact, aa.attachment, a.artefacttype, a.title, a.description
+                aa.artefact, aa.attachment, a.artefacttype, a.title, a.description, f.size
             FROM {artefact_attachment} aa
                 INNER JOIN {artefact} a ON aa.attachment = a.id
-            WHERE aa.artefact IN (' . join(', ', $artefactids) . ')', '');
+                LEFT JOIN {artefact_file_files} f ON a.id = f.artefact
+            WHERE aa.artefact IN (' . join(', ', array_map('intval', $artefactids)) . ')', '');
         if (!$attachments) {
             return array();
         }
         return $attachments;
     }
 
+    public function tags_from_id_list($artefactids) {
+        if (empty($artefactids)) {
+            return array();
+        }
+        $artefactids = join(',', array_map('intval', $artefactids));
+        $tags = get_records_select_array('artefact_tag', 'artefact IN (' . $artefactids . ')');
+        if (!$tags) {
+            return array();
+        }
+        return $tags;
+    }
+
     public function get_attachments($assoc=false) {
         $list = get_records_sql_assoc('SELECT a.id, a.artefacttype, a.title, a.description 
             FROM {artefact_attachment} aa
@@ -1017,6 +1062,9 @@ abstract class ArtefactType {
         if (record_exists('artefact_attachment', 'artefact', $this->get('id'), 'attachment', $attachmentid)) {
             return;
         }
+        if (!record_exists('artefact', 'id', $attachmentid)) {
+            throw new ArtefactNotFoundException(get_string('artefactnotfound', 'mahara', $attachmentid));
+        }
         $data = new StdClass;
         $data->artefact = $this->get('id');
         $data->attachment = $attachmentid;
@@ -1054,6 +1102,9 @@ abstract class ArtefactType {
             delete_records('artefact_attachment', 'artefact', $this->id);
             return;
         }
+        if (!record_exists('artefact', 'id', $attachmentid)) {
+            throw new ArtefactNotFoundException(get_string('artefactnotfound', 'mahara', $attachmentid));
+        }
         delete_records('artefact_attachment', 'artefact', $this->get('id'), 'attachment', $attachmentid);
         delete_records('artefact_parent_cache', 'parent', $this->get('id'), 'artefact', $attachmentid);
         if ($this->get('parent')) {
@@ -1067,53 +1118,48 @@ abstract class ArtefactType {
         return get_column('artefact_attachment', 'artefact', 'attachment', $attachmentid);
     }
 
-    public function get_feedback($limit=10, $offset=0, $viewid, $lastpage=false) {
-        global $USER;
-        $userid = $USER->get('id');
-        $artefactid = $this->id;
-        $canedit = $USER->can_edit_artefact($this);
-
-        $count = count_records_sql('
-            SELECT COUNT(*)
-            FROM {artefact_feedback}
-            WHERE view = ' . $viewid . ' AND artefact = ' . $artefactid
-                . (!$canedit ? ' AND (public = 1 OR author = ' . $userid . ')' : ''));
-        if ($lastpage) { // Ignore $offset and just get the last page of feedback
-            $offset = (ceil($count / $limit) - 1) * $limit;
-        }
-        $feedback = get_records_sql_array('
-            SELECT
-                id, author, authorname, ctime, message, public
-            FROM {artefact_feedback}
-            WHERE view = ' . $viewid . ' AND artefact = ' . $artefactid
-                . (!$canedit ? ' AND (public = 1 OR author = ' . $userid . ')' : '') . '
-            ORDER BY id', '', $offset, $limit);
-        if ($feedback) {
-            require_once(get_config('libroot') . 'view.php');
-            require_once(get_config('libroot') . 'pieforms/pieform.php');
-            foreach ($feedback as &$f) {
-                if ($f->public && $canedit) {
-                    $f->pubmessage = get_string('thisfeedbackispublic', 'view');
-                    $f->makeprivateform = pieform(make_private_form($f->id));
-                }
-                else if (!$f->public) {
-                    $f->pubmessage = get_string('thisfeedbackisprivate', 'view');
-                }
-            }
-        }
-        return (object) array(
-            'count'    => $count,
-            'limit'    => $limit,
-            'offset'   => $offset,
-            'lastpage' => $lastpage,
-            'data'     => $feedback ? $feedback : array(),
-            'view'     => $viewid,
-            'artefact' => $artefactid,
-            'canedit'  => $canedit,
-            'isowner'  => $userid && $userid == $this->get('owner'),
-        );
+    public function exportable() {
+        return true;
     }
 
+    // Update the locked field on a user's artefacts
+    // Lock anything in a submitted view, and unlock anything that isn't
+    public static function update_locked($userid) {
+        if (empty($userid)) {
+            return;
+        }
+        $submitted = get_column_sql('
+            SELECT a.id
+            FROM {artefact} a
+                JOIN {view_artefact} va ON a.id = va.artefact
+                JOIN {view} v ON va.view = v.id
+            WHERE a.owner = ?
+                AND v.owner = ?
+                AND (v.submittedgroup IS NOT NULL OR v.submittedhost IS NOT NULL)',
+            array($userid, $userid)
+        );
+        if ($submitted) {
+            $submitted = artefact_get_descendants($submitted);
+            if ($attachments = get_column_sql('
+                SELECT attachment FROM {artefact_attachment}
+                WHERE artefact IN (' . join(',', $submitted) . ')',
+                array())) {
+                $submitted = array_merge($submitted, $attachments);
+            }
+        }
+        db_begin();
+        if (!empty($submitted)) {
+            $idstr = '(' . join(',', $submitted) . ')';
+            set_field_select('artefact', 'locked', 1, "locked = 0 AND id IN $idstr", array());
+        }
+        // Unlock
+        $select = 'locked = 1 AND "owner" = ?';
+        if (isset($idstr)) {
+            $select .= " AND NOT id IN $idstr";
+        }
+        set_field_select('artefact', 'locked', 0, $select, array($userid));
+        db_commit();
+    }
 }
 
 /**
@@ -1149,7 +1195,7 @@ function artefact_check_plugin_sanity($pluginname) {
     }
     $types = call_static_method($classname, 'get_block_types');
     foreach ($types as $type) {
-        $pluginclassname = generate_class_name('blocktype', 'image');
+        $pluginclassname = generate_class_name('blocktype', $type);
         if (get_config('installed')) {
             if (table_exists(new XMLDBTable('blocktype_installed')) && $taken = get_record_select('blocktype_installed', 
                 'name = ? AND artefactplugin != ? ',
@@ -1198,15 +1244,46 @@ function rebuild_artefact_parent_cache_dirty() {
 function rebuild_artefact_parent_cache_complete() {
     db_begin();
     delete_records('artefact_parent_cache');
-    if ($artefactids = get_column('artefact', 'id')) {
-        foreach ($artefactids as $id) {
-            $parentids = array_keys(artefact_get_parents_for_cache($id));
-            foreach ($parentids as $p) {
-                $apc = new StdClass;
-                $apc->artefact = $id;
-                $apc->parent   = $p;
-                $apc->dirty    = 0;
-                insert_record('artefact_parent_cache', $apc);
+
+    $artefacts = get_records_sql_assoc('
+        SELECT id, parent, COUNT(aa.artefact) AS attached
+        FROM {artefact} a LEFT JOIN {artefact_attachment} aa ON a.id = aa.attachment
+        GROUP BY id, parent
+        HAVING parent IS NOT NULL OR COUNT(aa.artefact) > 0',
+        array()
+    );
+
+    if ($artefacts) {
+
+        foreach ($artefacts as &$artefact) {
+
+            // Nothing that can be a parent can be an attachment, so it's good
+            // enough to first get everything this artefact is attached to, and
+            // then find all its ancestors and the ancestors of everything it's
+            // attached to.
+
+            $ancestors = array();
+            if ($artefact->attached) {
+                $ancestors = get_column('artefact_attachment', 'artefact', 'attachment', $artefact->id);
+            }
+
+            $tocheck = $ancestors;
+            $tocheck[] = $artefact->id;
+
+            foreach ($tocheck as $id) {
+                $p = isset($artefacts[$id]) ? $artefacts[$id]->parent : null;
+                while (!empty($p)) {
+                    $ancestors[] = $p;
+                    $p = isset($artefacts[$p]) ? $artefacts[$p]->parent : null;
+                }
+            }
+
+            foreach (array_unique($ancestors) as $p) {
+                insert_record('artefact_parent_cache', (object) array(
+                    'artefact' => $artefact->id,
+                    'parent'   => $p,
+                    'dirty'    => 0,
+                ));
             }
         }
     }
@@ -1232,7 +1309,7 @@ function artefact_get_parents_for_cache($artefactids, &$parentids=false) {
     if (!is_array($artefactids)) {
         $artefactids = array($artefactids);
     }
-    $current = $artefactids;
+    $current = array_map('intval', $artefactids);
     if (empty($parentids)) { // first call
         $parentids = array();
     }
@@ -1245,7 +1322,7 @@ function artefact_get_parents_for_cache($artefactids, &$parentids=false) {
         $checkattachments = array();
         foreach ($parents as $p) {
             if (in_array($p->artefacttype, artefact_get_attachment_types())) {
-                $checkattachments[] = $p->id;
+                $checkattachments[] = (int)$p->id;
             }
         }
         if (!empty($checkattachments)) {
@@ -1346,7 +1423,7 @@ function artefact_instance_from_type($artefact_type, $user_id=null) {
 
 function artefact_watchlist_notification($artefactids) {
     // gets all the views containing this artefact or a parent of this artefact and creates a watchlist activity for each view
-    if ($views = get_column_sql('SELECT DISTINCT view FROM {view_artefact} WHERE artefact IN (' . implode(',', array_merge(array_keys(artefact_get_parents_for_cache($artefactids)), $artefactids)) . ')')) {
+    if ($views = get_column_sql('SELECT DISTINCT "view" FROM {view_artefact} WHERE artefact IN (' . implode(',', array_merge(array_keys(artefact_get_parents_for_cache($artefactids)), array_map('intval', $artefactids))) . ')')) {
         require_once('activity.php');
         foreach ($views as $view) {
             activity_occurred('watchlist', (object)array('view' => $view));
@@ -1356,13 +1433,15 @@ function artefact_watchlist_notification($artefactids) {
 
 function artefact_get_descendants($new) {
     $seen = array();
-    $new = array_combine($new, $new);
+    if (!empty($new)) {
+        $new = array_combine($new, $new);
+    }
     while (!empty($new)) {
         $seen = $seen + $new;
         $children = get_column_sql('
             SELECT id
             FROM {artefact}
-            WHERE parent IN (' . implode(',', $new) . ') AND id NOT IN (' . implode(',', $seen) . ')', array());
+            WHERE parent IN (' . implode(',', array_map('intval', $new)) . ') AND id NOT IN (' . implode(',', array_map('intval', $seen)) . ')', array());
         if ($children) {
             $new = array_diff($children, $seen);
             $new = array_combine($new, $new);
@@ -1411,7 +1490,7 @@ function artefact_get_references_in_html($html) {
 
 function artefact_get_records_by_id($ids) {
     if (!empty($ids)) {
-        if ($records = get_records_select_assoc('artefact', 'id IN (' . join(',', $ids) . ')')) {
+        if ($records = get_records_select_assoc('artefact', 'id IN (' . join(',', array_map('intval', $ids)) . ')')) {
             return $records;
         }
     }
@@ -1466,6 +1545,3 @@ function artefact_get_types_from_filter($filter) {
 
     return $contenttype_artefacttype[$filter];
 }
-
-
-?>
