@@ -27,12 +27,10 @@
 
 defined('INTERNAL') || die();
 
-$string['title'] = 'One Resumé Field';
-$string['description'] = 'Display any resumé information';
+$string['title'] = 'One Résumé Field';
+$string['description'] = 'Display any résumé information';
 
 $string['fieldtoshow'] = 'Field to show';
-$string['filloutyourresume'] = '%sFill out your resumé%s in order to add more fields!';
+$string['filloutyourresume'] = '%sFill out your résumé%s in order to add more fields!';
 
 $string['defaulttitledescription'] = 'If you leave this blank, the name of the field will be used';
-
-?>
