@@ -59,24 +59,12 @@ class PluginArtefactResume extends Plugin {
 
     public static function menu_items() {
         return array(
-            array(
-                'path' => 'profile/myresume',
-                'title' => get_string('myresume', 'artefact.resume'),
+            'content/resume' => array(
+                'path' => 'content/resume',
+                'title' => get_string('resume', 'artefact.resume'),
                 'url' => 'artefact/resume/',
-                'weight' => 20,
+                'weight' => 50,
             ),
-            array(
-                'path' => 'profile/mygoals',
-                'title' => get_string('mygoals', 'artefact.resume'),
-                'url' => 'artefact/resume/goals.php',
-                'weight' => 21,
-            ),
-            array(
-                'path' => 'profile/myskills',
-                'title' => get_string('myskills', 'artefact.resume'),
-                'url' => 'artefact/resume/skills.php',
-                'weight' => 22,
-            )
         );
     }
 
@@ -92,6 +80,55 @@ class PluginArtefactResume extends Plugin {
             'workskill'     => array('text'),
         );
     }
+
+    public static function submenu_items() {
+        $tabs = array(
+            'index' => array(
+                'page'  => 'index',
+                'url'   => 'artefact/resume',
+                'title' => get_string('introduction', 'artefact.resume'),
+            ),
+            'employment' => array(
+                'page'  => 'employment',
+                'url'   => 'artefact/resume/employment.php',
+                'title' => get_string('educationandemployment', 'artefact.resume'),
+            ),
+            'achievements' => array(
+                'page'  => 'achievements',
+                'url'   => 'artefact/resume/achievements.php',
+                'title' => get_string('achievements', 'artefact.resume'),
+            ),
+            'goals' => array(
+                'page'  => 'goals',
+                'url'   => 'artefact/resume/goals.php',
+                'title' => get_string('goals', 'artefact.resume'),
+            ),
+            'skills' => array(
+                'page'  => 'skills',
+                'url'   => 'artefact/resume/skills.php',
+                'title' => get_string('skills', 'artefact.resume'),
+            ),
+            'interests' => array(
+                'page'  => 'interests',
+                'url'   => 'artefact/resume/interests.php',
+                'title' => get_string('interests', 'artefact.resume'),
+            ),
+        );
+        if (defined('RESUME_SUBPAGE') && isset($tabs[RESUME_SUBPAGE])) {
+            $tabs[RESUME_SUBPAGE]['selected'] = true;
+        }
+        return $tabs;
+    }
+
+    public static function composite_tabs() {
+        return array(
+            'educationhistory'  => 'employment',
+            'employmenthistory' => 'employment',
+            'certification'     => 'achievements',
+            'book'              => 'achievements',
+            'membership'        => 'achievements',
+        );
+    }
 }
 
 class ArtefactTypeResume extends ArtefactType {
@@ -142,7 +179,7 @@ class ArtefactTypeResume extends ArtefactType {
         parent::commit();
 
         if ($blockinstances = get_records_sql_array('
-            SELECT id, view, configdata
+            SELECT id, "view", configdata
             FROM {block_instance}
             WHERE blocktype = \'entireresume\'
             AND "view" IN (
@@ -193,18 +230,13 @@ class ArtefactTypeContactinformation extends ArtefactTypeResume {
             try {
                 $$f = artefact_instance_from_type($f, $this->get('owner'));
                 $rendered = $$f->render_self(array());
-                $smarty->assign($f, format_whitespace($rendered['html']));
+                $smarty->assign($f, $rendered['html']);
                 $smarty->assign('hascontent', true);
             }
             catch (Exception $e) { }
         }
 
-        $template = 'artefact:resume:fragments/contactinformation.';
-        if (!empty($options['editing'])) {
-            $template .= 'editing.';
-        }
-        $template .= 'tpl';
-        return array('html' => $smarty->fetch($template));
+        return array('html' => $smarty->fetch('artefact:resume:fragments/contactinformation.tpl'));
     }
 
     public static function is_singular() {
@@ -212,11 +244,15 @@ class ArtefactTypeContactinformation extends ArtefactTypeResume {
     }
 
     public static function setup_new($userid) {
-        $artefact = new ArtefactTypeContactinformation(null, array(
-            'owner' => $userid,
-            'title' => get_string('contactinformation', 'artefact.resume')
-        ));
-        $artefact->commit();
+        try {
+            return artefact_instance_from_type('contactinformation', $userid);
+        } catch (ArtefactNotFoundException $e) {
+            $artefact = new ArtefactTypeContactinformation(null, array(
+                'owner' => $userid,
+                'title' => get_string('contactinformation', 'artefact.resume')
+            ));
+            $artefact->commit();
+        }
         return $artefact;
     }
 
@@ -321,7 +357,7 @@ class ArtefactTypePersonalinformation extends ArtefactTypeResume {
                 $value = get_string($value, 'artefact.resume');
             }
             if ($field == 'dateofbirth' && !empty($value)) {
-                $value = strftime(get_string('strftimedate'), $value);
+                $value = strftime(get_string('strftimedate'), $value+3600);
             }
             $fields[get_string($field, 'artefact.resume')] = $value;
         }
@@ -337,6 +373,19 @@ class ArtefactTypePersonalinformation extends ArtefactTypeResume {
 
         db_commit();
     }
+
+    public static function bulk_delete($artefactids) {
+        if (empty($artefactids)) {
+            return;
+        }
+
+        $idstr = join(',', array_map('intval', $artefactids));
+
+        db_begin();
+        delete_records_select('artefact_resume_personal_information', 'artefact IN (' . $idstr . ')');
+        parent::bulk_delete($artefactids);
+        db_commit();
+    }
 }
 
 
@@ -443,6 +492,19 @@ abstract class ArtefactTypeResumeComposite extends ArtefactTypeResume {
         db_commit();
     }
 
+    public static function bulk_delete_composite($artefactids, $compositetype) {
+        $table = 'artefact_resume_' . $compositetype;
+        if (empty($artefactids)) {
+            return;
+        }
+
+        $idstr = join(',', array_map('intval', $artefactids));
+
+        db_begin();
+        delete_records_select($table, 'artefact IN (' . $idstr . ')');
+        parent::bulk_delete($artefactids);
+        db_commit();
+    }
 
     /**
     * Takes a pieform that's been set up by all the 
@@ -513,9 +575,6 @@ abstract class ArtefactTypeResumeComposite extends ArtefactTypeResume {
             ORDER BY ar.displayorder';
 
         if (!empty($options['viewid'])) { 
-            if (!can_view_view($options['viewid'])) {
-                throw new AccessDeniedException();
-            }
             require_once('view.php');
             $v = new View($options['viewid']);
             $owner = $v->get('owner');
@@ -536,6 +595,85 @@ abstract class ArtefactTypeResumeComposite extends ArtefactTypeResume {
         return $content;
     }
 
+    public static function get_js(array $compositetypes) {
+        $js = self::get_common_js();
+        foreach ($compositetypes as $compositetype) {
+            $js .= call_static_method(
+                generate_artefact_class_name($compositetype),
+                'get_artefacttype_js',
+                $compositetype
+            );
+        }
+        return $js;
+    }
+
+    public static function get_common_js() {
+        $cancelstr = get_string('cancel');
+        $addstr = get_string('add');
+        $confirmdelstr = get_string('compositedeleteconfirm', 'artefact.resume');
+        $js = <<<EOF
+var tableRenderers = {};
+
+function toggleCompositeForm(type) {
+    var elemName = '';
+    elemName = type + 'form';
+    if (hasElementClass(elemName, 'hidden')) {
+        removeElementClass(elemName, 'hidden');
+        $('add' + type + 'button').innerHTML = '{$cancelstr}';
+    }
+    else {
+        $('add' + type + 'button').innerHTML = '{$addstr}';
+        addElementClass(elemName, 'hidden');
+    }
+}
+
+function compositeSaveCallback(form, data) {
+    key = form.id.substr(3);
+    tableRenderers[key].doupdate(); 
+    toggleCompositeForm(key);
+    // Can't reset() the form here, because its values are what were just submitted, 
+    // thanks to pieforms
+    forEach(form.elements, function(element) {
+        if (hasElementClass(element, 'text') || hasElementClass(element, 'textarea')) {
+            element.value = '';
+        }
+    });
+}
+
+function deleteComposite(type, id, artefact) {
+    if (confirm('{$confirmdelstr}')) {
+        sendjsonrequest('compositedelete.json.php',
+            {'id': id, 'artefact': artefact},
+            'GET',
+            function(data) {
+                tableRenderers[type].doupdate();
+            },
+            function() {
+                // @todo error
+            }
+        );
+    }
+    return false;
+}
+
+function moveComposite(type, id, artefact, direction) {
+    sendjsonrequest('compositemove.json.php',
+        {'id': id, 'artefact': artefact, 'direction':direction},
+        'GET',
+        function(data) {
+            tableRenderers[type].doupdate();
+        },
+        function() {
+            // @todo error
+        }
+    );
+    return false;
+}
+EOF;
+        $js .= self::get_showhide_composite_js();
+        return $js;
+    }
+
     static function get_tablerenderer_title_js($titlestring, $bodystring) {
         return "
                 function (r, d) {
@@ -576,6 +714,105 @@ abstract class ArtefactTypeResumeComposite extends ArtefactTypeResume {
             }
         ";
     }
+
+    static function get_artefacttype_js($compositetype) {
+        global $THEME;
+        $editstr = get_string('edit');
+        $delstr = get_string('delete');
+        $imagemoveblockup   = json_encode($THEME->get_url('images/move-up.gif'));
+        $imagemoveblockdown = json_encode($THEME->get_url('images/move-down.gif'));
+        $upstr = get_string('moveup', 'artefact.resume');
+        $downstr = get_string('movedown', 'artefact.resume');
+
+        $js = call_static_method(generate_artefact_class_name($compositetype), 'get_composite_js');
+
+        $js .= <<<EOF
+tableRenderers.{$compositetype} = new TableRenderer(
+    '{$compositetype}list',
+    'composite.json.php',
+    [
+EOF;
+
+        $js .= <<<EOF
+
+        function (r, d) {
+            var buttons = [];
+            if (r._rownumber > 1) {
+                var up = A({'href': ''}, IMG({'src': {$imagemoveblockup}, 'alt':'{$upstr}'}));
+                connect(up, 'onclick', function (e) {
+                    e.stop();
+                    return moveComposite(d.type, r.id, r.artefact, 'up');
+                });
+                buttons.push(up);
+            }
+            if (!r._last) {
+                var down = A({'href': '', 'class':'movedown'}, IMG({'src': {$imagemoveblockdown}, 'alt':'{$downstr}'}));
+                connect(down, 'onclick', function (e) {
+                    e.stop();
+                    return moveComposite(d.type, r.id, r.artefact, 'down');
+                });
+                buttons.push(' ');
+                buttons.push(down);
+            }
+            return TD({'class':'movebuttons'}, buttons);
+        },
+EOF;
+
+        $js .= call_static_method(generate_artefact_class_name($compositetype), 'get_tablerenderer_js');
+
+        $js .= <<<EOF
+        function (r, d) {
+            var editlink = A({'href': 'editcomposite.php?id=' + r.id + '&artefact=' + r.artefact, 'title': '{$editstr}'}, IMG({'src': config.theme['images/edit.gif'], 'alt':'{$editstr}'}));
+            var dellink = A({'href': '', 'title': '{$delstr}'}, IMG({'src': config.theme['images/icon_close.gif'], 'alt': '[x]'}));
+            connect(dellink, 'onclick', function (e) {
+                e.stop();
+                return deleteComposite(d.type, r.id, r.artefact);
+            });
+            return TD({'class':'right'}, null, editlink, ' ', dellink);
+        }
+    ]
+);
+
+tableRenderers.{$compositetype}.type = '{$compositetype}';
+tableRenderers.{$compositetype}.statevars.push('type');
+tableRenderers.{$compositetype}.emptycontent = '';
+tableRenderers.{$compositetype}.updateOnLoad();
+
+EOF;
+        return $js;
+    }
+
+    static function get_composite_js() {
+        return '';
+    }
+
+    static function get_forms(array $compositetypes) {
+        require_once(get_config('libroot') . 'pieforms/pieform.php');
+        $compositeforms = array();
+        foreach ($compositetypes as $compositetype) {
+            $elements = call_static_method(generate_artefact_class_name($compositetype), 'get_addform_elements');
+            $elements['submit'] = array(
+                'type' => 'submit',
+                'value' => get_string('save'),
+            );
+            $elements['compositetype'] = array(
+                'type' => 'hidden',
+                'value' => $compositetype,
+            );
+            $cform = array(
+                'name' => 'add' . $compositetype,
+                'plugintype' => 'artefact',
+                'pluginname' => 'resume',
+                'elements' => $elements,
+                'jsform' => true,
+                'successcallback' => 'compositeform_submit',
+                'jssuccesscallback' => 'compositeSaveCallback',
+            );
+            $compositeforms[$compositetype] = pieform($cform);
+        }
+        return $compositeforms;
+    }
+
 }
 
 class ArtefactTypeEmploymenthistory extends ArtefactTypeResumeComposite { 
@@ -596,7 +833,7 @@ class ArtefactTypeEmploymenthistory extends ArtefactTypeResumeComposite {
     }
 
     public static function get_tablerenderer_title_js_string() {
-        return " r.jobtitle + ' : ' + r.employer";
+        return " r.jobtitle + ': ' + r.employer";
     }
 
     public static function get_tablerenderer_body_js_string() {
@@ -611,11 +848,13 @@ class ArtefactTypeEmploymenthistory extends ArtefactTypeResumeComposite {
                     'required' => true,
                 ),
                 'title' => get_string('startdate', 'artefact.resume'),
+                'size' => 20,
                 'help' => true,
             ),
             'enddate' => array(
                 'type' => 'text', 
                 'title' => get_string('enddate', 'artefact.resume'),
+                'size' => 20,
             ),
             'employer' => array(
                 'type' => 'text',
@@ -623,6 +862,12 @@ class ArtefactTypeEmploymenthistory extends ArtefactTypeResumeComposite {
                     'required' => true,
                 ),
                 'title' => get_string('employer', 'artefact.resume'),
+                'size' => 50,
+            ),
+            'employeraddress' => array(
+                'type' => 'text',
+                'title' => get_string('employeraddress', 'artefact.resume'),
+                'size' => 50,
             ),
             'jobtitle' => array(
                 'type' => 'text',
@@ -630,6 +875,7 @@ class ArtefactTypeEmploymenthistory extends ArtefactTypeResumeComposite {
                     'required' => true,
                 ),
                 'title' => get_string('jobtitle', 'artefact.resume'),
+                'size' => 50,
             ),
             'positiondescription' => array(
                 'type' => 'textarea',
@@ -640,6 +886,10 @@ class ArtefactTypeEmploymenthistory extends ArtefactTypeResumeComposite {
             ),
         );
     }
+
+    public static function bulk_delete($artefactids) {
+        ArtefactTypeResumeComposite::bulk_delete_composite($artefactids, 'employmenthistory');
+    }
 }
 
 class ArtefactTypeEducationhistory extends ArtefactTypeResumeComposite {
@@ -662,14 +912,23 @@ class ArtefactTypeEducationhistory extends ArtefactTypeResumeComposite {
     }
 
     public static function get_tablerenderer_title_js_string() {
-        $at = get_string('at');
-        return " r.qualname + ' (' + r.qualtype + ') {$at} ' + r.institution";
+        return " formatQualification(r.qualname, r.qualtype, r.institution)";
     }
 
     public static function format_render_self_data($data) {
         $at = get_string('at');
         foreach ($data as &$row) {
-            $row->qualification = $row->qualname . ' (' . $row->qualtype . ")  $at " . $row->institution;
+            $row->qualification = '';
+            if (strlen($row->qualname) && strlen($row->qualtype)) {
+                $row->qualification = $row->qualname. ' (' . $row->qualtype . ') ' . $at . ' ';
+            }
+            else if (strlen($row->qualtype)) {
+                $row->qualification = $row->qualtype . ' ' . $at . ' ';
+            }
+            else if (strlen($row->qualname)) {
+                $row->qualification = $row->qualname . ' ' . $at . ' ';
+            }
+            $row->qualification .= $row->institution;
         }
         return $data;
     }
@@ -686,11 +945,13 @@ class ArtefactTypeEducationhistory extends ArtefactTypeResumeComposite {
                     'required' => true,
                 ),
                 'title' => get_string('startdate', 'artefact.resume'),
+                'size' => 20,
                 'help' => true,
             ),
             'enddate' => array(
                 'type' => 'text', 
                 'title' => get_string('enddate', 'artefact.resume'),
+                'size' => 20,
             ),
             'institution' => array(
                 'type' => 'text',
@@ -698,20 +959,22 @@ class ArtefactTypeEducationhistory extends ArtefactTypeResumeComposite {
                     'required' => true,
                 ),
                 'title' => get_string('institution', 'artefact.resume'),
+                'size' => 50,
+            ),
+            'institutionaddress' => array(
+                'type' => 'text',
+                'title' => get_string('institutionaddress', 'artefact.resume'),
+                'size' => 50,
             ),
             'qualtype' => array(
                 'type' => 'text',
-                'rules' => array(
-                    'required' => true,
-                ),
                 'title' => get_string('qualtype', 'artefact.resume'),
+                'size' => 50,
             ),
             'qualname' => array(
                 'type' => 'text',
-                'rules' => array(
-                    'required' => true,
-                ),
                 'title' => get_string('qualname', 'artefact.resume'),
+                'size' => 50,
             ),
             'qualdescription' => array(
                 'type' => 'textarea',
@@ -722,6 +985,30 @@ class ArtefactTypeEducationhistory extends ArtefactTypeResumeComposite {
             ),
         );
     }
+
+    static function get_composite_js() {
+        $at = get_string('at');
+        return <<<EOF
+function formatQualification(name, type, institution) {
+    var qual = '';
+    if (name && type) {
+        qual = name + ' (' + type + ') {$at} ';
+    }
+    else if (type) {
+        qual = type + ' {$at} ';
+    }
+    else if (name) {
+        qual = name + ' {$at} ';
+    }
+    qual += institution;
+    return qual;
+}
+EOF;
+    }
+
+    public static function bulk_delete($artefactids) {
+        ArtefactTypeResumeComposite::bulk_delete_composite($artefactids, 'educationhistory');
+    }
 }
 
 class ArtefactTypeCertification extends ArtefactTypeResumeComposite { 
@@ -754,6 +1041,7 @@ class ArtefactTypeCertification extends ArtefactTypeResumeComposite {
                     'required' => true,
                 ),
                 'title' => get_string('date', 'artefact.resume'),
+                'size' => 20,
                 'help' => true,
             ),
             'title' => array(
@@ -762,6 +1050,7 @@ class ArtefactTypeCertification extends ArtefactTypeResumeComposite {
                     'required' => true,
                 ),
                 'title' => get_string('title', 'artefact.resume'),
+                'size' => 20,
             ),
             'description' => array(
                 'type' => 'textarea',
@@ -772,6 +1061,10 @@ class ArtefactTypeCertification extends ArtefactTypeResumeComposite {
             ),
         );
     }
+
+    public static function bulk_delete($artefactids) {
+        ArtefactTypeResumeComposite::bulk_delete_composite($artefactids, 'certification');
+    }
 }
 
 class ArtefactTypeBook extends ArtefactTypeResumeComposite {
@@ -806,6 +1099,7 @@ class ArtefactTypeBook extends ArtefactTypeResumeComposite {
                 ),
                 'title' => get_string('date', 'artefact.resume'),
                 'help' => true,
+                'size' => 20,
             ),
             'title' => array(
                 'type' => 'text',
@@ -813,6 +1107,7 @@ class ArtefactTypeBook extends ArtefactTypeResumeComposite {
                     'required' => true,
                 ),
                 'title' => get_string('title', 'artefact.resume'),
+                'size' => 50,
             ),
             'contribution' => array(
                 'type' => 'text',
@@ -820,6 +1115,7 @@ class ArtefactTypeBook extends ArtefactTypeResumeComposite {
                     'required' => true,
                 ),
                 'title' => get_string('contribution', 'artefact.resume'),
+                'size' => 50,
             ),
             'description' => array(
                 'type' => 'textarea',
@@ -830,6 +1126,10 @@ class ArtefactTypeBook extends ArtefactTypeResumeComposite {
             ),
         );
     }
+
+    public static function bulk_delete($artefactids) {
+        ArtefactTypeResumeComposite::bulk_delete_composite($artefactids, 'book');
+    }
 }
 
 class ArtefactTypeMembership extends ArtefactTypeResumeComposite { 
@@ -865,10 +1165,12 @@ class ArtefactTypeMembership extends ArtefactTypeResumeComposite {
                 ),
                 'title' => get_string('startdate', 'artefact.resume'),
                 'help' => true,
+                'size' => 20,
             ),
             'enddate' => array(
                 'type' => 'text', 
                 'title' => get_string('enddate', 'artefact.resume'),
+                'size' => 20,
             ),
             'title' => array(
                 'type' => 'text',
@@ -876,6 +1178,7 @@ class ArtefactTypeMembership extends ArtefactTypeResumeComposite {
                     'required' => true,
                 ),
                 'title' => get_string('title', 'artefact.resume'),
+                'size' => 50,
             ),
             'description' => array(
                 'type' => 'textarea',
@@ -886,6 +1189,10 @@ class ArtefactTypeMembership extends ArtefactTypeResumeComposite {
             ),
         );
     }
+
+    public static function bulk_delete($artefactids) {
+        ArtefactTypeResumeComposite::bulk_delete_composite($artefactids, 'membership');
+    }
 }
 
 class ArtefactTypeResumeGoalAndSkill extends ArtefactTypeResume {
@@ -921,16 +1228,23 @@ function compositeform_submit(Pieform $form, $values) {
 
 function compositeformedit_submit(Pieform $form, $values) {
     global $SESSION;
+
+    $tabs = PluginArtefactResume::composite_tabs();
+    $goto = get_config('wwwroot') . '/artefact/resume/';
+    if (isset($tabs[$values['compositetype']])) {
+        $goto .= $tabs[$values['compositetype']] . '.php';
+    }
+
     try {
         call_static_method(generate_artefact_class_name($values['compositetype']),
             'process_compositeform', $form, $values);
     }
     catch (Exception $e) {
         $SESSION->add_error_msg(get_string('compositesavefailed', 'artefact.resume'));
-        redirect('/artefact/resume/');
+        redirect($goto);
     }
     $SESSION->add_ok_msg(get_string('compositesaved', 'artefact.resume'));
-    redirect('/artefact/resume/');
+    redirect($goto);
 }
 
 function goalandskillform_submit(Pieform $form, $values) {
@@ -955,5 +1269,3 @@ function goalandskillform_submit(Pieform $form, $values) {
     }
     $form->json_reply(PIEFORM_OK, get_string('goalandskillsaved', 'artefact.resume'));
 }   
-
-?>
