@@ -143,7 +143,7 @@ class PluginAuthImap extends PluginAuth {
         if ($instance > 0) {
             $current        = get_records_array('auth_instance',        'id',       $instance, 'priority ASC');
             if ($current == false) {
-                throw new Exception('Could not find data for auth instance '.$instance);
+                throw new SystemException('Could not find data for auth instance '.$instance);
             }
             $default = $current[0];
             $current_config = get_records_menu('auth_instance_config', 'instance', $instance, '', 'field, value');
@@ -288,5 +288,3 @@ class PluginAuthImap extends PluginAuth {
         return $values;
     }
 }
-
-?>
