@@ -38,11 +38,13 @@ $string['ldapfieldforemail'] = 'LDAP field for Email';
 $string['ldapfieldforfirstname'] = 'LDAP field for First Name';
 $string['ldapfieldforsurname'] = 'LDAP field for Surname';
 $string['ldapversion'] = 'LDAP version';
+$string['starttls'] = 'TLS encryption';
 $string['password'] = 'Password';
 $string['searchsubcontexts'] = 'Search subcontexts';
 $string['userattribute'] = 'User attribute';
 $string['usertype'] = 'User type';
 $string['weautocreateusers'] = 'We auto-create users';
 $string['updateuserinfoonlogin'] = 'Update user info on login';
+$string['updateuserinfoonloginadnote'] = 'Note: Enabling this may prevent some MS ActiveDirectory sites/users from subsequent Mahara logins';
+
 $string['cannotconnect'] = 'Cannot connect to any LDAP hosts';
-?>
