@@ -57,6 +57,9 @@ require(dirname(__FILE__) . '/init.php');
 
 // get the config pointing to the SAML library - and load it
 $samllib = get_config_plugin('auth', 'saml', 'simplesamlphplib');
+if (null === $samllib) {
+    exit(0);
+}
 require_once($samllib.'/lib/_autoload.php');
 
 // point at the configured config directory
@@ -65,20 +68,56 @@ $samlconfig = get_config_plugin('auth', 'saml', 'simplesamlphpconfig');
 // get all the things that we will need from the SAML authentication
 // and then shutdown the session control
 SimpleSAML_Configuration::init($samlconfig);
-$as = new SimpleSAML_Auth_Simple('default-sp');
-$saml_config = SimpleSAML_Configuration::getInstance();
 $saml_session = SimpleSAML_Session::getInstance();
-$valid_saml_session = $saml_session->isValid('default-sp');
 
 // do we have a logout request?
-if(isset($_GET["logout"])) {
+if(param_variable("logout", false)) {
     // logout the saml session
+    $sp = $saml_session->getAuthority();
+    if (! $sp) {
+        $sp = 'default-sp';
+    }
+    $as = new SimpleSAML_Auth_Simple($sp);
     $as->logout($CFG->wwwroot);
 }
+$sp = param_alphanumext('as','default-sp');
+if (! in_array($sp, SimpleSAML_Auth_Source::getSources())) {
+    $sp = 'default-sp';
+}
+$as = new SimpleSAML_Auth_Simple($sp);
+$saml_config = SimpleSAML_Configuration::getInstance();
+$valid_saml_session = $saml_session->isValid($sp);
+
+// do we have a returnto URL ?
+$wantsurl = param_variable("wantsurl", false);
+if($wantsurl) {
+    $_SESSION['wantsurl'] = $wantsurl;
+}
+else if (isset($_SESSION['wantsurl'])) {
+    $wantsurl = $_SESSION['wantsurl'];
+}
+else if (! $saml_session->getIdP()){
+    $_SESSION['wantsurl'] = array_key_exists('HTTP_REFERER',$_SERVER) ? $_SERVER['HTTP_REFERER'] : $CFG->wwwroot;
+    $wantsurl = $_SESSION['wantsurl'];
+}
+else {
+    $wantsurl = $CFG->wwwroot;
+}
+
+// taken from Moodle clean_param
+include_once('validateurlsyntax.php');
+if (!validateUrlSyntax($wantsurl, 's?H?S?F?E?u-P-a?I?p?f?q?r?')) {
+    $wantsurl = $CFG->wwwroot;
+}
 
 // now - are we logged in?
 $as->requireAuth();
 
+// ensure that $_SESSION is cleared
+if (isset($_SESSION['wantsurl'])) {
+    unset($_SESSION['wantsurl']);
+}
+
 $saml_attributes = $as->getAttributes();
 session_write_close();
 
@@ -158,9 +197,8 @@ if(!$USER->is_logged_in()) {
     simplesaml_init($saml_config, $valid_saml_session, $saml_attributes, $as);
 }
 // they are logged in, so they dont need to be here 
-else {
-    header('Location: '.$CFG->wwwroot);
-}
+//    header('Location: '.$CFG->wwwroot);
+redirect($wantsurl);
     
 
 /**
@@ -242,7 +280,6 @@ function simplesaml_init($saml_config, $valid_saml_session, $saml_attributes, $a
             $auth = new AuthSaml($instance->id);
             if ($auth->request_user_authorise($saml_attributes)) {
                 session_write_close();
-                redirect($CFG->wwwroot);
             }
             else {
                  throw new UserNotFoundException(get_string('errnosamluser','auth.saml'));
@@ -252,5 +289,3 @@ function simplesaml_init($saml_config, $valid_saml_session, $saml_attributes, $a
         }
     }
 }
-
-?>
