@@ -197,10 +197,8 @@ class Session {
         $result = '<div id="messages">';
         if (isset($_SESSION['messages'])) {
             foreach ($_SESSION['messages'] as $data) {
-                $result .= '<div class="' . $data['type'] . '">';
-                $result .= '<div class="fr"><a href="" onclick="removeElement(this.parentNode.parentNode);return false;">';
-                $result .= '<img src="' . $THEME->get_url('images/icon_close.gif') . '" alt="[X]"></a></div>';
-                $result .= $data['msg'] . '</div>';
+                $result .= '<div class="' . $data['type'] . '"><div>';
+                $result .= $data['msg'] . '</div></div>';
             }
             $_SESSION['messages'] = array();
         }
@@ -274,4 +272,78 @@ function insert_messages() {
     return $SESSION->render_messages();
 }
 
-?>
+
+/**
+ * Delete all sessions belonging to a given user except for the current one
+ */
+function remove_user_sessions($userid) {
+    global $sessionpath, $USER;
+
+    $sessionids = get_column('usr_session', 'session', 'usr', (int) $userid);
+
+    if (empty($sessionids)) {
+        return;
+    }
+
+    $alive = array();
+    $dead = array();
+    $sid = $USER->get('sessionid');
+    foreach ($sessionids as $sessionid) {
+        if ($sessionid == $sid) {
+            continue;
+        }
+        $file = $sessionpath;
+        for ($i = 0; $i < 3; $i++) {
+            $file .= '/' . substr($sessionid, $i, 1);
+        }
+        $file .= '/sess_' . $sessionid;
+        if (file_exists($file)) {
+            $alive[] = $sessionid;
+        }
+        else {
+            $dead[] = $sessionid;
+        }
+    }
+
+    if (!empty($dead)) {
+        delete_records_select('usr_session', 'session IN (' . join(',', array_map('db_quote', $dead)) . ')');
+    }
+
+    if (empty($alive)) {
+        return;
+    }
+
+    session_commit();
+
+    foreach ($alive as $sessionid) {
+        session_id($sessionid);
+        if (session_start()) {
+            session_destroy();
+            session_commit();
+        }
+    }
+
+    session_id($sid);
+    session_start();
+
+    delete_records_select('usr_session', 'session IN (' . join(',', array_map('db_quote', $alive)) . ')');
+}
+
+/**
+ * Delete all session files except for the current one
+ */
+function remove_all_sessions() {
+    global $sessionpath, $USER;
+
+    $sid = $USER->get('sessionid');
+
+    $iterator = new RecursiveIteratorIterator(new RecursiveDirectoryIterator($sessionpath));
+    foreach ($iterator as $path) {
+        if ($path->isFile() && $path->getFilename() !== ('sess_' . $sid)) {
+            @unlink($path->getPathname());
+        }
+    }
+    clearstatcache();
+
+    delete_records_select('usr_session', 'session != ?', array($sid));
+}
