@@ -1082,7 +1082,7 @@ class LiveUser extends User {
         // Unset session variables related to authentication
         $this->SESSION->set('authinstance', null);
         if (get_config('installed') && !defined('INSTALLER') && $this->get('sessionid')
-            && function_exists('table_exists') && table_exists('usr_session')) {
+            && function_exists('table_exists') && table_exists(new XMLDBTable('usr_session'))) {
             delete_records('usr_session', 'session', $this->get('sessionid'));
         }
 
@@ -1158,11 +1158,6 @@ class LiveUser extends User {
             $this->set_account_preference('lang', $sessionlang);
         }
 
-        // Set language for the current request
-        if (!empty($this->accountprefs['lang'])) {
-            current_language($this->accountprefs['lang']);
-        }
-
         $this->reset_institutions();
         $this->reset_grouproles();
         $this->load_views();
