@@ -124,11 +124,11 @@ class AuthXmlrpc extends Auth {
             throw new AccessDeniedException();
         }
 
-        $virgin = false;
-
-        $oldlastlogin = null;
         $create = false;
         $update = false;
+        if ('1' == $this->config['updateuserinfoonlogin']) {
+            $update = true;
+        }
 
         // Retrieve a $user object. If that fails, create a blank one.
         try {
@@ -173,9 +173,6 @@ class AuthXmlrpc extends Auth {
                 die_info(get_string('accountsuspended', 'mahara', strftime(get_string('strftimedaydate'), $user->get('suspendedctime')), $user->get('suspendedreason')));
             }
 
-            if ('1' == $this->config['updateuserinfoonlogin']) {
-                $update = true;
-            }
         } catch (AuthUnknownUserException $e) {
             if (!empty($this->config['weautocreateusers'])) {
                 $institution = new Institution($this->institution);
@@ -209,6 +206,7 @@ class AuthXmlrpc extends Auth {
             $user->firstname          = $remoteuser->firstname;
             $user->lastname           = $remoteuser->lastname;
             $user->email              = $remoteuser->email;
+            $imported = array('firstname', 'lastname', 'email');
 
             //TODO: import institution's per-user-quota?:
             //$user->quota              = $userrecord->quota;
@@ -219,7 +217,8 @@ class AuthXmlrpc extends Auth {
 
             $user->id = create_user($user, array(), $this->institution, $this, $remoteuser->username);
 
-            $this->import_user_settings($user, $remoteuser);
+            $locked = $this->import_user_settings($user, $remoteuser);
+            $locked = array_merge($imported, $locked);
 
             /*
              * We need to convert the object to a stdclass with its own
@@ -237,15 +236,24 @@ class AuthXmlrpc extends Auth {
             $user->find_by_id($userobj->id);
 
         } elseif ($update) {
-            $simplefieldstoimport = array('firstname', 'lastname', 'email');
-            foreach ($simplefieldstoimport as $field) {
+            $imported = array('firstname', 'lastname', 'email');
+            foreach ($imported as $field) {
                 if ($user->$field != $remoteuser->$field) {
                     $user->$field = $remoteuser->$field;
                     set_profile_field($user->id, $field, $user->$field);
                 }
             }
 
-            $this->import_user_settings($user, $remoteuser);
+            if (isset($remoteuser->idnumber)) {
+                if ($user->studentid != $remoteuser->idnumber) {
+                    $user->studentid = $remoteuser->idnumber;
+                    set_profile_field($user->id, 'studentid', $user->studentid);
+                }
+                $imported[] = 'studentid';
+            }
+
+            $locked = $this->import_user_settings($user, $remoteuser);
+            $locked = array_merge($imported, $locked);
 
             $user->lastlastlogin      = $user->lastlogin;
             $user->lastlogin          = time();
@@ -354,6 +362,9 @@ class AuthXmlrpc extends Auth {
                     log_warn(get_string('cantcreatetempprofileiconfile', 'artefact.file', $filename));
                 }
             }
+            if ($update) {
+                $locked[] = 'profileicon';
+            }
         }
 
         /*******************************************/
@@ -369,6 +380,10 @@ class AuthXmlrpc extends Auth {
         $SESSION->set('authinstance', $this->instanceid);
         $SESSION->set('mnetuserfrom', $_SERVER['HTTP_REFERER']);
 
+        if ($update && isset($locked)) {
+            $SESSION->set('lockedfields', $locked);
+        }
+
         return true;
     }
 
@@ -385,12 +400,12 @@ class AuthXmlrpc extends Auth {
         // The user is likely to be associated with the parent instance
         if (is_numeric($this->config['parent']) && $this->config['parent'] > 0) {
             $_instanceid = $this->config['parent'];
-            $userrecord = get_record('usr', 'LOWER(username)', strtolower($username), 'authinstance', $_instanceid);
+            $userrecord = record_exists_select('usr', 'LOWER(username) = ? and authinstance = ?', array(strtolower($username), $_instanceid));
         }
 
         if (empty($userrecord)) {
             $_instanceid = $this->instanceid;
-            $userrecord = get_record('usr', 'LOWER(username)', strtolower($username), 'authinstance', $_instanceid);
+            $userrecord = record_exists_select('usr', 'LOWER(username) = ? and authinstance = ?', array(strtolower($username), $_instanceid));
         }
 
         if ($userrecord != false) {
@@ -429,11 +444,14 @@ class AuthXmlrpc extends Auth {
      * @param stdClass $remoteuser
      */
     private function import_user_settings($user, $remoteuser) {
+        $imported = array();
+
         // City
         if (!empty($remoteuser->city)) {
             if (get_profile_field($user->id, 'town') != $remoteuser->city) {
                 set_profile_field($user->id, 'town', $remoteuser->city);
             }
+            $imported[] = 'town';
         }
 
         // Country
@@ -443,6 +461,7 @@ class AuthXmlrpc extends Auth {
             if (in_array($newcountry, $validcountries)) {
                 set_profile_field($user->id, 'country', $newcountry);
             }
+            $imported[] = 'country';
         }
 
         // Language
@@ -460,6 +479,7 @@ class AuthXmlrpc extends Auth {
             if (get_profile_field($user->id, 'introduction') != $remoteuser->description) {
                 set_profile_field($user->id, 'introduction', $remoteuser->description);
             }
+            $imported[] = 'introduction';
         }
 
         // HTML Editor setting
@@ -470,6 +490,8 @@ class AuthXmlrpc extends Auth {
                 $user->set_account_preference('wysiwyg', $htmleditor);
             }
         }
+
+        return $imported;
     }
 
     public function kill_parent($username) {
@@ -521,6 +543,8 @@ class AuthXmlrpc extends Auth {
         }
 
         $USER->logout();
+        // Unset locked fields
+        $SESSION->clear('lockedfields');
 
         if (isset($_GET['logout'])) {
             // Explicit logout request
@@ -842,7 +866,10 @@ class PluginAuthXmlrpc extends PluginAuth {
                 $peer->bootstrap($values['wwwroot'], null, $values['appname'], $values['institution']);
             } catch (RemoteServerException $e) {
                 log_debug($e->getMessage());
-                $form->set_error('wwwroot',get_string('cantretrievekey', 'auth'));
+                $form->set_error('wwwroot',get_string('cantretrievekey', 'auth') . '<br>' . $e->getMessage());
+            } catch (ParamOutOfRangeException $e) {
+                log_debug($e->getMessage());
+                $form->set_error('wwwroot',get_string('cantretrievekey', 'auth') . '<br>' . $e->getMessage());
             }
         }
         else if ($values['institution'] != $peer->institution) {
@@ -1024,5 +1051,3 @@ function localurl_to_jumpurl($url) {
     }
     return $indirecturl;
 }
-
-?>
