@@ -34,12 +34,10 @@ require_once('group.php');
 require_once('searchlib.php');
 $filter = param_alpha('filter', 'notmember');
 $offset = param_integer('offset', 0);
-
-$groupsperpage = 20;
-
+$groupcategory = param_signed_integer('groupcategory', 0);
+$groupsperpage = 10;
 $query = param_variable('query', '');
 
-
 if ($filter == 'member') {
     $type = 'member';
 }
@@ -50,97 +48,98 @@ else { // all or some other text
     $filter = 'all';
     $type = 'all';
 }
-
-$searchform = pieform(array(
-    'name'   => 'search',
-    'method' => 'post',
-    'renderer' => 'oneline',
-    'elements' => array(
-        'query' => array(
+$elements = array();
+$elements['query'] = array(
             'type' => 'text',
-            'defaultvalue' => $query
-        ),
-        'filter' => array(
+            'defaultvalue' => $query);
+$elements['filter'] = array(
             'type' => 'select',
             'options' => array(
                 'notmember' => get_string('groupsnotin', 'group'),
                 'member'    => get_string('groupsimin', 'group'),
                 'all'       => get_string('allgroups', 'group')
             ),
-            'defaultvalue' => $filter
-        ),
-        'search' => array(
+            'defaultvalue' => $filter);
+if (get_config('allowgroupcategories')
+    && $groupcategories = get_records_menu('group_category','','','displayorder', 'id,title')
+) {
+    $options[0] = get_string('allcategories', 'group');
+    $options[-1] = get_string('categoryunassigned', 'group');
+    $options += $groupcategories;
+    $elements['groupcategory'] = array(
+                'type'         => 'select',
+                'options'      => $options,
+                'defaultvalue' => $groupcategory,
+                'help'         => true);
+}
+$elements['search'] = array(
             'type' => 'submit',
-            'value' => get_string('search')
-        )
+            'value' => get_string('search'));
+$searchform = pieform(array(
+    'name'   => 'search',
+    'method' => 'post',
+    'renderer' => 'oneline',
+    'elements' => $elements
     )
-));
+);
 
-$groups = search_group($query, $groupsperpage, $offset, $type);
+$groups = search_group($query, $groupsperpage, $offset, $type, $groupcategory);
 
 // gets more data about the groups found by search_group
 // including type if the user is associated with the group in some way
-// and the first three members by id
 if ($groups['data']) {
     $groupids = array();
     foreach ($groups['data'] as $group) {
         $groupids[] = $group->id;
     }
-    $groups['data'] =  get_records_sql_assoc(
-        "SELECT g1.id, g1.name, g1.description, g1.jointype, g1.membershiptype, g1.membercount, COUNT(gmr.member) AS requests
+    $groups['data'] =  get_records_sql_array(
+        "SELECT g1.id, g1.name, g1.description, g1.public, g1.jointype, g1.grouptype, g1.role, g1.membershiptype, g1.membercount, COUNT(gmr.member) AS requests
         FROM (
-            SELECT g.id, g.name, g.description, g.jointype, t.membershiptype, COUNT(gm.member) AS membercount
+            SELECT g.id, g.name, g.description, g.public, g.jointype, g.grouptype, t.role, t.membershiptype, COUNT(gm.member) AS membercount
             FROM {group} g
             LEFT JOIN {group_member} gm ON (gm.group = g.id)
             LEFT JOIN (
-                SELECT g.id, 'admin' AS membershiptype
+                SELECT g.id, 'admin' AS membershiptype, gm.role AS role
                 FROM {group} g
                 INNER JOIN {group_member} gm ON (gm.group = g.id AND gm.member = ? AND gm.role = 'admin')
                 UNION
-                SELECT g.id, 'member' AS membershiptype
+                SELECT g.id, 'member' AS membershiptype, gm.role AS role
                 FROM {group} g
                 INNER JOIN {group_member} gm ON (g.id = gm.group AND gm.member = ? AND gm.role != 'admin')
                 UNION
-                SELECT g.id, 'invite' AS membershiptype
+                SELECT g.id, 'invite' AS membershiptype, gmi.role
                 FROM {group} g
                 INNER JOIN {group_member_invite} gmi ON (gmi.group = g.id AND gmi.member = ?)
                 UNION
-                SELECT g.id, 'request' AS membershiptype
+                SELECT g.id, 'request' AS membershiptype, NULL as role
                 FROM {group} g
                 INNER JOIN {group_member_request} gmr ON (gmr.group = g.id AND gmr.member = ?)
             ) t ON t.id = g.id
             WHERE g.id IN (" . implode($groupids, ',') . ')
-            GROUP BY g.id, g.name, g.description, g.jointype, t.membershiptype
-            ORDER BY g.name
+            GROUP BY g.id, g.name, g.description, g.public, g.jointype, g.grouptype, t.role, t.membershiptype
         ) g1
         LEFT JOIN {group_member_request} gmr ON (gmr.group = g1.id)
-        GROUP BY g1.id, g1.name, g1.description, g1.jointype, g1.membershiptype, g1.membercount',
+        GROUP BY g1.id, g1.name, g1.description, g1.public, g1.jointype, g1.grouptype, g1.role, g1.membershiptype, g1.membercount
+        ORDER BY g1.name',
         array($USER->get('id'), $USER->get('id'), $USER->get('id'), $USER->get('id'))
     );
-    if ($groups['data']) {
-        // Get 3 members from each group in a separate query -- mysql doesn't like including them as subqueries with limit 1 in the above query
-        $members = get_records_sql_array("
-            SELECT m1.group, m1.member, u.* FROM {group_member} m1
-            INNER JOIN {usr} u ON (m1.member = u.id AND u.deleted = 0)
-            WHERE 3 > (
-                SELECT COUNT(m2.member)
-                FROM {group_member} m2
-                WHERE m1.group = m2.group AND m2.member < m1.member
-            )
-            AND m1.group IN (" . implode($groupids, ',') . ')', array());
-        if ($members) {
-            foreach ($members as $m) {
-                $groups['data'][$m->group]->members[] = (object) array('id' => $m->id, 'name' => display_name($m));
-            }
-        }
-    }
-    $groups['data'] = array_values($groups['data']);
 }
 
 group_prepare_usergroups_for_display($groups['data'], 'find');
 
+$params = array();
+if ($filter != 'notmember') {
+    $params['filter'] = $filter;
+}
+if ($groupcategory != 0) {
+    $params['groupcategory'] = $groupcategory;
+}
+if ($query) {
+    $params['query'] = $query;
+}
+
 $pagination = build_pagination(array(
-    'url' => get_config('wwwroot') . 'group/find.php?filter=' . $filter . '&amp;query=' . $query,
+    'url' => get_config('wwwroot') . 'group/find.php' . ($params ? ('?' . http_build_query($params)) : ''),
     'count' => $groups['count'],
     'limit' => $groupsperpage,
     'offset' => $offset,
@@ -149,14 +148,12 @@ $pagination = build_pagination(array(
 ));
 
 function search_submit(Pieform $form, $values) {
-    redirect('/group/find.php?filter=' . $values['filter'] . (isset($values['query']) ? '&query=' . urlencode($values['query']) : ''));
+    redirect('/group/find.php?filter=' . $values['filter'] . (!empty($values['query']) ? '&query=' . urlencode($values['query']) : '') . (!empty($values['groupcategory']) ? '&groupcategory=' . intval($values['groupcategory']) : ''));
 }
 
 $smarty = smarty();
-$smarty->assign('PAGEHEADING', hsc(TITLE));
+$smarty->assign('PAGEHEADING', TITLE);
 $smarty->assign('form', $searchform);
 $smarty->assign('groups', $groups['data']);
 $smarty->assign('pagination', $pagination['html']);
 $smarty->display('group/find.tpl');
-
-?>
