@@ -28,7 +28,7 @@
 defined('INTERNAL') || die();
 
 /**
- * Implements import of LEAP2A files
+ * Implements import of Leap2A files
  *
  * For more documentation, please see:
  * http://wiki.mahara.org/index.php?title=Developer_Area/Import%2F%2FExport/LEAP_Import
@@ -41,6 +41,10 @@ class PluginImportLeap extends PluginImport {
     private $loadmapping = array();
     private $coreloadmapping = array();
     private $artefactids = array();
+    private $viewids = array();
+    private $collectionids = array();
+    private $collectionviewentries = array();
+    protected $filename;
 
     protected $persondataid = null;
 
@@ -51,6 +55,9 @@ class PluginImportLeap extends PluginImport {
     protected $leap2anamespace = null;
     protected $leap2atypenamespace = null;
     protected $leap2acategories = null;
+    // the version is stored with the full url since the url might change in
+    // future versions (as it has between 2009-03 and 2010-07)
+    protected $supportedleap2aversions = array('http://www.leapspecs.org/2010-07/2A/');
 
     private $snapshots = array();
 
@@ -70,8 +77,27 @@ class PluginImportLeap extends PluginImport {
     const XHTML_DIV_EMPTY = '<div xmlns="http://www.w3.org/1999/xhtml"/>';
 
     const STRATEGY_IMPORT_AS_VIEW = 1;
+    const STRATEGY_IMPORT_AS_COLLECTION = 2;
 
-    public static function validate_import_data($importdata) {
+    public static function validate_transported_data(ImporterTransport $transport) {
+        $importdata = $transport->files_info();
+        if (!$file = self::find_file($importdata)) {
+            throw new ImportException(null, 'Missing leap xml file');
+        }
+    }
+
+    public static function find_file($importdata) {
+        $path = $importdata['tempdir'] . 'extract/';
+        if (!empty($importdata['manifestfile'])) {
+            $files = array($importdata['manifestfile']);
+        } else {
+            $files = array('leap.xml', 'leap2.xml', 'leap2a.xml');
+        }
+        foreach ($files as $f) {
+            if (file_exists($path . $f)) {
+                return $path . $f;
+            }
+        }
     }
 
     public function get($field) {
@@ -84,16 +110,16 @@ class PluginImportLeap extends PluginImport {
     public function process() {
         db_begin();
 
-        $data = $this->get('data');
-        $filename = get_config('dataroot') . $data['filename'];
-        $this->trace('Loading import from ' . $filename);
+        $this->filename = self::find_file($this->get('importertransport')->files_info());
+        $this->logfile = dirname($this->filename) . '/import.log';
+        $this->trace('Loading import from ' . $this->filename);
         $this->snapshot('begin');
 
         $options =
             LIBXML_COMPACT |    // Reported to greatly speed XML parsing
             LIBXML_NONET        // Disable network access - security check
         ;
-        if (!$this->xml = simplexml_load_file($filename, 'SimpleXMLElement', $options)) {
+        if (!$this->xml = simplexml_load_file($this->filename, 'SimpleXMLElement', $options)) {
             // TODO: bail out in a much nicer way...
             throw new ImportException($this, "FATAL: XML file is not well formed! Please consult Mahara's error log for more information");
         }
@@ -123,15 +149,33 @@ class PluginImportLeap extends PluginImport {
      *
      */
     private function detect_leap2a_namespace () {
+
         // check for the leap2a version used
-        $leap2 = false;
-        if(in_array('leap2', $this->namespaces)) {
-            $leap2 = true;
+        // disable xml warnings. The initial LEAP2A spec hasn't got the leap2
+        // namespace so the following xpath expression triggers a warning
+        // which we want to suppress.
+        $oldvalue = libxml_use_internal_errors(true);
+        $version = $this->xml->xpath('//leap2:version');
+        libxml_use_internal_errors($oldvalue);
+
+        // if there is no version string we assume the first version of the
+        // LEAP2A spec which doesn't contain the version element
+        if(!empty($version) && !in_array($version[0][0], $this->supportedleap2aversions)) {
+            throw new ImportException($this, "FATAL: The version of the uploaded LEAP2A file is not supported by this Mahara version");
         }
-        if($leap2) {
+
+        if($version) {
             $this->leap2anamespace = self::NS_LEAP;
             $this->leap2atypenamespace = self::NS_LEAP;
-            $this->leap2acategories = self::NS_CATEGORIES;
+            // this is a workaround for a bug that was introduced during the
+            // update to LEAP2A 2010-07. Exports between the update and this
+            // bugfix will contain a wrong namespace. This workaround will
+            // allow those exports to still import properly. (bug #673434)
+            if (isset($this->namespaces['http://wiki.leapspecs.org/2A/categories'])) {
+                $this->leap2acategories = 'http://wiki.leapspecs.org/2A/categories';
+            } else {
+                $this->leap2acategories = self::NS_CATEGORIES;
+            }
         } else {
             $this->leap2anamespace = self::NS_LEAP_200903;
             $this->leap2atypenamespace = self::NS_LEAPTYPE_200903;
@@ -400,10 +444,12 @@ class PluginImportLeap extends PluginImport {
         // persondata entry
         // TODO: this should return an artefact mapping so things can create 
         // links to profile fields, but nothing actually needs it yet
-        foreach (plugins_installed('artefact') as $plugin) {
-            $classname = 'LeapImport' . ucfirst($plugin->name);
-            if (method_exists($classname, 'import_author_data')) {
-                call_static_method($classname, 'import_author_data', $this, $this->persondataid);
+        if (!is_array($this->data) || !array_key_exists('skippersondata', $this->data) || $this->data['skippersondata'] !== true) {
+            foreach (plugins_installed('artefact') as $plugin) {
+                $classname = 'LeapImport' . ucfirst($plugin->name);
+                if (method_exists($classname, 'import_author_data')) {
+                    call_static_method($classname, 'import_author_data', $this, $this->persondataid);
+                }
             }
         }
 
@@ -456,6 +502,53 @@ class PluginImportLeap extends PluginImport {
 
             $loadedentries[] = $entryid;
         }
+
+        // Put views into collections
+
+        // Keep track of which views have been placed in a collection, because
+        // Mahara can't handle more one collection per view.
+        $incollection = array();
+
+        foreach ($this->collectionviewentries as $cid => $entryids) {
+            $i = 0;
+            foreach ($entryids as $entryid) {
+                $viewid = self::get_viewid_imported_by_entryid($entryid);
+                if ($viewid && !isset($incollection[$viewid])) {
+                    $record = (object) array(
+                        'collection' => $cid,
+                        'view' => $viewid,
+                        'displayorder' => $i,
+                    );
+                    insert_record('collection_view', $record);
+                    $incollection[$viewid] = $cid;
+                    $i++;
+                }
+            }
+        }
+
+        // Allow each plugin to load relationships to views if they need to
+        foreach ($loadedentries as $entryid) {
+            if (isset($this->loadmapping[$entryid])) {
+                $strategydata = $this->loadmapping[$entryid];
+                $classname = 'LeapImport' . ucfirst($strategydata['artefactplugin']);
+                $entry = $this->get_entry_by_id($entryid);
+                call_static_method($classname, 'setup_view_relationships',
+                    $entry, $this, $strategydata['strategy'], $strategydata['other_required_entries']);
+            }
+        }
+    }
+
+    public function entry_has_strategy($entryid, $strategyid, $artefactplugin=null) {
+        if (isset($this->loadmapping[$entryid])) {
+            if (empty($this->loadmapping[$entryid]['artefactplugin']) && !empty($artefactplugin)) {
+                return false;
+            }
+            if ($this->loadmapping[$entryid]['artefactplugin'] != $artefactplugin) {
+                return false;
+            }
+            return $this->loadmapping[$entryid]['strategy'] == $strategyid;
+        }
+        return false;
     }
 
     private function import_completed() {
@@ -522,7 +615,7 @@ class PluginImportLeap extends PluginImport {
             // from trace() itself
             global $CFG;
             $oldtargets = $CFG->log_dbg_targets;
-            $oldfile    = $CFG->log_file;
+            $oldfile = isset($CFG->log_file) ? $CFG->log_file : null;
             $CFG->log_dbg_targets = $this->logtargets;
             $CFG->log_file = $this->logfile;
             $file = $line = $trace = null;
@@ -554,13 +647,21 @@ class PluginImportLeap extends PluginImport {
      * @param SimpleXMLElement $entry
      */
     public function get_import_strategies_for_entry(SimpleXMLElement $entry) {
-        if (self::is_rdf_type($entry, $this, 'selection')
-            && self::is_correct_category_scheme($entry, $this, 'selection_type', 'Webpage')) {
-            return array(array(
-                'strategy' => self::STRATEGY_IMPORT_AS_VIEW,
-                'score'    => 100,
-                'other_required_entries' => array(),
-            ));
+        if (self::is_rdf_type($entry, $this, 'selection')) {
+            if (self::is_correct_category_scheme($entry, $this, 'selection_type', 'Webpage')) {
+                return array(array(
+                    'strategy' => self::STRATEGY_IMPORT_AS_VIEW,
+                    'score'    => 100,
+                    'other_required_entries' => array(),
+                ));
+            }
+            if (self::is_correct_category_scheme($entry, $this, 'selection_type', 'Website')) {
+                return array(array(
+                    'strategy' => self::STRATEGY_IMPORT_AS_COLLECTION,
+                    'score'    => 100,
+                    'other_required_entries' => array(),
+                ));
+            }
         }
         return array();
     }
@@ -608,7 +709,36 @@ class PluginImportLeap extends PluginImport {
                     )
                 );
                 $view->addblockinstance($bi);
+                $this->viewids[(string)$entry->id] = $view->get('id');
             }
+            break;
+        case self::STRATEGY_IMPORT_AS_COLLECTION:
+            require_once('collection.php');
+
+            $collectiondata = array(
+                'name'        => (string)$entry->title,
+                'description' => (string)$entry->summary,
+                'owner'       => $this->get('usr'),
+            );
+            if ($published = strtotime((string)$entry->published)) {
+                $collectiondata['ctime'] = $published;
+            }
+            if ($updated = strtotime((string)$entry->updated)) {
+                $collectiondata['mtime'] = $updated;
+            }
+
+            $collection = new Collection(0, $collectiondata);
+            $collection->commit();
+            $this->collectionids[(string)$entry->id] = $collection->get('id');
+
+            // Remember entry ids that form part of this entry, and use them later
+            // to put views into collections.
+            foreach ($entry->link as $link) {
+                if ($this->curie_equals($link['rel'], '', 'has_part') && isset($link['href'])) {
+                    $this->collectionviewentries[$collection->get('id')][] = (string) $link['href'];
+                }
+            }
+
             break;
         default:
             throw new ImportException($this, 'TODO: get_string: unknown strategy chosen for importing entry');
@@ -622,7 +752,7 @@ class PluginImportLeap extends PluginImport {
      * structure. If they're present, we use them to create a View using that 
      * structure.
      *
-     * This differs a bit from the LEAP2A specification, but we do so 
+     * This differs a bit from the Leap2A specification, but we do so 
      * deliberately to get 100% compatibility with Mahara to Mahara exports. 
      * Other systems can also construct content in the right format to trigger 
      * Mahara to import things as a full view.
@@ -739,6 +869,7 @@ class PluginImportLeap extends PluginImport {
         $view->set('owner', $this->get('usr'));
 
         $view->commit();
+        $this->viewids[(string)$entry->id] = $view->get('id');
         return true;
     }
 
@@ -792,7 +923,7 @@ class PluginImportLeap extends PluginImport {
     }
 
     /**
-     * Given an artefact record, looks through it for any leap2a style
+     * Given an artefact record, looks through it for any Leap2A style
      * references to other artefacts, and rewrite those to point at the created
      * ones.
      *
@@ -830,8 +961,9 @@ class PluginImportLeap extends PluginImport {
      * @return boolean Whether it's worth checking in more detail
      */
     private function artefact_reference_quickcheck($field) {
+        $ns = $this->namespaces[$this->leap2anamespace];
 
-        return (false !== strpos($field, 'rel="'.$this->leap2anamespace.':has_part"')
+        return (false !== strpos($field, 'rel="'.$ns.':has_part"')
                 || false !== strpos($field, 'rel="enclosure"'))
             && (
                 (false !== strpos($field, '<img'))
@@ -846,28 +978,78 @@ class PluginImportLeap extends PluginImport {
      * @return string The fixed field
      */
     private function fix_artefact_reference($field) {
-        $match = '#<((img)|a)([^>]+)rel="(?:'.$this->leap2anamespace.':has_part|enclosure)" (?:src|href)="([^"]+)"([^>]*)>#';
-        $field = preg_replace_callback($match,
-            array($this, '_fixref'),
-            $field);
-        return $field;
+        $ns = $this->namespaces[$this->leap2anamespace];
+
+        // load the field as XML
+        $dom = new DOMDocument('1.0', 'utf-8');
+        $dom->loadHTML($field);
+        $xml = simplexml_import_dom($dom);
+
+        // and search for <img> and <a> tags
+        $elements = $xml->xpath('//img|//a');
+
+        // loop through all elements found
+        foreach ($elements as $e) {
+            $rel  = (string)$e->attributes()->rel;
+            $name = (string)$e->getName();
+            $href = $e->attributes()->href;
+            $src  = $e->attributes()->src;
+
+            // identified as fixable?
+            if ($rel == $ns . ':has_part' || $rel == 'enclosure') {
+                // change the href / src attributes
+                if (isset($href)) {
+                    $value = $this->_fixref((string)$href);
+                }
+                else if (isset($src)) {
+                    $value = $this->_fixref((string)$src);
+                }
+
+                if (isset($value)) {
+                    switch ($name) {
+                        case 'a':
+                            if (isset($e->attributes()->href)) {
+                                $e->attributes()->href = $value;
+                            }
+                            else {
+                                $e->addAttribute('href', $value);
+                            }
+                            break;
+                        case 'img':
+                            if (isset($e->attributes()->src)) {
+                                $e->attributes()->src = $value;
+                            }
+                            else {
+                                $e->addAttribute('src', $value);
+                            }
+                            break;
+                    }
+
+                    // remove the 'rel' attribute
+                    unset($e->attributes()->rel);
+                }
+            }
+        }
+
+        // DOMDocument wraps the content with '<html><body></body></html>'
+        // so we call children() twice to remove it again
+        return $xml->children()->children()->asXML();
     }
 
-    private function _fixref($matches) {
+    private function _fixref($hrefsrc) {
         static $basepath;
         if (!$basepath) {
             $basepath = get_mahara_install_subdirectory();
         }
 
-        $artefacts = $this->get_artefactids_imported_by_entryid($matches[4]);
+        $artefacts = $this->get_artefactids_imported_by_entryid($hrefsrc);
         if (is_null($artefacts) || count($artefacts) != 1) {
-            // This can happen if a leap2a xml file is uploaded that refers to
+            // This can happen if a Leap2A xml file is uploaded that refers to
             // files that (naturally) weren't uploaded with it.
-            log_debug("Warning: fixref was expecting one artefact to have been imported by entry {$matches[4]} but seems to have gotten " . count($artefacts));
-            return $matches[0];
+            log_debug("Warning: fixref was expecting one artefact to have been imported by entry {$hrefsrc} but seems to have gotten " . count($artefacts));
+            return $hrefsrc;
         }
-        return '<' . $matches[1] . $matches[3] . ($matches[1] == 'img' ? 'src' : 'href') . '="'
-            . $basepath . 'artefact/file/download.php?file=' . $artefacts[0] . '"' . $matches[5] . '>';
+        return $basepath . 'artefact/file/download.php?file=' . $artefacts[0];
     }
 
     /**
@@ -890,6 +1072,9 @@ class PluginImportLeap extends PluginImport {
         // TODO: entryid injection? Probably not worth worrying about
         $matches = $this->xml->xpath("//a:feed/a:entry/a:id[.='$entryid']/..");
         // TODO: there had better be only one...
+        if (empty($matches)) {
+            return null;
+        }
         $entry = $matches[0];
         if ($entry) {
             $this->registerXpathNamespaces($entry);
@@ -904,10 +1089,17 @@ class PluginImportLeap extends PluginImport {
         return $this->artefactids[$entryid];
     }
 
+    public function get_viewid_imported_by_entryid($entryid) {
+        if (!isset($this->viewids[$entryid])) {
+            return null;
+        }
+        return $this->viewids[$entryid];
+    }
+
     /**
      * Returns xpath for an attribute matching a given curie
      *
-     * See http://wiki.cetis.ac.uk/2009-03/LEAP2A_elements#Use_of_CURIEs
+     * See http://wiki.cetis.ac.uk/2009-03/Leap2A_elements#Use_of_CURIEs
      *
      * @param string $attribute The attribute to match
      * @param string $namespace The namespace for the attribute value
@@ -975,7 +1167,7 @@ class PluginImportLeap extends PluginImport {
      *
      * @param SimpleXMLElement $entry    The entry to check
      * $param PluginImportLeap $importer The importer
-     * @param string $category           The category to look in. See http://wiki.cetis.ac.uk/2009-03/LEAP2A_categories
+     * @param string $category           The category to look in. See http://wiki.cetis.ac.uk/2009-03/Leap2A_categories
      * @param string $term               The term to look for (see the docs for the appropriate category)
      * @return boolean Whether the entry has the term in the category
      */
@@ -1024,6 +1216,8 @@ class PluginImportLeap extends PluginImport {
         case 'html':
         case 'text':
             return (string)$entry->content;
+        case '':
+            return ''; // empty entry
         default:
             throw new SystemException("Unrecognised content type for entry '$entry->id' ($type)");
         }
@@ -1056,7 +1250,7 @@ class PluginImportLeap extends PluginImport {
      * Returned in a structure like so:
      * array(
      *     'start' => array(
-     *         'value' => 'w3c compliant date/time format, as allowed by LEAP2A',
+     *         'value' => 'w3c compliant date/time format, as allowed by Leap2A',
      *         'label' => 'label attribute, which is a plaintext version of the date',
      *     ),
      *     'end' => array(
@@ -1067,7 +1261,7 @@ class PluginImportLeap extends PluginImport {
      *     )
      * )
      *
-     * The only keys in the return value are those allowed by the LEAP2A spec, 
+     * The only keys in the return value are those allowed by the Leap2A spec, 
      * and only if they exist on the entry.
      *
      * The values may have the 'value', 'label' or both keys, depending on what 
@@ -1076,7 +1270,7 @@ class PluginImportLeap extends PluginImport {
      * Try and use the 'value' first, if you have a choice. Quite a few places 
      * in Mahara currently just store dates as plaintext though.
      *
-     * Spec reference: http://wiki.cetis.ac.uk/2009-03/LEAP2A_literals#date
+     * Spec reference: http://wiki.cetis.ac.uk/2009-03/Leap2A_literals#date
      */
     public static function get_leap_dates(SimpleXMLElement $entry, $namespaces, $ns) {
         $dates = array();
@@ -1220,9 +1414,8 @@ class PluginImportLeap extends PluginImport {
     private function create_linked_file(SimpleXMLElement $entry, SimpleXMLElement $link) {
         $this->trace($link);
         $pathname = urldecode((string)$link['href']);
-        $data = $this->get('data');
-        $dir = dirname($data['filename']);
-        $pathname = $dir . DIRECTORY_SEPARATOR . $pathname;
+        $dir = dirname($this->get('filename'));
+        $pathname = $dir . '/' . $pathname;
         if (!file_exists($pathname)) {
             return false;
         }
@@ -1410,6 +1603,13 @@ abstract class LeapImportArtefactPlugin {
     public static function setup_relationships(SimpleXMLElement $entry, PluginImportLeap $importer, $strategy, array $otherentries) {
     }
 
+    /**
+     * Gives plugins a chance to construct relationships between the newly
+     * created artefacts and newly created views.
+     */
+    public static function setup_view_relationships(SimpleXMLElement $entry, PluginImportLeap $importer, $strategy, array $otherentries) {
+    }
+
     /**
      * Runs after the importer has finished, to allow the plugin to perform any
      * cleanup operations.
@@ -1420,5 +1620,3 @@ abstract class LeapImportArtefactPlugin {
     }
 
 }
-
-?>
