@@ -36,6 +36,7 @@ safe_require('interaction', 'forum');
 require_once('group.php');
 require_once(get_config('docroot') . 'interaction/lib.php');
 require_once('pieforms/pieform.php');
+require_once('antispam.php');
 
 $postid = param_integer('id', 0);
 
@@ -102,10 +103,15 @@ else { // edit post
     // no record for edits to own posts with 30 minutes
     if (user_can_edit_post($post->poster, $post->ctime)) {
         $post->editrecord = false;
+        $timeleft = (int)get_config_plugin('interaction', 'forum', 'postdelay') - round((time() - $post->ctime) / 60);
     }
     else if ($moderator) {
         $post->editrecord = true;
     }
+    else if (user_can_edit_post($post->poster, $post->ctime, $USER->get('id'), false)) {
+        $SESSION->add_error_msg(get_string('postaftertimeout', 'interaction.forum', get_config_plugin('interaction', 'forum', 'postdelay')));
+        redirect('/interaction/forum/topic.php?id=' . $parent->topic);
+    }
     else {
         throw new AccessDeniedException(get_string('canteditpost', 'interaction.forum'));
     }
@@ -115,30 +121,10 @@ else { // edit post
 
 $parent->ctime = relative_date(get_string('strftimerecentfullrelative', 'interaction.forum'), get_string('strftimerecentfull'), $parent->ctime);
 
-// Javascript to hide the subject box if it has nothing in it, with a link you 
-// click to expand it.
-$clicksetsubject = json_encode(get_string('clicksetsubject', 'interaction.forum'));
-$inlinejs = <<<EOF
-addLoadEvent(function() {
-    var subjectInput = $('editpost_subject');
-    if (subjectInput.value == '') {
-        hideElement(subjectInput);
-        var expandLink = A({'href': ''}, {$clicksetsubject});
-        connect(expandLink, 'onclick', function(e) {
-            showElement(subjectInput);
-            subjectInput.focus();
-            e.stop();
-            removeElement(expandLink);
-        });
-        insertSiblingNodesBefore(subjectInput, expandLink);
-    }
-    tinyMCE.execCommand('mceFocus',false,'mce_editor_0');
-});
-EOF;
-
 $editform = pieform(array(
     'name'     => 'editpost',
     'successcallback' => isset($post) ? 'editpost_submit' : 'addpost_submit',
+    'autofocus' => 'body',
     'elements' => array(
         'subject' => array(
             'type'         => 'text',
@@ -146,7 +132,9 @@ $editform = pieform(array(
             'defaultvalue' => isset($post) ? $post->subject : null,
             'rules'        => array(
                 'maxlength' => 255
-            )
+            ),
+            'hidewhenempty' => true,
+            'expandtext'    => get_string('clicksetsubject', 'interaction.forum'),
         ),
         'body' => array(
             'type'         => 'wysiwyg',
@@ -154,12 +142,15 @@ $editform = pieform(array(
             'rows'         => 18,
             'cols'         => 70,
             'defaultvalue' => isset($post) ? $post->body : null,
-            'rules'        => array( 'required' => true )
+            'rules'        => array(
+                'required'  => true,
+                'maxlength' => 65536,
+            ),
         ),
         'submit'   => array(
             'type'  => 'submitcancel',
             'value'       => array(
-                isset($post) ? get_string('edit') : get_string('Post','interaction.forum'),
+                isset($post) ? get_string('save') : get_string('Post','interaction.forum'),
                 get_string('cancel')
             ),
             'goto'      => get_config('wwwroot') . 'interaction/forum/topic.php?id=' . $parent->topic . '#post' . (isset($postid) ? $postid : $parentid)
@@ -175,6 +166,12 @@ $editform = pieform(array(
     ),
 ));
 
+function editpost_validate(Pieform $form, $values) {
+    if ($baddomain = get_first_blacklisted_domain($values['body'])) {
+        $form->set_error('body', get_string('blacklisteddomaininurl', 'mahara', $baddomain));
+    }
+}
+
 function editpost_submit(Pieform $form, $values) {
     global $USER, $SESSION;
     $postid = param_integer('id');
@@ -183,7 +180,7 @@ function editpost_submit(Pieform $form, $values) {
         'interaction_forum_post',
         array(
             'subject' => $values['subject'],
-            'body' => $values['body']
+            'body' => PluginInteractionForum::prepare_post_body($values['body'], $postid),
         ),
         array('id' => $postid)
     );
@@ -205,18 +202,22 @@ function editpost_submit(Pieform $form, $values) {
 function addpost_submit(Pieform $form, $values) {
     global $USER, $SESSION;
     $parentid = param_integer('parent');
-    $postid = insert_record(
-        'interaction_forum_post',
-        (object)array(
-            'topic' => $values['topic'],
-            'poster' => $USER->get('id'),
-            'parent' => $parentid,
-            'subject' => $values['subject'],
-            'body' => $values['body'],
-            'ctime' =>  db_format_timestamp(time())
-        ),
-        'id', true
+    $post = (object)array(
+        'topic'   => $values['topic'],
+        'poster'  => $USER->get('id'),
+        'parent'  => $parentid,
+        'subject' => $values['subject'],
+        'body'    => $values['body'],
+        'ctime'   =>  db_format_timestamp(time())
     );
+    $postid = insert_record('interaction_forum_post', $post, 'id', true);
+
+    // Rewrite the post id into links in the body
+    $newbody = PluginInteractionForum::prepare_post_body($post->body, $postid);
+    if (!empty($newbody) && $newbody != $post->body) {
+        set_field('interaction_forum_post', 'body', $newbody, 'id', $postid);
+    }
+
     $delay = get_config_plugin('interaction', 'forum', 'postdelay');
     if (!is_null($delay) && $delay == 0) {
         PluginInteractionForum::interaction_forum_new_post(array($postid));
@@ -234,6 +235,8 @@ $smarty->assign('groupadmins', group_get_admin_ids($parent->group));
 if (isset($inlinejs)) {
     $smarty->assign('INLINEJAVASCRIPT', $inlinejs);
 }
-$smarty->display('interaction:forum:editpost.tpl');
 
-?>
+if (isset($timeleft)) {
+    $smarty->assign('timeleft', $timeleft);
+}
+$smarty->display('interaction:forum:editpost.tpl');
