@@ -36,6 +36,7 @@ safe_require('interaction', 'forum');
 require_once('group.php');
 require_once(get_config('docroot') . 'interaction/lib.php');
 require_once('pieforms/pieform.php');
+require_once('antispam.php');
 
 $userid = $USER->get('id');
 $topicid = param_integer('id', 0);
@@ -63,23 +64,25 @@ else { // edit topic
 }
 
 $forum = get_record_sql(
-    'SELECT f.group AS groupid, f.title, g.name AS groupname, g.grouptype, ic.value AS newtopicusers
+    'SELECT f.group AS groupid, f.title, g.name AS groupname, g.grouptype
     FROM {interaction_instance} f
-    INNER JOIN {group} g ON (g.id = f.group AND g.deleted = ?)
-    LEFT OUTER JOIN {interaction_forum_instance_config} ic ON (f.id = ic.forum AND ic.field = \'createtopicusers\')
+    INNER JOIN {group} g ON (g.id = f.group AND g.deleted = 0)
     WHERE f.id = ?
-    AND f.deleted != ?',
-    array(0, $forumid, 1)
+    AND f.deleted != 1',
+    array($forumid)
 );
+
 if (!$forum) {
     throw new NotFoundException(get_string('cantfindforum', 'interaction.forum', $forumid));
 }
 
+$forumconfig = get_records_assoc('interaction_forum_instance_config', 'forum', $forumid, '', 'field,value');
+
 define('GROUP', $forum->groupid);
 $membership = user_can_access_forum((int)$forumid);
 $moderator = (bool)($membership & INTERACTION_FORUM_MOD);
 
-if (!$membership || ($forum->newtopicusers == 'moderators' && !$moderator)) {
+if (!$membership || ($forumconfig['createtopicusers']->value == 'moderators' && !$moderator)) {
     throw new AccessDeniedException(get_string('cantaddtopic', 'interaction.forum'));
 }
 
@@ -93,10 +96,15 @@ else { // edit topic
     // no record for edits to own posts with 30 minutes
     if (user_can_edit_post($topic->poster, $topic->ctime)) {
         $topic->editrecord = false;
+        $timeleft = (int)get_config_plugin('interaction', 'forum', 'postdelay') - round((time() - $topic->ctime) / 60);
     }
     else if ($moderator) {
         $topic->editrecord = true;
     }
+    else if (user_can_edit_post($topic->poster, $topic->ctime, $USER->get('id'), false)) {
+        $SESSION->add_error_msg(get_string('postaftertimeout', 'interaction.forum', get_config_plugin('interaction', 'forum', 'postdelay')));
+        redirect('/interaction/forum/topic.php?id=' . $topicid);
+    }
     else {
         throw new AccessDeniedException(get_string('cantedittopic', 'interaction.forum'));
     }
@@ -105,7 +113,7 @@ else { // edit topic
 $editform = array(
     'name'     => isset($topic) ? 'edittopic' : 'addtopic',
     'method'   => 'post',
-    'autofocus' => false,
+    'autofocus' => isset($topic) ? 'body' : 'subject',
     'elements' => array(
         'subject' => array(
             'type'         => 'text',
@@ -122,7 +130,10 @@ $editform = array(
             'rows'         => 18,
             'cols'         => 70,
             'defaultvalue' => isset($topic) ? $topic->body : null,
-            'rules'        => array( 'required' => true )
+            'rules'        => array(
+                'required'  => true,
+                'maxlength' => 65536,
+            ),
         ),
         'sticky' => array(
             'type'         => 'checkbox',
@@ -134,7 +145,7 @@ $editform = array(
             'type'         => 'checkbox',
             'title'        => get_string('Closed', 'interaction.forum'),
             'description'  => get_string('closeddescription', 'interaction.forum'),
-            'defaultvalue' => isset($topic) && $topic->closed == 1 ? 'checked' : null
+            'defaultvalue' => isset($topic) ? $topic->closed : !empty($forumconfig['closetopics']->value),
         ),
         'submit'   => array(
             'type'  => 'submitcancel',
@@ -162,6 +173,18 @@ if(!$moderator){
 
 $editform = pieform($editform);
 
+function addtopic_validate(Pieform $form, $values) {
+    if ($baddomain = get_first_blacklisted_domain($values['body'])) {
+        $form->set_error('body', get_string('blacklisteddomaininurl', 'mahara', $baddomain));
+    }
+}
+
+function edittopic_validate(Pieform $form, $values) {
+    if ($baddomain = get_first_blacklisted_domain($values['body'])) {
+        $form->set_error('body', get_string('blacklisteddomaininurl', 'mahara', $baddomain));
+    }
+}
+
 function addtopic_submit(Pieform $form, $values) {
     global $USER, $SESSION;
     $forumid = param_integer('forum');
@@ -174,17 +197,21 @@ function addtopic_submit(Pieform $form, $values) {
             'closed' => isset($values['closed']) && $values['closed'] ? 1 : 0
         ), 'id', true
     );
-    $postid = insert_record(
-        'interaction_forum_post',
-        (object)array(
-            'topic' => $topicid,
-            'poster' => $USER->get('id'),
-            'subject' => $values['subject'],
-            'body' => $values['body'],
-            'ctime' =>  db_format_timestamp(time())
-        ),
-        'id', true
+    $post = (object)array(
+        'topic'   => $topicid,
+        'poster'  => $USER->get('id'),
+        'subject' => $values['subject'],
+        'body'    => $values['body'],
+        'ctime'   =>  db_format_timestamp(time())
     );
+    $postid = insert_record('interaction_forum_post', $post, 'id', true);
+
+    // Rewrite the post id into links in the body
+    $newbody = PluginInteractionForum::prepare_post_body($post->body, $postid);
+    if (!empty($newbody) && $newbody != $post->body) {
+        set_field('interaction_forum_post', 'body', $newbody, 'id', $postid);
+    }
+
     if (!record_exists('interaction_forum_subscription_forum', 'user', $USER->get('id'), 'forum', $forumid)) {
         insert_record('interaction_forum_subscription_topic', (object)array(
             'user'  => $USER->get('id'),
@@ -214,7 +241,7 @@ function edittopic_submit(Pieform $form, $values) {
             'interaction_forum_post',
             array(
                 'subject' => $values['subject'],
-                'body' => $values['body']
+                'body' => PluginInteractionForum::prepare_post_body($values['body'], $values['post']),
             ),
             array('id' => $values['post'])
         );
@@ -253,6 +280,7 @@ $smarty = smarty();
 $smarty->assign('heading', $forum->groupname);
 $smarty->assign('subheading', TITLE);
 $smarty->assign('editform', $editform);
+if (isset($timeleft)) {
+    $smarty->assign('timeleft', $timeleft);
+}
 $smarty->display('interaction:forum:edittopic.tpl');
-
-?>
