@@ -35,6 +35,9 @@ class PluginInteractionForum extends PluginInteraction {
             $autosubscribe = isset($instanceconfig['autosubscribe']) ? $instanceconfig['autosubscribe']->value : false;
             $weight = isset($instanceconfig['weight']) ? $instanceconfig['weight']->value : null;
             $createtopicusers = isset($instanceconfig['createtopicusers']) ? $instanceconfig['createtopicusers']->value : null;
+            $closetopics = !empty($instanceconfig['closetopics']);
+            $indentmode = isset($instanceconfig['indentmode']) ? $instanceconfig['indentmode']->value : null;
+            $maxindent = isset($instanceconfig['maxindent']) ? $instanceconfig['maxindent']->value : null;
 
             $moderators = get_column_sql(
                 'SELECT fm.user FROM {interaction_forum_moderator} fm
@@ -70,6 +73,30 @@ class PluginInteractionForum extends PluginInteraction {
         }
 
         return array(
+            'indentmode' => array(
+                'type'         => 'select',
+                'title'        => get_string('indentmode', 'interaction.forum'),
+                'options'      => array('full_indent'  => get_string('indentfullindent', 'interaction.forum'),
+                                        'max_indent'   => get_string('indentmaxindent', 'interaction.forum'),
+                                        'no_indent'    => get_string('indentflatindent', 'interaction.forum') ),
+                'description'  => get_string('indentmodedescription', 'interaction.forum'),
+                'defaultvalue' => isset($indentmode) ? $indentmode : 'full_indent',
+                'rules' => array(
+                    'required' => true,
+                ),
+            ),
+            'maxindent' => array(
+                'type'         => 'text',
+                'title'        => get_string('maxindent', 'interaction.forum'),
+                'size'         => 2,
+                'defaultvalue' => isset($maxindent) ? $maxindent : 10,
+                'class'        => (isset($indentmode) && $indentmode == 'max_indent') ? '' : 'hidden',
+                'rules' => array(
+                    'integer' => true,
+                    'minvalue' => 1,
+                    'maxvalue' => 100,
+                ),
+            ),
             'fieldset' => array(
                 'type' => 'fieldset',
                 'collapsible' => true,
@@ -77,15 +104,10 @@ class PluginInteractionForum extends PluginInteraction {
                 'legend' => get_string('settings'),
                 'elements' => array(
                     'autosubscribe' => array(
-                        'type'         => 'select',
+                        'type'         => 'checkbox',
                         'title'        => get_string('autosubscribeusers', 'interaction.forum'),
-                        'options'      => array(true  => get_string('yes'),
-                                                false => get_string('no')),
                         'description'  => get_string('autosubscribeusersdescription', 'interaction.forum'),
                         'defaultvalue' => isset($autosubscribe) ? $autosubscribe : false,
-                        'rules' => array(
-                            'required' => true,
-                        ),
                         'help'         => true,
                     ),
                     'weight' => array(
@@ -121,11 +143,41 @@ class PluginInteractionForum extends PluginInteraction {
                             'required' => true,
                         ),
                     ),
+                    'closetopics' => array(
+                        'type'         => 'checkbox',
+                        'title'        => get_string('closetopics', 'interaction.forum'),
+                        'description'  => get_string('closetopicsdescription', 'interaction.forum'),
+                        'defaultvalue' => !empty($closetopics),
+                    ),
                 )
             )
         );
     }
 
+    public static function instance_config_js() {
+        return <<<EOF
+function update_maxindent() {
+    var s = $('edit_interaction_indentmode');
+    var m = $('edit_interaction_maxindent_container');
+    var t = $('edit_interaction_maxindent');
+    if (!m) {
+        return;
+    }
+    if (s.options[s.selectedIndex].value == 'max_indent') {
+        removeElementClass(m, 'hidden');
+        removeElementClass(t, 'hidden');
+    }
+    else {
+        addElementClass(m, 'hidden');
+        addElementClass(t, 'hidden');
+    }
+}
+addLoadEvent(function() {
+    connect('edit_interaction_indentmode', 'onchange', update_maxindent);
+});
+EOF;
+    }
+
     public static function instance_config_save($instance, $values){
         db_begin();
 
@@ -224,6 +276,50 @@ class PluginInteractionForum extends PluginInteraction {
             'value' => $values['createtopicusers'] == 'moderators' ? 'moderators' : 'members',
         ));
 
+        // Close topics
+        delete_records_sql(
+            "DELETE FROM {interaction_forum_instance_config}
+            WHERE field = 'closetopics' AND forum = ?",
+            array($instance->get('id'))
+        );
+        if (!empty($values['closetopics'])) {
+            insert_record('interaction_forum_instance_config', (object)array(
+                'forum' => $instance->get('id'),
+                'field' => 'closetopics',
+                'value' => 1,
+            ));
+        }
+
+        //Indent mode
+        delete_records_sql(
+            "DELETE FROM {interaction_forum_instance_config}
+            WHERE field = 'indentmode' AND forum = ?",
+            array($instance->get('id'))
+        );
+        if (!isset($values['indentmode'])) {
+            $values['indentmode'] = 'full_indent';
+        }
+        insert_record('interaction_forum_instance_config', (object)array(
+            'forum' => $instance->get('id'),
+            'field' => 'indentmode',
+            'value' => $values['indentmode'],
+        ));
+
+        //Max indent
+        delete_records_sql(
+            "DELETE FROM {interaction_forum_instance_config}
+            WHERE field = 'maxindent' AND forum = ?",
+            array($instance->get('id'))
+        );
+        if (!isset($values['maxindent'])) {
+            $values['maxindent'] = 10;
+        }
+        insert_record('interaction_forum_instance_config', (object)array(
+            'forum' => $instance->get('id'),
+            'field' => 'maxindent',
+            'value' => $values['maxindent'],
+        ));
+
 
         db_commit();
     }
@@ -244,9 +340,19 @@ class PluginInteractionForum extends PluginInteraction {
                 'callfunction' => 'interaction_forum_new_post',
                 'minute'       => '*/30',
             ),
+            (object)array(
+                'callfunction' => 'clean_forum_notifications',
+                'minute'       => '30',
+                'hour'         => '22',
+            ),
         );
     }
 
+    public static function clean_forum_notifications() {
+        safe_require('notification', 'internal');
+        PluginNotificationInternal::clean_notifications(array('newpost'));
+    }
+
     /**
      * Subscribes the forum plugin to events
      *
@@ -267,6 +373,17 @@ class PluginInteractionForum extends PluginInteraction {
         );
     }
 
+    public static function menu_items() {
+        return array(
+            'groups/topics' => array(
+                'path' => 'groups/topics',
+                'url' => 'group/topics.php',
+                'title' => get_string('Topics', 'interaction.forum'),
+                'weight' => 60,
+            ),
+        );
+    }
+
     /**
      * When a user joins a group, subscribe them automatically to all forums 
      * that should be subscribable
@@ -365,19 +482,21 @@ class PluginInteractionForum extends PluginInteraction {
     public static function interaction_forum_new_post($postnow=null) {
         if (is_array($postnow) && !empty($postnow)) {
             $values = array();
-            $postswhere = 'id IN (' . join(',', $postnow) . ')';
+            $postswhere = 'id IN (' . join(',', array_map('intval', $postnow)) . ')';
+            $delay = false;
         }
         else {
             $currenttime = time();
             $minpostdelay = $currenttime - get_config_plugin('interaction', 'forum', 'postdelay') * 60;
             $values = array(db_format_timestamp($minpostdelay));
             $postswhere = 'ctime < ?';
+            $delay = null;
         }
         $posts = get_column_sql('SELECT id FROM {interaction_forum_post} WHERE sent = 0 AND deleted = 0 AND ' . $postswhere, $values);
         if ($posts) {
             set_field_select('interaction_forum_post', 'sent', 1, 'deleted = 0 AND sent = 0 AND ' . $postswhere, $values);
             foreach ($posts as $postid) {
-                activity_occurred('newpost', array('postid' => $postid), 'interaction', 'forum', (bool) $postnow);
+                activity_occurred('newpost', array('postid' => $postid), 'interaction', 'forum', $delay);
             }
         }
     }
@@ -426,6 +545,166 @@ class PluginInteractionForum extends PluginInteraction {
     public static function save_config_options($values) {
         set_config_plugin('interaction', 'forum', 'postdelay', $values['postdelay']);
     }
+
+    public static function get_active_topics($limit, $offset, $category) {
+        global $USER;
+
+        if (is_postgres()) {
+            $lastposts = '
+                    SELECT DISTINCT ON (topic) topic, id, poster, subject, body, ctime
+                    FROM {interaction_forum_post} p
+                    WHERE p.deleted = 0
+                    ORDER BY topic, ctime DESC';
+        }
+        else if (is_mysql()) {
+            $lastposts = '
+                    SELECT topic, id, poster, subject, body, ctime
+                    FROM (
+                        SELECT topic, id, poster, subject, body, ctime
+                        FROM {interaction_forum_post}
+                        WHERE deleted = 0
+                        ORDER BY ctime DESC
+                    ) temp1
+                    GROUP BY topic';
+        }
+
+        $from = '
+            FROM
+                {interaction_forum_topic} t
+                JOIN {interaction_instance} f ON t.forum = f.id
+                JOIN {group} g ON f.group = g.id
+                JOIN {group_member} gm ON (gm.group = g.id AND gm.member = ?)
+                JOIN {interaction_forum_post} first ON (first.topic = t.id AND first.parent IS NULL)
+                JOIN (' . $lastposts . '
+                ) last ON last.topic = t.id';
+
+        $values = array($USER->get('id'));
+
+        $where = '
+            WHERE g.deleted = 0 AND f.deleted = 0 AND t.deleted = 0';
+
+        if (!empty($category)) {
+            $where .= ' AND g.category = ?';
+            $values[] = (int) $category;
+        }
+
+        $result = array(
+            'count'  => count_records_sql('SELECT COUNT(*) ' . $from . $where, $values),
+            'limit'  => $limit,
+            'offset' => $offset,
+            'data'   => array(),
+        );
+
+        if (!$result['count']) {
+            return $result;
+        }
+
+        $select = '
+            SELECT
+                t.id, t.forum AS forumid, f.title AS forumname, g.id AS groupid, g.name AS groupname,
+                first.subject AS topicname, first.poster AS firstpostby,
+                last.id AS postid, last.poster, last.subject, last.body, last.ctime,
+                COUNT(posts.id) AS postcount';
+
+        $from .= '
+                LEFT JOIN {interaction_forum_post} posts ON posts.topic = t.id';
+
+        $sort = '
+            GROUP BY
+                t.id, t.forum, f.title, g.id, g.name,
+                first.subject, first.poster,
+                last.id, last.poster, last.subject, last.body, last.ctime
+            ORDER BY last.ctime DESC';
+
+        $result['data'] = get_records_sql_array($select . $from . $where . $sort, $values, $offset, $limit);
+
+        return $result;
+    }
+
+    // Rewrite download links in the post body to add a post id parameter.
+    // Used in download.php to determine permission to view the file.
+    static $replacement_postid;
+
+    public static function replace_download_link($matches) {
+        parse_str(html_entity_decode($matches[1]), $params);
+        if (empty($params['file'])) {
+            return $matches[0];
+        }
+        $url = get_config('wwwroot') . 'artefact/file/download.php?file=' . (int) $params['file'];
+        unset($params['post']);
+        unset($params['file']);
+        if (!empty($params)) {
+            $url .= '&' . http_build_query($params);
+        }
+        return $url . '&post=' . (int) self::$replacement_postid;
+    }
+
+    public static function prepare_post_body($body, $postid) {
+        self::$replacement_postid = $postid;
+        return preg_replace_callback(
+            '#(?<=[\'"])' . get_config('wwwroot') . 'artefact/file/download\.php\?(file=\d+(?:(?:&amp;|&)(?:[a-z]+=[x0-9]+)+)*)#',
+            array('self', 'replace_download_link'),
+            $body
+        );
+    }
+
+    /**
+     * Given a post id & the id of an image artefact, check that the logged-in user
+     * has permission to see the image in the context of the post.
+     */
+    public static function can_see_attached_file($file, $postid) {
+        global $USER;
+        require_once('group.php');
+
+        if (!$file instanceof ArtefactTypeImage) {
+            return false;
+        }
+
+        $post = get_record_sql('
+            SELECT
+                p.body, p.poster, g.id AS groupid, g.public
+            FROM {interaction_forum_post} p
+            INNER JOIN {interaction_forum_topic} t ON (t.id = p.topic AND t.deleted = 0)
+            INNER JOIN {interaction_forum_post} fp ON (fp.parent IS NULL AND fp.topic = t.id)
+            INNER JOIN {interaction_instance} f ON (t.forum = f.id AND f.deleted = 0)
+            INNER JOIN {group} g ON (f.group = g.id AND g.deleted = 0)
+            WHERE p.id = ? AND p.deleted = 0',
+            array($postid)
+        );
+
+        if (!$post) {
+            return false;
+        }
+
+        if (!$post->public && !group_user_access($post->groupid, $USER->get('id'))) {
+            return false;
+        }
+
+        // Check that the author of the post is allowed to publish the file
+        $poster = new User();
+        $poster->find_by_id($post->poster);
+        if (!$poster->can_publish_artefact($file)) {
+            return false;
+        }
+
+        // Load the post as an html fragment & make sure it has the image in it
+        $page = new DOMDocument();
+        libxml_use_internal_errors(true);
+        $success = $page->loadHTML($post->body);
+        libxml_use_internal_errors(false);
+        if (!$success) {
+            return false;
+        }
+        $xpath = new DOMXPath($page);
+        $srcstart = get_config('wwwroot') . 'artefact/file/download.php?file=' . $file->get('id') . '&';
+        $query = '//img[starts-with(@src,"' . $srcstart . '")]';
+        $elements = $xpath->query($query);
+        if ($elements->length < 1) {
+            return false;
+        }
+
+        return true;
+    }
 }
 
 class InteractionForumInstance extends InteractionInstance {
@@ -448,6 +727,7 @@ class InteractionForumInstance extends InteractionInstance {
 class ActivityTypeInteractionForumNewPost extends ActivityTypePlugin {
 
     protected $postid;
+    protected $temp;
 
     public function __construct($data) {
         parent::__construct($data);
@@ -497,51 +777,60 @@ class ActivityTypeInteractionForumNewPost extends ActivityTypePlugin {
             $this->customheaders[] = 'References: <forumpost' . $post->parent . '@' . $hostname . '>';
         }
 
-        $posttime = strftime(get_string('strftimedaydatetime'), $post->ctime);
-        $htmlbody = $post->body;
-        $textbody = trim(html2text($post->body));
-        $postlink = get_config('wwwroot') . 'interaction/forum/topic.php?id=' . $post->topicid . '#post' . $this->postid;
+        $post->posttime = strftime(get_string('strftimedaydatetime'), $post->ctime);
+        $this->message = strip_tags(str_shorten_html($post->body, 200, true)); // For internal notifications.
+
+        $post->textbody = trim(html2text($post->body));
+        $post->htmlbody = clean_html($post->body);
+        $this->url = get_config('wwwroot') . 'interaction/forum/topic.php?id=' . $post->topicid . '#post' . $this->postid;
+
+        $this->add_urltext(array(
+            'key'     => 'Topic',
+            'section' => 'interaction.forum'
+        ));
+
+        $this->strings->subject = (object) array(
+            'key'     => $post->parent ? 'replyforumpostnotificationsubject' : 'newforumpostnotificationsubject',
+            'section' => 'interaction.forum',
+            'args'    => array($post->groupname, $post->forumtitle, $post->parent ? $post->topicsubject : $post->subject),
+        );
 
         foreach ($this->users as &$user) {
-            $lang = (empty($user->lang) || $user->lang == 'default') ? get_config('lang') : $user->lang;
-            if ($post->parent) {
-                $user->subject = get_string_from_language($lang, 'replyforumpostnotificationsubject', 'interaction.forum', $post->groupname, $post->forumtitle, $post->topicsubject);
-            }
-            else {
-                $user->subject = get_string_from_language($lang, 'newforumpostnotificationsubject', 'interaction.forum', $post->groupname, $post->forumtitle, $post->subject);
-            }
-
-            $type = $subscribers[$user->id]->type;
-            $unsubscribeid = $post->{$type . 'id'};
-            $unsubscribelink = get_config('wwwroot') . 'interaction/forum/unsubscribe.php?' . $type . '=' . $unsubscribeid . '&key=' . $subscribers[$user->id]->key;
-
-            $user->message = get_string_from_language($lang, 'forumposttemplate', 'interaction.forum',
-                $post->subject ? $post->subject : get_string_from_language($lang, 're', 'interaction.forum', $post->topicsubject),
-                display_name($post->poster, $user),
-                $posttime,
-                $textbody,
-                $postlink,
-                $type,
-                $unsubscribelink
-            );
-            $user->htmlmessage = get_string_from_language($lang, 'forumposthtmltemplate', 'interaction.forum',
-                $post->subject ? $post->subject : get_string_from_language($lang, 're', 'interaction.forum', $post->topicsubject),
-                display_name($post->poster, $user),
-                $posttime,
-                $htmlbody,
-                $postlink,
-                $unsubscribelink,
-                $type
-            );
+            $user->subscribetype = $subscribers[$user->id]->type;
+            $user->unsubscribekey = $subscribers[$user->id]->key;
         }
+
+        $this->temp = (object) array('post' => $post);
     }
 
-    public function get_subject($user) {
-        return $user->subject;
+    public function get_emailmessage($user) {
+        $post = $this->temp->post;
+        $unsubscribeid = $post->{$user->subscribetype . 'id'};
+        $unsubscribelink = get_config('wwwroot') . 'interaction/forum/unsubscribe.php?' . $user->subscribetype . '=' . $unsubscribeid . '&key=' . $user->unsubscribekey;
+        return get_string_from_language($user->lang, 'forumposttemplate', 'interaction.forum',
+            $post->subject ? $post->subject : get_string_from_language($user->lang, 're', 'interaction.forum', $post->topicsubject),
+            display_name($post->poster, $user),
+            $post->posttime,
+            $post->textbody,
+            $this->url,
+            $user->subscribetype,
+            $unsubscribelink
+        );
     }
 
-    public function get_message($user) {
-        return $user->message;
+    public function get_htmlmessage($user) {
+        $post = $this->temp->post;
+        $unsubscribeid = $post->{$user->subscribetype . 'id'};
+        $unsubscribelink = get_config('wwwroot') . 'interaction/forum/unsubscribe.php?' . $user->subscribetype . '=' . $unsubscribeid . '&key=' . $user->unsubscribekey;
+        return get_string_from_language($user->lang, 'forumposthtmltemplate', 'interaction.forum',
+            $post->subject ? hsc($post->subject) : get_string_from_language($user->lang, 're', 'interaction.forum', hsc($post->topicsubject)),
+            hsc(display_name($post->poster, $user)),
+            $post->posttime,
+            $post->htmlbody,
+            $this->url,
+            $unsubscribelink,
+            $user->subscribetype
+        );
     }
 
     public function get_plugintype(){
@@ -610,12 +899,16 @@ function user_can_access_forum($forumid, $userid=null) {
  *
  * @returns boolean
  */
-function user_can_edit_post($poster, $posttime, $userid=null) {
+function user_can_edit_post($poster, $posttime, $userid=null, $verifydelay=true) {
 	if (empty($userid)) {
         global $USER;
         $userid = $USER->get('id');
     }
-    return $poster == $userid && $posttime > (time() - get_config_plugin('interaction', 'forum', 'postdelay') * 60);
+    $permitted = true;
+    if ($verifydelay) {
+        $permitted = $posttime > (time() - get_config_plugin('interaction', 'forum', 'postdelay') * 60);
+    }
+    return $poster == $userid && $permitted;
 }
 
 /**
@@ -693,5 +986,3 @@ function subscribe_forum_submit(Pieform $form, $values) {
         redirect('/interaction/forum/view.php?id=' . $values['forum'] . '&offset=' . $values['offset']);
     }
 }
-
-?>
