@@ -44,13 +44,13 @@ $topic = get_record_sql(
     'SELECT p.subject, p.poster, p.id AS firstpost, ' . db_format_tsfield('p.ctime', 'ctime') . ', t.id, f.group AS groupid, g.name AS groupname, f.id AS forumid, f.title AS forumtitle, t.closed, sf.forum AS forumsubscribed, st.topic AS topicsubscribed
     FROM {interaction_forum_topic} t
     INNER JOIN {interaction_instance} f ON (t.forum = f.id AND f.deleted != 1)
-    INNER JOIN {group} g ON (g.id = f.group AND g.deleted = ?)
+    INNER JOIN {group} g ON (g.id = f.group AND g.deleted = 0)
     INNER JOIN {interaction_forum_post} p ON (p.topic = t.id AND p.parent IS NULL)
     LEFT JOIN {interaction_forum_subscription_forum} sf ON (sf.forum = f.id AND sf.user = ?)
     LEFT JOIN {interaction_forum_subscription_topic} st ON (st.topic = t.id AND st.user = ?)
     WHERE t.id = ?
     AND t.deleted != 1',
-    array(0, $USER->get('id'), $USER->get('id'), $topicid)
+    array($USER->get('id'), $USER->get('id'), $topicid)
 );
 
 if (!$topic) {
@@ -59,9 +59,16 @@ if (!$topic) {
 
 define('GROUP', $topic->groupid);
 
+$publicgroup = get_field('group', 'public', 'id', $topic->groupid);
+$feedlink = get_config('wwwroot') . 'interaction/forum/atom.php?type=t&id=' . $topic->id;
+
 $membership = user_can_access_forum((int)$topic->forumid);
 $moderator = (bool)($membership & INTERACTION_FORUM_MOD);
 
+$forumconfig = get_records_assoc('interaction_forum_instance_config', 'forum', $topic->forumid, '', 'field,value');
+$indentmode = isset($forumconfig['indentmode']) ? $forumconfig['indentmode']->value : 'full_indent';
+$maxindentdepth = isset($forumconfig['maxindent']) ? $forumconfig['maxindent']->value : 10;
+
 if (!$membership
     && !get_field('group', 'public', 'id', $topic->groupid)) {
     throw new GroupAccessDeniedException(get_string('cantviewtopic', 'interaction.forum'));
@@ -145,50 +152,181 @@ for ($i = 0; $i < $count; $i++) {
     $posts[$temp]->edit = $postedits;
 }
 
-// builds the first post (with index 0) which has as children all the posts in the topic
-$posts = buildpost(0, '', $posts);
+// If the user has internal notifications for this topic, mark them
+// all as read.  Obviously there's no guarantee the user will actually
+// read all the posts on this page, but better than letting the unread
+// notifications grow too fast.  Unfortunately the only way to find
+// notifications on this topic is to look for the url of this page.
+execute_sql('
+    UPDATE {notification_internal_activity}
+    SET "read" = 1
+    WHERE "read" = 0 AND usr = ? AND url LIKE ? || \'%\' AND type = (
+        SELECT id FROM {activity_type} WHERE name = ?
+    )',
+    array(
+        $USER->get('id'),
+        get_config('wwwroot') . 'interaction/forum/topic.php?id=' . $topicid . '#post',
+        'newpost',
+    )
+);
 
-$smarty = smarty();
+// builds the first post (with index 0) which has as children all the posts in the topic
+$posts = buildpostlist($posts, $indentmode, $maxindentdepth);
+
+$headers = array();
+if ($publicgroup) {
+    $headers[] = '<link rel="alternate" type="application/atom+xml" href="' . $feedlink . '" />';
+}
+
+$smarty = smarty(array(), $headers, array(), array());
 $smarty->assign('topic', $topic);
 $smarty->assign('membership', $membership);
 $smarty->assign('moderator', $moderator);
 $smarty->assign('posts', $posts);
 $smarty->display('interaction:forum:topic.tpl');
 
-/**
- * builds a post (including its children)
+function buildpostlist(&$posts, $mode, $max_depth) {
+    buildsubjects(0, '', $posts);
+    switch ($mode) {
+        case 'no_indent':
+            return buildflatposts($posts);
+            break;
+        case 'max_indent':
+            $new_posts = array();
+            buildmaxindentposts(0, $posts, $max_depth);
+            $new_posts = buildpost(0, $posts);
+            return renderpost($new_posts);
+            break;
+        case 'full_indent':
+        default:
+            $new_posts = buildpost(0, $posts);
+            return renderpost($new_posts);
+            break;
+    }
+}
+
+
+/*
+ * Sorts posts so that if there parent is too deep will take the nearest ancestor of the right depth
  *
- * @param int $postindex the index of the post
- * @param string $parentsubject the subject of the parent
- * @param array $posts the posts in the topic
- *
- * @returns string the html for the post
+ * @param int $postindex the current index
+ * @param array $posts list of posts
+ * @param int $max_depth the maximum depth to indent to
+ * @oaram int $current_depth the current depth
+ * @param int $current_parent the current post parent/ancestor
  */
 
-function buildpost($postindex, $parentsubject, &$posts){
+function buildmaxindentposts($postindex, &$posts, $max_depth, $current_depth = 0, $current_parent = 0) {
     global $moderator, $topic, $groupadmins;
     $localposts = $posts;
+
+    $current_depth++;
+    foreach ($localposts as $index => $post) {
+        if ($posts[$index]->parent == $posts[$postindex]->id) {
+            if ($current_depth < $max_depth) {
+                $current_parent = $posts[$postindex]->id;
+            } else {
+                $posts[$index]->parent = $current_parent;
+            }
+            buildmaxindentposts($index, $posts, $max_depth, $current_depth, $current_parent);
+        }
+    }
+}
+
+/*
+ * Renders a post and its children
+ *
+ * @param object $post post object
+ *
+ * @return string html output
+ */
+
+function renderpost($post) {
+    global $moderator, $topic, $groupadmins;
+    $children = array();
+    if (isset($post->children) && !empty($post->children)) {
+        foreach ($post->children as $index=>$child_post) {
+            $children[] = renderpost($child_post);
+        }
+    }
+    $membership = user_can_access_forum((int)$topic->forumid);
+    $smarty = smarty_core();
+    $smarty->assign('post', $post);
+    $smarty->assign('groupadmins', $groupadmins);
+    $smarty->assign('children', $children);
+    $smarty->assign('moderator', $moderator);
+    $smarty->assign('membership', $membership);
+    $smarty->assign('closed', $topic->closed);
+    return $smarty->fetch('interaction:forum:post.tpl');
+}
+
+/**
+ * Builds a flat list of posts
+ *
+ * @param array $posts the posts in the topic
+ *
+ * @returns string the html for the topc
+ */
+
+function buildflatposts(&$posts) {
+    $localposts = $posts;
+    $first_post = array_shift($localposts);
+    if (!isset($first_post->subject) || empty($first_post->subject)) {
+        $first_post->subject = get_string('re', 'interaction.forum', '');
+    }
+
+    $children = array();
+    foreach ($localposts as $index => $post) {
+        $children[] = $post;
+    }
+    $first_post->children = $children;
+    return renderpost($first_post);
+}
+
+/*
+ * Builds subjects for the topic
+ *
+ * @param int $postindex index of the post
+ * @param string $parentsubject subject title of the parent post
+ * @param array $posts the posts in the topic
+ */
+
+function buildsubjects($postindex, $parentsubject, &$posts) {
+    $localposts = $posts;
     if ($posts[$postindex]->subject) {
         $parentsubject = $posts[$postindex]->subject;
     }
     else {
         $posts[$postindex]->subject = get_string('re', 'interaction.forum', $parentsubject);
     }
+    foreach ($localposts as $index => $post) {
+        if ($posts[$index]->parent == $posts[$postindex]->id) {
+            buildsubjects($index, $parentsubject, $posts);
+        }
+    }
+}
+
+/**
+ * Sorts children posts into their parent
+ * 
+ * @param int $postindex the index of the post
+ * @param array $posts the posts in the topic
+ *
+ * @returns array the html for the post
+ */
+
+function buildpost($postindex, &$posts){
+    global $moderator, $topic, $groupadmins;
+    $localposts = $posts;
+
     $children = array();
     foreach ($localposts as $index => $post) {
         if ($posts[$index]->parent == $posts[$postindex]->id) {
-            $children[] = buildpost($index, $parentsubject, $posts);
+            $children[] = buildpost($index, $posts);
         }
     }
-    $membership = user_can_access_forum((int)$topic->forumid);
-    $smarty = smarty_core();
-    $smarty->assign('post', $posts[$postindex]);
-    $smarty->assign('groupadmins', $groupadmins);
-    $smarty->assign('children', $children);
-    $smarty->assign('moderator', $moderator);
-    $smarty->assign('membership', $membership);
-    $smarty->assign('closed', $topic->closed);
-    return $smarty->fetch('interaction:forum:post.tpl');
+    $posts[$postindex]->children = $children;
+    return $posts[$postindex];
 }
 
 function subscribe_topic_validate(Pieform $form, $values) {
@@ -220,5 +358,3 @@ function subscribe_topic_submit(Pieform $form, $values) {
     }
     redirect('/interaction/forum/topic.php?id=' . $values['topic']);
 }
-
-?>
