@@ -1,8 +1,24 @@
 /**
  * Javascript side of the accessible pagination for Mahara.
+ * @source: http://gitorious.org/mahara/mahara
  *
- * Copyright: 2006-2008 Catalyst IT Ltd
- * This file is licensed under the same terms as Mahara itself
+ * @licstart
+ * Copyright (C) 2006-2010  Catalyst IT Ltd
+ *
+ * The JavaScript code in this page is free software: you can
+ * redistribute it and/or modify it under the terms of the GNU
+ * General Public License (GNU GPL) as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option)
+ * any later version.  The code is distributed WITHOUT ANY WARRANTY;
+ * without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU GPL for more details.
+ *
+ * As additional permission under GNU GPL version 3 section 7, you
+ * may distribute non-source (e.g., minimized or compacted) forms of
+ * that code without the copy of the GNU GPL normally required by
+ * section 4, provided you include this license notice and a URL
+ * through which recipients can access the Corresponding Source.
+ * @licend
  */
 
 /**
@@ -28,7 +44,7 @@ var Paginator = function(id, datatable, script, extradata) {
     }
 
     this.rewritePaginatorLinks = function() {
-        forEach(getElementsByTagAndClassName('span', 'pagination'), function(i) {
+        forEach(getElementsByTagAndClassName('span', 'pagination', self.id), function(i) {
             var a = getFirstElementByTagAndClassName('a', null, i);
 
             // If there is a link
@@ -52,6 +68,16 @@ var Paginator = function(id, datatable, script, extradata) {
             else {
                 tbody.innerHTML = data['data']['tablerows'];
             }
+
+            // Pieforms should probably separate its js from its html. For
+            // now, be evil: scrape it out of the script elements and eval
+            // it every time the page changes.
+            forEach(getElementsByTagAndClassName('script', null, tbody), function(s) {
+                var m = scrapeText(s).match(new RegExp('^(new Pieform\\\(.*?\\\);)$'));
+                if (m && m[1]) {
+                    eval('var pf = ' + m[1] + ' pf.init();');
+                }
+            });
         }
 
         // Update the pagination
