@@ -28,6 +28,7 @@
 define('INTERNAL', 1);
 define('JSON', 1);
 define('PUBLIC', 1);
+define('NOSESSKEY', 1);
 
 require(dirname(dirname(__FILE__)) . '/init.php');
 
@@ -47,8 +48,4 @@ if (empty($data)) {
 }
 
 $json = array('error' => false, 'content' => $data);
-echo json_encode($json);
-exit;
-
-
-?>
+json_reply(false, $json);
