@@ -52,6 +52,10 @@ $string['membershiptype.controlled'] = 'Controlled Membership';
 $string['membershiptype.invite']     = 'Invite Only';
 $string['membershiptype.request']    = 'Request Membership';
 $string['membershiptype.open']       = 'Open Membership';
+$string['membershiptype.abbrev.controlled'] = 'Controlled';
+$string['membershiptype.abbrev.invite']     = 'Invite';
+$string['membershiptype.abbrev.request']    = 'Request';
+$string['membershiptype.abbrev.open']       = 'Open';
 $string['pendingmembers']            = 'Pending Members';
 $string['reason']                    = 'Reason';
 $string['approve']                   = 'Approve';
@@ -60,16 +64,37 @@ $string['groupalreadyexists'] = 'A Group by this name already exists';
 $string['Created'] = 'Created';
 $string['groupadmins'] = 'Group admins';
 $string['Admin'] = 'Admin';
-$string['grouptype'] = 'Group Type';
+$string['grouptype'] = 'Group type';
 $string['publiclyviewablegroup'] = 'Publicly Viewable Group?';
-$string['publiclyviewablegroupdescription'] = 'Allow anyone (including people who aren\'t members of this site) to view this group, including the forums?';
+$string['publiclyviewablegroupdescription'] = 'Allow people who are not logged-in to view this group, including the forums?';
+$string['Type'] = 'Type';
+$string['publiclyvisible'] = 'Publicly visible';
+$string['Public'] = 'Public';
 $string['usersautoadded'] = 'Users auto-added?';
 $string['usersautoaddeddescription'] = 'Automatically put all new users into this group?';
-
+$string['groupcategory'] = 'Group category';
+$string['allcategories'] = 'All categories';
+$string['groupoptionsset'] = 'Group options have been updated.';
+$string['nocategoryselected'] = 'No category selected';
+$string['categoryunassigned'] = 'Category unassigned';
 $string['hasrequestedmembership'] = 'has requested membership of this group';
 $string['hasbeeninvitedtojoin'] = 'has been invited to join this group';
 $string['groupinvitesfrom'] = 'Invited to join:';
 $string['requestedmembershipin'] = 'Requested membership in:';
+$string['viewnotify'] = 'Shared page notifications';
+$string['viewnotifydescription'] = 'If checked, a notification will be sent to every group member whenever a member shares one of their pages with the group.  Enabling this setting in very large groups can produce a lot of notifications.';
+
+$string['editgroupmembership'] = 'Edit group membership';
+$string['editmembershipforuser'] = 'Edit membership for %s';
+$string['changedgroupmembership'] = 'Group membership updated sucessfully.';
+$string['changedgroupmembershipsubject'] = 'Your group memberships have been changed';
+$string['addedtogroupsmessage'] = "%s has added you to the group(s):\n\n%s\n\n";
+$string['removedfromgroupsmessage'] = "%s has removed you from the group(s):\n\n%s\n\n";
+$string['cantremoveuserisadmin'] = "Tutor cannot remove admins and other tutorsmembers.";
+$string['cantremovemember'] = "Tutor cannot remove members.";
+$string['current'] = "Current";
+$string['requests'] = "Requests";
+$string['invites'] = "Invites";
 
 // Used to refer to all the members of a group - NOT a "member" group role!
 $string['member'] = 'member';
@@ -78,16 +103,16 @@ $string['Members'] = 'Members';
 
 $string['memberrequests'] = 'Membership requests';
 $string['declinerequest'] = 'Decline request';
-$string['submittedviews'] = 'Submitted views';
-$string['releaseview'] = 'Release view';
+$string['submittedviews'] = 'Submitted pages';
+$string['releaseview'] = 'Release page';
 $string['invite'] = 'Invite';
 $string['remove'] = 'Remove';
 $string['updatemembership'] = 'Update membership';
 $string['memberchangefailed'] = 'Failed to update some membership information';
 $string['memberchangesuccess'] = 'Membership status changed successfully';
-$string['viewreleasedsubject'] = 'Your view has been released';
-$string['viewreleasedmessage'] = 'The view that you submitted to %s has been released back to you by %s';
-$string['viewreleasedsuccess'] = 'View was released successfully';
+$string['viewreleasedsubject'] = 'Your page "%s" has been released from %s by %s';
+$string['viewreleasedmessage'] = 'Your page "%s" has been released from %s by %s';
+$string['viewreleasedsuccess'] = 'Page was released successfully';
 $string['groupmembershipchangesubject'] = 'Group membership: %s';
 $string['groupmembershipchangedmessagetutor'] = 'You have been promoted to a tutor in this group';
 $string['groupmembershipchangedmessagemember'] = 'You have been demoted from a tutor in this group';
@@ -121,9 +146,9 @@ $string['grouprequestsubject'] = 'New group membership request';
 $string['grouprequestmessage'] = '%s would like to join your group %s';
 $string['grouprequestmessagereason'] = "%s would like to join your group %s. Their reason for wanting to join is:\n\n%s";
 $string['cantdeletegroup'] = 'You cannot delete this group';
-$string['groupconfirmdelete'] = 'Are you sure you wish to delete this group?';
-$string['groupconfirmdeletehasviews'] = 'Are you sure you wish to delete this group? Some of your views use this group for access control, removing this group would mean that the members of that group would not have access to the views.';
+$string['groupconfirmdelete'] = "This will delete all pages, files, and forums contained within the group.  Are you sure you wish to fully delete this group and all its content?";
 $string['deletegroup'] = 'Group Deleted Successfully';
+$string['deletegroup1'] = 'Delete Group';
 $string['allmygroups'] = 'All My Groups';
 $string['groupsimin']  = 'Groups I\'m In';
 $string['groupsiown']  = 'Groups I Own';
@@ -132,7 +157,6 @@ $string['groupsiwanttojoin'] = 'Groups I Want To Join';
 $string['requestedtojoin'] = 'You have requested to join this group';
 $string['groupnotfound'] = 'Group with id %s not found';
 $string['groupconfirmleave'] = 'Are you sure you want to leave this group?';
-$string['groupconfirmleavehasviews'] = 'Are you sure you want to leave this group? Some of your views use this group for access control, leaving this group would mean that the members of the group would not have access to the views';
 $string['cantleavegroup'] = 'You can\'t leave this group';
 $string['usercantleavegroup'] = 'This user cannot leave this group';
 $string['usercannotchangetothisrole'] = 'The user cannot change to this role';
@@ -141,18 +165,32 @@ $string['memberslist'] = 'Members: ';
 $string['nogroups'] = 'No groups';
 $string['deletespecifiedgroup'] = 'Delete group \'%s\'';
 $string['requestjoinspecifiedgroup'] = 'Request to join group \'%s\'';
-$string['youaregroupmember'] = 'You are  a member of this group';
+$string['youaregroupmember'] = 'You are a member of this group';
+$string['youaregrouptutor'] = 'You are a tutor in this group';
+$string['youaregroupadmin'] = 'You are an admin in this group';
 $string['youowngroup'] = 'You own this group';
 $string['groupsnotin'] = 'Groups I\'m not in';
 $string['allgroups'] = 'All groups';
 $string['allgroupmembers'] = 'All group members';
 $string['trysearchingforgroups'] = 'Try %ssearching for groups%s to join!';
-$string['nogroupsfound'] = 'No groups found :(';
+$string['nogroupsfound'] = 'No groups found.';
 $string['group'] = 'group';
 $string['Group'] = 'Group';
 $string['groups'] = 'groups';
 $string['notamember'] = 'You are not a member of this group';
 $string['notmembermayjoin'] = 'You must join the group \'%s\' to see this page.';
+$string['declinerequestsuccess'] = 'Group membership request has been declined sucessfully.';
+$string['notpublic'] = 'This group is not public.';
+$string['moregroups'] = 'More groups';
+
+// Bulk add, invite
+$string['addmembers'] = 'Add members';
+$string['invitationssent'] = '%d invitations sent';
+$string['newmembersadded'] = 'Added %d new members';
+$string['potentialmembers'] = 'Potential members';
+$string['sendinvitations'] = 'Send invitations';
+$string['userstobeadded'] = 'Users to be added';
+$string['userstobeinvited'] = 'Users to be invited';
 
 // friendslist
 $string['reasonoptional'] = 'Reason (optional)';
@@ -167,7 +205,7 @@ $string['friendformrejectsuccess'] = 'Rejected friend request';
 $string['addtofriendslist'] = 'Add to friends';
 $string['requestfriendship'] = 'Request friendship';
 
-$string['addedtofriendslistsubject'] = 'New friend';
+$string['addedtofriendslistsubject'] = '%s has added you as a friend';
 $string['addedtofriendslistmessage'] = '%s added you as a friend! This means that %s is also on your friend list now too. '
     . ' Click on the link below to see their profile page';
 
@@ -191,6 +229,7 @@ $string['cantremovefriend'] = 'You cannot remove this user from your friends lis
 $string['friendshipalreadyrequested'] = 'You have requested to be added to %s\'s friends list';
 $string['friendshipalreadyrequestedowner'] = '%s has requested to be added to your friends list';
 $string['rejectfriendshipreason'] = 'Reason for rejecting request';
+$string['alreadyfriends'] = 'You are already friends with %s';
 
 $string['friendrequestacceptedsubject'] = 'Friend request accepted';
 $string['friendrequestacceptedmessage'] = '%s has accepted your friend request and they have been added to your friends list'; 
@@ -203,9 +242,9 @@ $string['currentfriends'] = 'Current Friends';
 $string['pendingfriends'] = 'Pending friends';
 $string['backtofriendslist'] = 'Back to Friends List';
 $string['findnewfriends'] = 'Find New Friends';
-$string['Views']          = 'Views';
+$string['Views']          = 'Pages';
 $string['Files']          = 'Files';
-$string['seeallviews']    = 'See all %s views...';
+$string['seeallviews']    = 'See all %s pages...';
 $string['noviewstosee']   = 'None that you can see :(';
 $string['whymakemeyourfriend'] = 'This is why you should make me your friend:';
 $string['approverequest'] = 'Approve Request!';
@@ -245,7 +284,6 @@ $string['Reply'] = 'Reply';
 $string['denyfriendrequest'] = 'Deny Friend Request';
 $string['sendfriendshiprequest'] = 'Send %s a friendship request';
 $string['cantdenyrequest'] = 'That is not a valid friendship request';
-$string['cantrequestfrienship'] = 'You cannot request frienship from this user';
 $string['cantmessageuser'] = 'You cannot send this user a message';
 $string['cantviewmessage'] = 'You cannot view this message';
 $string['requestedfriendship'] = 'requested friendship';
@@ -273,14 +311,18 @@ $string['Role'] = 'Role';
 $string['changerole'] = 'Change role';
 $string['changeroleofuseringroup'] = 'Change role of %s in %s';
 $string['currentrole'] = 'Current role';
-$string['changeroleto'] = 'Change role to';
+$string['changerolefromto'] = 'Change role from %s to';
 $string['rolechanged'] = 'Role changed';
 $string['removefromgroup'] = 'Remove from group';
 $string['userremoved'] = 'User removed';
 $string['About'] = 'About';
+$string['aboutgroup'] = 'About %s';
 
 $string['Joined'] = 'Joined';
 
-$string['instructions:invite'] = 'This is an invite-only group. Invite users through their profile pages.';
-$string['instructions:controlled'] = 'This is a controlled membership group. Add users through their profile pages.';
-?>
+$string['membersdescription:invite'] = 'This is an invite-only group. You can invite users through their profile pages or <a href="%s">send multiple invitations at once</a>.';
+$string['membersdescription:controlled'] = 'This is a controlled membership group. You can add users through their profile pages or <a href="%s">add many users at once</a>.';
+
+// View submission
+$string['submit'] = 'Submit';
+$string['allowssubmissions'] = 'Allows submissions';
