@@ -50,6 +50,7 @@ $string['description'] = 'Description';
 $string['remove']  = 'Remove';
 $string['Close'] = 'Close';
 $string['Help'] = 'Help';
+$string['applychanges'] = 'Apply changes';
 
 $string['no']     = 'No';
 $string['yes']    = 'Yes';
@@ -61,9 +62,13 @@ $string['All'] = 'All';
 
 $string['enable'] = 'Enable';
 $string['disable'] = 'Disable';
-$string['pluginenabled'] = 'Plugin enabled';
-$string['plugindisabled'] = 'Plugin disabled';
-$string['pluginnotenabled'] = 'Plugin not enabled.  You must enable the %s plugin first.';
+$string['show'] = 'Show';
+$string['hide'] = 'Hide';
+$string['pluginenabled'] = 'The plugin has is now visible.';
+$string['plugindisabled'] = 'The plugin has been hidden.';
+$string['pluginnotenabled'] = 'Plugin is hidden.  You must make the %s plugin visible first.';
+$string['pluginexplainaddremove'] = 'Plugins in Mahara are always installed and can be accessed if users know the URLs and would otherwise have access. Rather than enabling and disabling the functionality, plugins are hidden or made visible by clicking on the \'Hide\' or \'Show\' links beside the plugins below.';
+$string['pluginexplainartefactblocktypes'] = 'When hiding an \'artefact\' type plugin, the Mahara system also stops the display of the blocks related to it.';
 
 $string['next']      = 'Next';
 $string['nextpage']  = 'Next page';
@@ -96,12 +101,14 @@ $string['sortalpha'] = 'Sort tags alphabetically';
 $string['sortfreq'] = 'Sort tags by frequency';
 $string['sortresultsby'] = 'Sort results by:';
 $string['date'] = 'Date';
+$string['dateformatguide'] = 'Use the format YYYY/MM/DD';
+$string['datetimeformatguide'] = 'Use the format YYYY/MM/DD HH:MM';
 $string['filterresultsby'] = 'Filter results by:';
 $string['tagfilter_all'] = 'All';
 $string['tagfilter_file'] = 'Files';
 $string['tagfilter_image'] = 'Images';
 $string['tagfilter_text'] = 'Text';
-$string['tagfilter_view'] = 'Views';
+$string['tagfilter_view'] = 'Pages';
 $string['edittags'] = 'Edit Tags';
 $string['selectatagtoedit'] = 'Select a tag to edit';
 $string['edittag'] = 'Edit <a href="%s">%s</a>';
@@ -124,13 +131,13 @@ $string['updatefailed'] = 'Update failed';
 $string['strftimenotspecified']  = 'Not specified';
 
 // profile sideblock strings
-$string['invitedgroup'] = 'group invited to';
-$string['invitedgroups'] = 'groups invited to';
+$string['invitedgroup'] = 'group invitation';
+$string['invitedgroups'] = 'group invitations';
 $string['logout'] = 'Logout';
 $string['pendingfriend'] = 'pending friend';
 $string['pendingfriends'] = 'pending friends';
 $string['profile'] = 'profile';
-$string['views'] = 'Views';
+$string['views'] = 'Pages';
 
 // Online users sideblock strings
 $string['onlineusers'] = 'Online users';
@@ -285,10 +292,9 @@ $string['accountinactivewarninghtml'] = '<p>Dear %s,</p>
 <p>You can prevent your account from becoming inactive by logging in.</p>
 
 <p>Regards, %s Site Administrator</p>';
-$string['accountsuspended'] = 'Your account has been suspeneded as of %s. The reason for your suspension is:<blockquote>%s</blockquote>';
-$string['youraccounthasbeensuspended'] = 'Your account has been suspeneded';
-$string['youraccounthasbeenunsuspended'] = 'Your account has been unsuspeneded';
-$string['changepassword'] = 'Change Password';
+$string['accountsuspended'] = 'Your account has been suspended as of %s. The reason for your suspension is:<blockquote>%s</blockquote>';
+$string['youraccounthasbeensuspended'] = 'Your account has been suspended';
+$string['youraccounthasbeenunsuspended'] = 'Your account has been unsuspended';
 $string['changepasswordinfo'] = 'You are required to change your password before you can proceed.';
 $string['chooseusernamepassword'] = 'Choose your username and password';
 $string['chooseusernamepasswordinfo'] = 'You need a username and password to log in to %s.  Please choose them now.';
@@ -319,16 +325,12 @@ $string['preferredname'] = 'Display Name';
 $string['usernamedescription'] = ' ';
 $string['usernamehelp'] = 'The username you have been given to access this system.';
 $string['youaremasqueradingas'] = 'You are masquerading as %s.';
-$string['yournewpassword'] = 'Your new password';
+$string['yournewpassword'] = 'Your new password. Passwords must be at least six characters long and contain at least one digit and two letters';
 $string['yournewpasswordagain'] = 'Your new password again';
 $string['invalidsesskey'] = 'Invalid session key';
 $string['cannotremovedefaultemail'] = 'You cannot remove your primary email address';
 $string['emailtoolong'] = 'E-mail addresses cannot be longer that 255 characters';
 $string['mustspecifyoldpassword'] = 'You must specify your current password';
-$string['captchatitle'] = 'CAPTCHA Image';
-$string['captchaimage'] = 'CAPTCHA Image';
-$string['captchadescription'] = 'Enter the characters you see in the picture. Letters are not case sensitive';
-$string['captchaincorrect'] = 'Enter the letters as they are shown in the image';
 $string['Site'] = 'Site';
 
 // Misc. register stuff that could be used elsewhere
@@ -341,8 +343,10 @@ $string['lastnamedescription'] = ' ';
 $string['studentid'] = 'ID number';
 $string['displayname'] = 'Display name';
 $string['fullname'] = 'Full name';
-$string['registerstep1description'] = 'Welcome! To use this site you must first register. You must also agree to the <a href="terms.php">terms and conditions</a>. The data we collect here will be stored according to our <a href="privacy.php">privacy statement</a>.';
-$string['registerstep3fieldsoptional'] = '<h3>Choose an Optional Profile Image</h3><p>You have now successfully registered with %s! You may now choose an optional profile icon to be displayed as your avatar.</p>';
+$string['registerwelcome'] = 'Welcome! To use this site you must first register.';
+$string['registeragreeterms'] = 'You must also agree to the <a href="terms.php">terms and conditions</a>.';
+$string['registerprivacy'] = 'The data we collect here will be stored according to our <a href="privacy.php">privacy statement</a>.';
+$string['registerstep3fieldsoptional'] = '<h3>Choose an Optional Profile Image</h3><p>You have now successfully registered with %s! You may now choose an optional profile picture to be displayed as your avatar.</p>';
 $string['registerstep3fieldsmandatory'] = '<h3>Fill Out Mandatory Profile Fields</h3><p>The following fields are required. You must fill them out before your registration is complete.</p>';
 $string['registeringdisallowed'] = 'Sorry, you cannot register for this system at this time';
 $string['membershipexpiry'] = 'Membership expires';
@@ -393,7 +397,7 @@ $string['forgotusernamepasswordemailmessagehtml'] = '<p>Dear %s,</p>
 
 <p>Regards, %s Site Administrator</p>';
 $string['forgotpassemailsendunsuccessful'] = 'Sorry, it appears that the e-mail could not be sent successfully. This is our fault, please try again shortly';
-$string['forgotpassemaildisabled'] = 'Sorry, email is disabled for the email address or username you entered. Please contact an administrator to reset your password.';
+$string['forgotpassemailsentanyway'] = 'An e-mail was sent to the address stored for this user, but the address may not be correct or the recipient server is returning messages. Please contact your Mahara administrator to reset your password if you do not receive the e-mail.';
 $string['forgotpassnosuchemailaddressorusername'] = 'The email address or username you entered doesn\'t match any users for this site';
 $string['forgotpasswordenternew'] = 'Please enter your new password to continue';
 $string['nosuchpasswordrequest'] = 'No such password request';
@@ -465,8 +469,8 @@ $string['unknownerror']       = 'An unknown error occurred (0x20f91a0)';
 
 // menu
 $string['home']        = 'Home';
-$string['myportfolio'] = 'My Portfolio';
-$string['myviews']       = ' My Views';
+$string['Content']     = 'Content';
+$string['myportfolio'] = 'Portfolio';
 $string['settings']    = 'Settings';
 $string['myfriends']          = 'My Friends';
 $string['findfriends']        = 'Find Friends';
@@ -475,9 +479,7 @@ $string['mygroups']           = 'My Groups';
 $string['findgroups']         = 'Find Groups';
 $string['returntosite']       = 'Return to Site';
 $string['siteadministration'] = 'Site Administration';
-$string['useradministration'] = 'User Administration';
-$string['viewmyprofilepage']  = 'View profile page';
-$string['editmyprofilepage']  = 'Edit profile page';
+$string['institutionadministration'] = 'Institution Administration';
 
 $string['unreadmessages'] = 'unread messages';
 $string['unreadmessage'] = 'unread message';
@@ -492,14 +494,16 @@ $string['about']              = 'About';
 $string['contactus']          = 'Contact Us';
 
 // my account
-$string['account'] =  'My account';
+$string['account'] =  'Settings';
 $string['accountprefs'] = 'Preferences';
 $string['preferences'] = 'Preferences';
 $string['activityprefs'] = 'Activity preferences';
 $string['changepassword'] = 'Change password';
 $string['notifications'] = 'Notifications';
+$string['inbox'] = 'Inbox';
+$string['gotoinbox'] = 'Go to inbox';
 $string['institutionmembership'] = 'Institution Membership';
-$string['institutionmembershipdescription'] = 'If you are a member of any institutions, they will be listed here.  You may also request membership of an institution, and if any institutions have invited you to join, you can accept or decline the invitation.';
+$string['institutionmembershipdescription'] = 'If you are a member of any institutions, they will be listed here. You may also request membership of institutions, and accept or decline pending membership invitations.';
 $string['youareamemberof'] = 'You are a member of %s';
 $string['leaveinstitution'] = 'Leave institution';
 $string['reallyleaveinstitution'] = 'Are you sure you want to leave this institution?';
@@ -522,6 +526,10 @@ $string['Invitations'] = 'Invitations';
 $string['config'] = 'Config';
 
 $string['sendmessage'] = 'Send message';
+$string['spamtrap'] = 'Spam trap';
+$string['formerror'] = 'There was an error processing your submission. Please try again.';
+$string['formerroremail'] = 'Contact us at %s if you continue to have problems.';
+$string['blacklisteddomaininurl'] = 'A url in this field contains the blacklisted domain %s.';
 
 $string['notinstallable'] = 'Not installable!';
 $string['installedplugins'] = 'Installed plugins';
@@ -541,7 +549,7 @@ $string['collapse'] = 'Collapse';
 $string['more...'] = 'More ...';
 $string['nohelpfound'] = 'There was no help found for this item';
 $string['nohelpfoundpage'] = 'There was no help found for this page';
-$string['couldnotgethelp'] = 'An error occurred trying to retrive the help page';
+$string['couldnotgethelp'] = 'An error occurred trying to retrieve the help page';
 $string['profileimage'] = 'Profile image';
 $string['primaryemailinvalid'] = 'Your primary email address is invalid';
 $string['addemail'] = 'Add email address';
@@ -568,8 +576,8 @@ $string['nodeletepermission'] = 'You do not have permission to delete this artef
 $string['noeditpermission'] = 'You do not have permission to edit this artefact';
 $string['Permissions'] = 'Permissions';
 $string['republish'] = 'Publish';
-$string['view'] = 'View';
-$string['artefactnotpublishable'] = 'Artefact %s is not publishable in view %s';
+$string['view'] = 'Page';
+$string['artefactnotpublishable'] = 'Artefact %s is not publishable in page %s';
 
 $string['belongingto'] = 'Belonging to';
 $string['allusers'] = 'All users';
@@ -604,10 +612,8 @@ $string['phpuploaderror_7'] = 'Failed to write file to disk.';
 $string['phpuploaderror_8'] = 'File upload stopped by extension.';
 $string['adminphpuploaderror'] = 'A file upload error was probably caused by your server configuration.';
 
-$string['youraccounthasbeensuspended'] = 'Your account has been suspended';
 $string['youraccounthasbeensuspendedtext2'] = 'Your account at %s has been suspended by %s.'; // @todo: more info?
 $string['youraccounthasbeensuspendedreasontext'] = "Your account at %s has been suspended by %s. Reason:\n\n%s";
-$string['youraccounthasbeenunsuspended'] = 'Your account has been unsuspended';
 $string['youraccounthasbeenunsuspendedtext2'] = 'Your account at %s has been unsuspended. You may once again log in and use the site.'; // can't provide a login link because we don't know how they log in - it might be by xmlrpc
 
 // size of stuff
@@ -863,6 +869,8 @@ $string['country.ye'] = 'Yemen';
 $string['country.zm'] = 'Zambia';
 $string['country.zw'] = 'Zimbabwe';
 
+$string['nocountryselected'] = 'No Country Selected';
+
 // general stuff that doesn't really fit anywhere else
 $string['system'] = 'System';
 $string['done'] = 'Done';
@@ -870,6 +878,12 @@ $string['back'] = 'Back';
 $string['backto'] = 'Back to %s';
 $string['alphabet'] = 'A,B,C,D,E,F,G,H,I,J,K,L,M,N,O,P,Q,R,S,T,U,V,W,X,Y,Z';
 $string['formatpostbbcode'] = 'You can format your post using BBCode. %sLearn more%s';
+$string['Created'] = 'Created';
+$string['Updated'] = 'Updated';
+$string['Total'] = 'Total';
+$string['Visits'] = 'Visits';
+$string['after'] = 'after';
+$string['before'] = 'before';
 
 // import related strings (maybe separated later)
 $string['importedfrom'] = 'Imported from %s';
@@ -878,13 +892,47 @@ $string['remotehost'] = 'Remote host %s';
 
 $string['Copyof'] = 'Copy of %s';
 
-// Profie views
-$string['loggedinusersonly'] = 'Logged in users only';
-$string['allowpublicaccess'] = 'Allow public (non logged in) access';
+// Profile views
+$string['loggedinusersonly'] = 'Allow logged in users only';
+$string['allowpublicaccess'] = 'Allow public access';
 $string['thisistheprofilepagefor'] = 'This is the profile page for %s';
+$string['viewmyprofilepage']  = 'View profile page';
+$string['editmyprofilepage']  = 'Edit profile page';
+$string['usersprofile'] = "%s's Profile";
+$string['profiledescription'] = 'Your profile page is what others see when they click on your name or profile picture';
+
+// Dashboard views
+$string['mydashboard'] = 'My Dashboard';
+$string['editdashboard'] = 'Edit';
+$string['usersdashboard'] = "%s's Dashboard";
+$string['dashboarddescription'] = 'Your dashboard page is what you see on the homepage when you first log in. Only you have access to it';
+$string['topicsimfollowing'] = "Topics I'm Following";
+$string['recentactivity'] = 'Recent Activity';
+$string['mymessages'] = 'My Messages';
 
 $string['pleasedonotreplytothismessage'] = "Please do not reply to this message.";
 $string['deleteduser'] = 'Deleted user';
 
-$string['recentupdates'] = 'Recent Updates';
-?>
+$string['theme'] = 'Theme';
+$string['choosetheme'] = 'Choose theme...';
+
+// Home page info block
+$string['Hide'] = 'Hide';
+$string['createcollect'] = 'Create and Collect';
+$string['createcollectsubtitle'] = 'Develop your portfolio';
+$string['updateyourprofile'] = 'Update your <a href="%s">Profile</a>';
+$string['uploadyourfiles'] = 'Upload your <a href="%s">Files</a>';
+$string['createyourresume'] = 'Create your <a href="%s">Resume</a>';
+$string['publishablog'] = 'Publish a <a href="%s">Journal</a>';
+$string['Organise'] = 'Organise';
+$string['organisesubtitle'] = 'Showcase your portfolio';
+$string['organisedescription'] = 'Organise your portfolio into <a href="%s">pages.</a>  Create different pages for different audiences - you choose the elements to include.';
+$string['sharenetwork'] = 'Share and Network';
+$string['sharenetworksubtitle'] = 'Find friends and join groups';
+$string['findfriendslinked'] = 'Find <a href="%s">Friends</a>';
+$string['joingroups'] = 'Join <a href="%s">Groups</a>';
+$string['sharenetworkdescription'] = '<br>Control your privacy.';
+$string['howtodisable'] = 'You have hidden the information box.  You can control its visibility in <a href="%s">Settings</a>.';
+
+// Blocktype
+$string['setblocktitle'] = 'Set a block title';
