@@ -83,6 +83,27 @@ function db_is_utf8() {
     return false;
 }
 
+function db_total_size() {
+    global $db;
+    if (!is_a($db, 'ADOConnection')) {
+        throw new SQLException('Database connection is not available ');
+    }
+    $dbname = db_quote(get_config('dbname'));
+    if (is_mysql()) {
+        $result = $db->Execute("
+            SELECT SUM( data_length + index_length ) AS dbsize
+            FROM information_schema.tables
+            WHERE table_schema = $dbname
+        ");
+        return $result->fields['dbsize'];
+    }
+    if (is_postgres()) {
+        $result = $db->Execute("SELECT * FROM pg_database_size($dbname)");
+        return $result->fields['pg_database_size'];
+    }
+    return false;
+}
+
 function column_collation_is_default($table, $column) {
     global $db;
     if (!is_a($db, 'ADOConnection')) {
@@ -133,13 +154,6 @@ function execute_sql($command, $values=null) {
         else {
             $result = $db->Execute($command);
         }
-        // searching for these rather than just select as subqueries may have select in them.
-        if (preg_match('/(update|insert|delete|alter|create)/i', $command)) {
-            increment_perf_db_writes();
-        }
-        else {
-            increment_perf_db_reads();
-        }
     }
     catch (ADODB_Exception $e) {
         log_debug($e->getMessage() . "Command was: $command");
@@ -301,7 +315,12 @@ function get_record($table, $field1, $value1, $field2=null, $value2=null, $field
  */
 function get_record_sql($sql, $values=null) {
     $limitfrom = 0;
-    $limitnum  = 2;
+    $limitnum  = 0;
+    # regex borrowed from htdocs/lib/adodb/adodb-lib.inc.php
+    if (!preg_match('/\sLIMIT\s+[0-9]+/i', $sql)) {
+        $limitfrom = 0;
+        $limitnum  = 2;
+    }
 
     if (!$rs = get_recordset_sql($sql, $values, $limitfrom, $limitnum)) {
         return false;
@@ -456,10 +475,8 @@ function get_recordset_sql($sql, $values=null, $limitfrom=null, $limitnum=null)
             if (!empty($values) && is_array($values) && count($values) > 0) {
                 $stmt = $db->Prepare($sql);
                 $rs = $db->Execute($stmt, $values);
-                increment_perf_db_reads();
             } else {
                 $rs = $db->Execute($sql);
-                increment_perf_db_reads();
             }
         }
     }
@@ -874,7 +891,6 @@ function set_field_select($table, $newfield, $newvalue, $select, $values) {
     $sql = 'UPDATE '. db_table_name($table) .' SET '. db_quote_identifier($newfield)  .' = ? ' . $select;
     try {
         $stmt = $db->Prepare($sql);
-        increment_perf_db_writes();
         return $db->Execute($stmt, $values);
     }
     catch (ADODB_Exception $e) {
@@ -910,7 +926,6 @@ function delete_records($table, $field1=null, $value1=null, $field2=null, $value
     $sql = 'DELETE FROM '. db_table_name($table) . ' ' . $select;
     try {
         $stmt = $db->Prepare($sql);
-        increment_perf_db_writes();
         return $db->Execute($stmt,$values);
     }
     catch (ADODB_Exception $e) {
@@ -949,10 +964,8 @@ function delete_records_sql($sql, $values=null) {
         $result = false;
         if (!empty($values) && is_array($values) && count($values) > 0) {
             $stmt = $db->Prepare($sql);
-            increment_perf_db_writes();
             $result = $db->Execute($stmt, $values);
         } else {
-            increment_perf_db_writes();
             $result = $db->Execute($sql);
         }
     }
@@ -1041,7 +1054,6 @@ function insert_record($table, $dataobject, $primarykey=false, $returnpk=false)
     // Run the SQL statement
     try {
         $stmt = $db->Prepare($insertSQL);
-        increment_perf_db_writes();
         $rs = $db->Execute($stmt,$ddd);
     }
     catch (ADODB_Exception $e) {
@@ -1068,7 +1080,6 @@ function insert_record($table, $dataobject, $primarykey=false, $returnpk=false)
         // try to get the primary key based on id
         try {
             $oidsql = 'SELECT ' . $primarykey . ' FROM '. db_table_name($table) . ' WHERE oid = ' . $id;
-            increment_perf_db_reads();
             $rs = $db->Execute($oidsql);
             if ($rs->RecordCount() == 1) {
                 return (integer)$rs->fields[0];
@@ -1255,7 +1266,6 @@ function update_record($table, $dataobject, $where=null) {
     $sql = 'UPDATE '. db_table_name($table) .' SET '. $update .' WHERE ' . $whereclause;
     try { 
         $stmt = $db->Prepare($sql);
-        increment_perf_db_writes();
         $rs = $db->Execute($stmt,array_merge($values, $wherevalues));
         return true;
     }
@@ -1352,7 +1362,6 @@ function where_values_prepared($value1=null, $value2=null, $value3=null, $value4
 function column_type($table, $column) {
     global $db;
 
-    increment_perf_db_reads();
     if(!$rs = $db->Execute('SELECT ' . $column.' FROM ' . db_table_name($table) . ' WHERE 1=2')) {
         return false;
     }
@@ -1454,7 +1463,12 @@ function db_format_tsfield($field, $as = null) {
  * and some other variables.
  */
 function configure_dbconnection() {
-    global $db;
+    global $db, $CFG;
+
+    if (!empty($CFG->perftolog) || !empty($CFG->perftofoot)) {
+        $db->fnExecute = 'increment_perf_db';
+        $db->fnCacheExecute = 'increment_perf_db_cached';
+    }
 
     $db->Execute("SET NAMES 'utf8'");
 
@@ -1554,20 +1568,24 @@ function create_sql_exception_message($e, $sql, $values) {
     return $message;
 }
 
-function increment_perf_db_reads() {
-    if (!get_config('perftolog') && !get_config('perftofoot')) {
-        return true;
-    }
+function &increment_perf_db($db, $sql, $inputarray) {
     global $PERF;
-    $PERF->dbreads++;
+
+    // searching for these rather than just select as subqueries may have select in them.
+    if (preg_match('/^(update|insert|delete|alter|create)/i', trim($sql))) {
+        $PERF->dbwrites++;
+    }
+    else {
+        $PERF->dbreads++;
+    }
+
+    $null = null;
+    return $null;
 }
 
-function increment_perf_db_writes() {
-    if (!get_config('perftolog') && !get_config('perftofoot')) {
-        return true;
-    }
+function increment_perf_db_cached($db, $secs2cache, $sql, $inputarray) {
     global $PERF;
-    $PERF->dbwrites++;
+    $PERF->dbcached++;
 }
 
 /**
@@ -1660,5 +1678,3 @@ function db_replace($replacearray) {
         }
     }
 }
-
-?>
