@@ -17,7 +17,7 @@
  * @author     James Stewart <james@jystewart.net>
  * @copyright  2005 James Stewart <james@jystewart.net>
  * @license    http://www.gnu.org/copyleft/lesser.html  GNU LGPL 2.1
- * @version    CVS: $Id: RSS2.php,v 1.12 2008/03/08 18:16:45 jystewart Exp $
+ * @version    CVS: $Id: RSS2.php 304308 2010-10-11 12:05:50Z clockwerx $
  * @link       http://pear.php.net/package/XML_Feed_Parser/
  */
 
@@ -25,7 +25,7 @@
  * This class handles RSS2 feeds.
  * 
  * @author    James Stewart <james@jystewart.net>
- * @version    Release: 1.0.3
+ * @version    Release: @package_version@
  * @package XML_Feed_Parser
  */
 class XML_Feed_Parser_RSS2 extends XML_Feed_Parser_Type
@@ -34,7 +34,7 @@ class XML_Feed_Parser_RSS2 extends XML_Feed_Parser_Type
      * The URI of the RelaxNG schema used to (optionally) validate the feed
      * @var string
      */
-    private $relax = 'rss20.rnc';
+    protected $relax = 'rss20.rng';
 
     /**
      * We're likely to use XPath, so let's keep it global
@@ -116,7 +116,7 @@ class XML_Feed_Parser_RSS2 extends XML_Feed_Parser_Type
         $this->model = $model;
 
         if ($strict) {
-            if (! $this->model->relaxNGValidate($this->relax)) {
+            if (! $this->relaxNGValidate()) {
                 throw new XML_Feed_Parser_Exception('Failed required validation');
             }
         }
@@ -332,4 +332,4 @@ class XML_Feed_Parser_RSS2 extends XML_Feed_Parser_Type
     }
 }
 
-?>
\ No newline at end of file
+?>
