@@ -51,7 +51,7 @@ function pieform_element_select(Pieform $form, $element) {/*{{{*/
             if (is_array($value)) {
                 $value = $value['value'];
             }
-            $result = hsc($value) . '<input type="hidden" name="' . $element['name'] . '" value="' . $key . '">';
+            $result = Pieform::hsc($value) . '<input type="hidden" name="' . Pieform::hsc($element['name']) . '" value="' . Pieform::hsc($key) . '">';
         }
         return $result;
     }
@@ -170,5 +170,3 @@ function pieform_element_select_get_value(Pieform $form, $element) {/*{{{*/
 
     return $values;
 }/*}}}*/
-
-?>
