@@ -1,26 +1,28 @@
 /**
  * Pieforms: Advanced web forms made easy
- * Copyright (C) 2006-2008 Catalyst IT Ltd (http://www.catalyst.net.nz)
+ * @source: http://gitorious.org/mahara/mahara
  *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * @licstart
+ * Copyright (C) 2006-2010  Catalyst IT Ltd
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * The JavaScript code in this page is free software: you can
+ * redistribute it and/or modify it under the terms of the GNU
+ * General Public License (GNU GPL) as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option)
+ * any later version.  The code is distributed WITHOUT ANY WARRANTY;
+ * without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU GPL for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * As additional permission under GNU GPL version 3 section 7, you
+ * may distribute non-source (e.g., minimized or compacted) forms of
+ * that code without the copy of the GNU GPL normally required by
+ * section 4, provided you include this license notice and a URL
+ * through which recipients can access the Corresponding Source.
+ * @licend
  *
  * @package    pieform
  * @subpackage static
  * @author     Nigel McNie <nigel@catalyst.net.nz>
- * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL
- * @copyright  (C) 2006-2008 Catalyst IT Ltd http://catalyst.net.nz
- *
  */
 
 window.pieformHandlers = {};
@@ -49,8 +51,19 @@ function PieformManager() {//{{{
         }
         forEach(check, function(form) {
             var element = getFirstElementByTagAndClassName(null, 'autofocus', form);
-            if (element && typeof(element.focus) == 'function') {
-                element.focus();
+            if (element && (typeof(element.focus) == 'function' || (element.focus && element.focus.call))) {
+                var type = getNodeAttribute(element, 'type');
+                if (type && type == 'hidden') {
+                    return;
+                }
+                try { // If element is invisible, IE will throw an error
+                    element.focus();
+                    if (hasElementClass(element, 'autoselect')
+                        && (typeof(element.select) == 'function' || (element.focus && element.select.call))) {
+                        element.select();
+                    }
+                }
+                catch (e) {}
                 throw MochiKit.Iter.StopIteration;
             }
         });
