@@ -200,7 +200,7 @@ class upload_manager {
         if (isset($this->file)
             && !empty($this->file['name']) 
             && preg_match("/\.([^\.]+)$/", $this->file['name'], $m)) {
-            return $m[1];
+            return strtolower($m[1]);
         }
         return null;
     }
@@ -330,9 +330,14 @@ function clam_mail_admins($notice) {
     $adminusers = get_records_array('usr', 'admin', 1);
     if ($adminusers) {
         foreach ($adminusers as $admin) {
-            // This should probably be some kind of notification
-            // rather than an email
-            email_user($admin, null, $subject, $notice);
+            $message = new StdClass;
+            $message->users = array($admin->id);
+
+            $message->subject = $subject;
+            $message->message = $notice;
+
+            require_once('activity.php');
+            activity_occurred('maharamessage', $message);
         }
     }
 }
@@ -392,5 +397,3 @@ function clam_log_infected($oldfilepath='', $newfilepath='', $userid=0) {
 
     log_debug($errorstr);
 }
-
-?>
