@@ -29,6 +29,8 @@ defined('INTERNAL') || die();
 
 class PluginNotificationInternal extends PluginNotification {
 
+    static $userdata = array('urltext', 'subject', 'message');
+
     public static function notify_user($user, $data) {
         $toinsert = new StdClass;
         $toinsert->type = $data->type;
@@ -41,12 +43,19 @@ class PluginNotificationInternal extends PluginNotification {
         }
         $toinsert->message = $data->message;
         $toinsert->subject = $data->subject;
+        $toinsert->parent = $data->parent;
         $toinsert->ctime = db_format_timestamp(time());
 
         if (!empty($data->url)) {
             $toinsert->url = $data->url;
         }
-        
+        if (!empty($data->urltext)) {
+            $toinsert->urltext = $data->urltext;
+        }
+        if (!empty($data->fromuser)) {
+            $toinsert->from = $data->fromuser;
+        }
+
         return insert_record('notification_internal_activity', $toinsert, 'id', true);
     }
     
@@ -55,9 +64,13 @@ class PluginNotificationInternal extends PluginNotification {
      */
 
     public static function unread_count($userid) {
-        return count_records('notification_internal_activity', 'usr', $userid, 'read', 0);
+        static $unreadcount = array();
+        if (!isset($unreadcount[$userid])) {
+            $unreadcount[$userid] = count_records('notification_internal_activity', 'usr', $userid, 'read', 0);
+        }
+        return $unreadcount[$userid];
     }
-    
+
     public static function get_event_subscriptions() {
         $subscriptions = array(
             (object)array(
@@ -72,6 +85,28 @@ class PluginNotificationInternal extends PluginNotification {
     public static function deleteuser($event, $user) {
         delete_records('notification_internal_activity', 'usr', $user['id']);
     }
-}
 
-?>
+    /**
+     * A method that does housekeeping on the notification_internal_activity table
+     * @param $types string|array the activity types to be cleaned
+     * @param $olderthandays integer the age an entry should at least be, before cleaning
+     */
+    public static function clean_notifications($types, $olderthandays=182) {
+        $staletime = db_format_timestamp(time() - ($olderthandays * 24 * 60 * 60));
+
+        if (!is_array($types)) {
+            // We're potentially dealing with just one type
+            $types = array($types);
+        }
+
+        $select = '
+            ctime < ?
+            AND "read" = 1
+            AND type IN(
+                SELECT id FROM {activity_type}
+                WHERE name IN (' . join(",", array_map(create_function('$a', 'return db_quote($a);'), $types)) . '))';
+
+        delete_records_select('notification_internal_activity', $select, array(db_format_timestamp($staletime)));
+    }
+
+}
