@@ -62,7 +62,7 @@ $form = pieform(array(
 ));
 
 $smarty = smarty();
-$smarty->assign('PAGEHEADING', hsc(TITLE));
+$smarty->assign('PAGEHEADING', TITLE);
 $smarty->assign('form', $form);
 $smarty->assign('user', $user);
 $smarty->display('user/denyrequest.tpl');
@@ -83,6 +83,7 @@ function denyrequest_submit(Pieform $form, $values) {
     $n->users = array($user->id);
     $lang = get_user_language($user->id);
     $displayname = display_name($USER, $user);
+    $n->urltext = $displayname;
 
     delete_records('usr_friend_request', 'owner', $loggedinid, 'requester', $id);
     $n->subject = get_string_from_language($lang, 'friendrequestrejectedsubject', 'group');
@@ -110,5 +111,3 @@ function denyrequest_submit(Pieform $form, $values) {
             break;
     }
 }
-
-?>
