@@ -32,6 +32,9 @@ require_once('pieforms/pieform.php');
 define('TITLE', get_string('findfriends'));
 require_once('searchlib.php');
 safe_require('search', 'internal');
+define('SECTION_PLUGINTYPE', 'core');
+define('SECTION_PLUGINNAME', 'user');
+define('SECTION_PAGE', 'find');
 
 $query = param_variable('query', '');
 $offset = param_integer('offset', 0);
@@ -39,7 +42,18 @@ $limit  = 10;
 
 $data = search_user($query, $limit, $offset, array('exclude' => $USER->get('id')));
 $data['query'] = $query;
-build_userlist_html($data, 'find');
+
+require_once(get_config('libroot').'group.php');
+$admingroups = false;
+foreach (group_get_user_groups() as $g) {
+    if (($g->jointype == 'invite' && $g->role == 'admin')
+        || ($g->jointype == 'controlled' && ($g->role == 'admin' || $g->see_submitted_views))) {
+        $admingroups = true;
+        break;
+    }
+}
+
+build_userlist_html($data, 'find', $admingroups);
 
 $searchform = pieform(array(
     'name' => 'search',
@@ -59,22 +73,26 @@ $searchform = pieform(array(
 $js = <<< EOF
 addLoadEvent(function () {
     p = {$data['pagination_js']}
-    connect('search_submit', 'onclick', function () {
-        var params = {'query': $('search_query').value};
+    connect('search_submit', 'onclick', function (event) {
+        replaceChildNodes('messages');
+        var params = {'query': $('search_query').value, 'extradata':serializeJSON({'page':'find'})};
         p.sendQuery(params);
+        event.stop();
     });
 });
 EOF;
 
-$smarty = smarty(array('paginator'), array(), array(), array('sideblocks' => array(friends_control_sideblock('find'))));
-$smarty->assign('PAGEHEADING', hsc(TITLE));
+$javascript = array('paginator');
+if ($admingroups) {
+    array_push($javascript, 'groupbox');
+}
+$smarty = smarty($javascript, array(), array('applychanges' => 'mahara', 'nogroups' => 'group'), array('sideblocks' => array(friends_control_sideblock('find'))));
+$smarty->assign('PAGEHEADING', TITLE);
 $smarty->assign('INLINEJAVASCRIPT', $js);
 $smarty->assign('results', $data);
 $smarty->assign('form', $searchform);
 $smarty->display('user/find.tpl');
 
 function search_submit(Pieform $form, $values) {
-    redirect('/user/find.php' . (isset($values['query']) ? '?query=' . urlencode($values['query']) : ''));
+    redirect('/user/find.php' . (!empty($values['query']) ? '?query=' . urlencode($values['query']) : ''));
 }
-
-?>
