@@ -60,7 +60,7 @@ $form = pieform(array(
 ));
 
 $smarty = smarty();
-$smarty->assign('PAGEHEADING', hsc(TITLE));
+$smarty->assign('PAGEHEADING', TITLE);
 $smarty->assign('form', $form);
 $smarty->assign('user', $user);
 $smarty->display('user/removefriend.tpl');
@@ -81,6 +81,7 @@ function removefriend_submit(Pieform $form, $values) {
     $n->users = array($user->id);
     $lang = get_user_language($user->id);
     $displayname = display_name($USER, $user);
+    $n->urltext = $displayname;
 
     delete_records_select('usr_friend', '(usr1 = ? AND usr2 = ?) OR (usr2 = ? AND usr1 = ?)', 
                             array($id, $loggedinid, $id, $loggedinid));
@@ -111,5 +112,3 @@ function removefriend_submit(Pieform $form, $values) {
     }
 
 }
-
-?>
