@@ -64,9 +64,13 @@ else {
     $view = $userobj->get_profile_view();
 }
 
+if (!$view) {
+    throw new AccessDeniedException(get_string('youcannotviewthisusersprofile', 'error'));
+}
+
 $viewid = $view->get('id');
 # access will either be logged in (always) or public as well
-if (!$view || !can_view_view($viewid)) {
+if (!can_view_view($viewid)) {
     throw new AccessDeniedException(get_string('youcannotviewthisusersprofile', 'error'));
 }
 
