@@ -49,19 +49,18 @@ if ($view->is_submitted()) {
 
 $group = $view->get('group');
 $institution = $view->get('institution');
-View::set_nav($group, $institution);
+$view->set_edit_nav();
+$view->set_user_theme();
 
 $new = param_boolean('new', 0);
 
 if ($new) {
-    define('TITLE', get_string('createviewsteptwo', 'view'));
+    define('TITLE', get_string('edittitleanddescription', 'view'));
 }
 else {
-    define('TITLE', get_string('editviewdetails', 'view', $view->get('title')));
+    define('TITLE', $view->get('title') . ': ' . get_string('edittitleanddescription', 'view'));
 }
 
-$heading = TITLE; // for the smarty template
-
 require_once('pieforms/pieform.php');
 
 $formatstring = '%s (%s)';
@@ -71,20 +70,20 @@ $ownerformatoptions = array(
     FORMAT_NAME_FIRSTNAMELASTNAME => sprintf($formatstring, get_string('fullname'), full_name())
 );
 
-$preferredname = $USER->get('preferredname');
-if ($preferredname !== '') {
-    $ownerformatoptions[FORMAT_NAME_PREFERREDNAME] = sprintf($formatstring, get_string('preferredname'), $preferredname);
+$displayname = display_name($USER);
+if ($displayname !== '') {
+    $ownerformatoptions[FORMAT_NAME_DISPLAYNAME] = sprintf($formatstring, get_string('preferredname'), $displayname);
 }
 $studentid = (string)get_field('artefact', 'title', 'owner', $USER->get('id'), 'artefacttype', 'studentid');
 if ($studentid !== '') {
     $ownerformatoptions[FORMAT_NAME_STUDENTID] = sprintf($formatstring, get_string('studentid'), $studentid);
 }
-$ownerformatoptions[FORMAT_NAME_DISPLAYNAME] = sprintf($formatstring, get_string('displayname'), display_name($USER));
 
 $editview = array(
     'name'     => 'editview',
     'method'   => 'post',
     'autofocus' => 'title',
+    'autoselect' => $new ? 'title' : null,
     'plugintype' => 'core',
     'pluginname' => 'view',
     'elements' => array(
@@ -108,6 +107,7 @@ $editview = array(
             'rows'         => 10,
             'cols'         => 70,
             'defaultvalue' => $view->get('description'),
+            'rules'        => array('maxlength' => 65536),
         ),
         'tags'        => array(
             'type'         => 'tags',
@@ -134,43 +134,16 @@ if (!($group || $institution)) {
     );
 }
 
-if ($new) {
-    $editview['elements']['submit'] = array(
-        'type'  => 'cancelbackcreate',
-        'value' => array(get_string('cancel'), get_string('back','view'), get_string('next')),
-        'confirm' => array(get_string('confirmcancelcreatingview', 'view'), null, null),
-    );
-}
-else {
-    $editview['elements']['submit'] = array(
-        'type'  => 'submit',
-        'value' => get_string('done'),
-    );
-}
+$editview['elements']['submit'] = array(
+    'type'  => 'submit',
+    'value' => get_string('save'),
+);
+
 
 $editview = pieform($editview);
 
-function editview_cancel_submit() {
-    global $view, $new, $group, $institution;
-    if ($new) {
-        $view->delete();
-    }
-    if ($group) {
-        redirect('/view/groupviews.php?group='.$group);
-    }
-    if ($institution) {
-        redirect('/view/institutionviews.php?institution='.$institution);
-    }
-    redirect('/view');
-}
-
 function editview_submit(Pieform $form, $values) {
-
-    global $view, $SESSION;
-
-    if (param_boolean('back')) {
-        redirect('/view/blocks.php?id=' . $view->get('id') . '&new=' . $new);
-    }
+    global $new, $view, $SESSION;
 
     $view->set('title', $values['title']);
     $view->set('description', $values['description']);
@@ -178,32 +151,20 @@ function editview_submit(Pieform $form, $values) {
     if (isset($values['ownerformat']) && $view->get('owner')) {
         $view->set('ownerformat', $values['ownerformat']);
     }
-
+    $SESSION->add_ok_msg(get_string('viewsavedsuccessfully', 'view'));
     $view->commit();
-
-    if ($values['new']) {
-        $redirecturl = '/view/access.php?id=' . $view->get('id') . '&new=1';
-    } 
-    else {
-        $SESSION->add_ok_msg(get_string('viewsavedsuccessfully', 'view'));
-        if ($view->get('group')) {
-            $redirecturl = '/view/groupviews.php?group='.$view->get('group');
-        }
-        else if ($view->get('institution')) {
-            $redirecturl = '/view/institutionviews.php?institution=' . $view->get('institution');
-        }
-        else {
-            $redirecturl = '/view/index.php';
-        }
-    }
-
-    redirect($redirecturl);
-
+    redirect('/view/blocks.php?id=' . $view->get('id'));
 }
 
 $smarty = smarty(array(), array(), array(), array('sidebars' => false));
-$smarty->assign('PAGEHEADING', hsc($heading));
 $smarty->assign('editview', $editview);
-$smarty->display('view/edit.tpl');
-
-?>
+$smarty->assign('viewid', $view->get('id'));
+$smarty->assign('viewtitle', $view->get('title'));
+$smarty->assign('edittitle', $view->can_edit_title());
+$smarty->assign('displaylink', $view->get_url());
+$smarty->assign('new', $new);
+if (get_config('viewmicroheaders')) {
+    $smarty->assign('microheaders', true);
+    $smarty->assign('microheadertitle', $view->display_title(true, false));
+}
+$smarty->display('view/edit.tpl');
\ No newline at end of file
