@@ -31,8 +31,10 @@ require(dirname(dirname(__FILE__)) . '/init.php');
 require_once('pieforms/pieform.php');
 require_once('view.php');
 require_once('activity.php');
+require_once(get_config('docroot') . 'artefact/lib.php');
 $viewid = param_integer('id');
 $groupid = param_integer('group');
+$returnto = param_variable('returnto', 'view');
 
 $view = get_record('view', 'id', $viewid, 'owner', $USER->get('id'));
 $group = get_record_sql(
@@ -61,13 +63,13 @@ $form = pieform(array(
         'submit' => array(
             'type' => 'submitcancel',
             'value' => array(get_string('yes'), get_string('no')),
-            'goto' => get_config('wwwroot') . 'view/'
+            'goto' => get_config('wwwroot') . returnto(),
         )
     ),
 ));
 
 $smarty = smarty();
-$smarty->assign('PAGEHEADING', hsc(TITLE));
+$smarty->assign('PAGEHEADING', TITLE);
 $smarty->assign('message', get_string('submitviewconfirm', 'view', $view->title, $group->name));
 $smarty->assign('form', $form);
 $smarty->display('view/submit.tpl');
@@ -75,17 +77,47 @@ $smarty->display('view/submit.tpl');
 function submitview_submit(Pieform $form, $values) {
     global $SESSION, $USER, $viewid, $groupid, $group;
     db_begin();
-    update_record('view', array('submittedgroup' => $groupid), array('id' => $viewid));
+    update_record('view', array('submittedgroup' => $groupid, 'submittedtime' => db_format_timestamp(time())), array('id' => $viewid));
+    $roles = get_column('grouptype_roles', 'role', 'grouptype', $group->grouptype, 'see_submitted_views', 1);
+    foreach ($roles as $role) {
+        $accessrecord = (object) array(
+            'view'            => $viewid,
+            'group'           => $groupid,
+            'role'            => $role,
+            'visible'         => 0,
+            'allowcomments'   => 1,
+            'approvecomments' => 0,
+        );
+        ensure_record_exists('view_access', $accessrecord, $accessrecord);
+    }
+    ArtefactType::update_locked($USER->get('id'));
     activity_occurred('groupmessage', array(
         'subject'       => get_string('viewsubmitted', 'view'), // will be overwritten
         'message'       => get_string('viewsubmitted', 'view'), // will be overwritten
         'submittedview' => $viewid,
         'viewowner'     => $USER->get('id'),
         'group'         => $groupid,
-        'roles'         => get_column('grouptype_roles', 'role', 'grouptype', $group->grouptype, 'see_submitted_views', 1),
+        'roles'         => $roles,
+        'strings'       => (object) array(
+            'urltext' => (object) array('key' => 'view'),
+        ),
     ));
     db_commit();
     $SESSION->add_ok_msg(get_string('viewsubmitted', 'view'));
-    redirect('/view/');
+    redirect('/' . returnto());
+}
+
+function returnto() {
+    GLOBAL $viewid, $groupid, $returnto;
+    // Deteremine the best place to return to
+    if ($returnto === 'group') {
+        $goto = 'group/view.php?id=' . $groupid;
+    }
+    else if ($returnto === 'view') {
+        $goto = 'view/view.php?id=' . $viewid;
+    }
+    else {
+        $goto = 'view/';
+    }
+    return $goto;
 }
-?>
